#!/usr/bin/env python
# 
# Copyright 2014, 2020 by Delphix
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import setuptools
from distutils.core import setup

setup(
    name='delphixpy',
    version='1.11.2.0',
    description='Delphix Client Bindings',
    author='Delphix',
    author_email='support@delphix.com',
    url='http://www.delphix.com',
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
    ],
    long_description="""DelphixPy
=========

DelphixPy is a set of auto-generated Python API wrappers to the
Delphix Virtualization Engine.

Usage
------------

.. code:: python

   # Simple script to refresh a Database
   from delphixpy.delphix_engine import DelphixEngine
   engine = DelphixEngine(
       "delphix-address",
       "delphix-user",
       "delphix-password",
       "DOMAIN",  # Instead of DOMAIN, use SYSTEM if you are using the sysadmin user.
       use_https=True,  # Connect through HTTPS instead of default HTTP
    )
   database.refresh(engine, "ORACLE_DB_CONTAINER-3")

Many more examples can be found in the `DelphixPy Examples Repository <https://github.com/delphix/delphixpy-examples>`_


Supported API Versions
----------------------

DelphixPy supports Delphix Engines versioned 4.0.0.x or equivalently
Delphix Engines running API version 1.3.0 and on.


Changelog
---------

1.10.5
^^^^^^
- Python3.7 introduces backwards incompatible syntax which breaks
  DelphixPy, to accomodate the `job_context.async` function has been
  renamed to `job_context.asyncly`.
- Drop support for Delphix Engines older than 4.1. API Versions: 1.3.0, 1.3.1, 1.3.2, 1.3.3
- Publish universal wheels.

1.10.3
^^^^^^
- API objects are now hashable in Python3
- Undefined objects now raise errors when their attributes are modified
- Various bug fixes

1.10.2
^^^^^^

- Python3 compatibility. Python2 and Python3 are both supported
  now. The Python2 wrappers will now require all strings be of
  type `unicode` and the Python3 wrappers will now require all
  strings to be of type `str`.

  This may cause regressions on existing Python2 code as seen by:
  `AssertionError: Expected one of [u'string'], but got <type 'str'>`

- Https support
- Various speed improvements
""",
    packages=[
        'delphixpy',
        'delphixpy/web',
        'delphixpy/web/environment',
        'delphixpy/web/environment/oracle',
        'delphixpy/web/environment/oracle/clusternode',
        'delphixpy/web/environment/oracle/listener',
        'delphixpy/web/environment/user',
        'delphixpy/web/environment/windows',
        'delphixpy/web/environment/windows/clusternode',
        'delphixpy/web/environment/windows/clusterinstance',
        'delphixpy/web/environment/windows/availabilitygrouplistener',
        'delphixpy/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/web/timezone',
        'delphixpy/web/theme',
        'delphixpy/web/domain',
        'delphixpy/web/connectivity',
        'delphixpy/web/replication',
        'delphixpy/web/replication/sourcestate',
        'delphixpy/web/replication/targetstate',
        'delphixpy/web/replication/spec',
        'delphixpy/web/replication/serializationpoint',
        'delphixpy/web/registration',
        'delphixpy/web/registration/status',
        'delphixpy/web/fault',
        'delphixpy/web/fault/effect',
        'delphixpy/web/network',
        'delphixpy/web/network/interface',
        'delphixpy/web/network/route',
        'delphixpy/web/network/test',
        'delphixpy/web/network/test/latency',
        'delphixpy/web/network/test/throughput',
        'delphixpy/web/network/test/dsp',
        'delphixpy/web/network/dsp',
        'delphixpy/web/network/dsp/autotune',
        'delphixpy/web/transformation',
        'delphixpy/web/database',
        'delphixpy/web/database/template',
        'delphixpy/web/database/performanceHistory',
        'delphixpy/web/user',
        'delphixpy/web/delphix',
        'delphixpy/web/host',
        'delphixpy/web/host/privilegeElevation',
        'delphixpy/web/host/privilegeElevation/profile',
        'delphixpy/web/host/privilegeElevation/profileScript',
        'delphixpy/web/usage',
        'delphixpy/web/system',
        'delphixpy/web/system/status',
        'delphixpy/web/system/verification',
        'delphixpy/web/system/verification/reports',
        'delphixpy/web/system/verification/reports/steps',
        'delphixpy/web/system/package',
        'delphixpy/web/system/version',
        'delphixpy/web/system/upgradeCheckResult',
        'delphixpy/web/capacity',
        'delphixpy/web/capacity/consumer',
        'delphixpy/web/capacity/consumer/historical',
        'delphixpy/web/capacity/system',
        'delphixpy/web/capacity/system/historical',
        'delphixpy/web/capacity/group',
        'delphixpy/web/capacity/group/historical',
        'delphixpy/web/capacity/snapshot',
        'delphixpy/web/action',
        'delphixpy/web/analytics',
        'delphixpy/web/analytics/statistic',
        'delphixpy/web/group',
        'delphixpy/web/passwordPolicy',
        'delphixpy/web/permission',
        'delphixpy/web/notification',
        'delphixpy/web/policy',
        'delphixpy/web/session',
        'delphixpy/web/selfservice',
        'delphixpy/web/selfservice/datasource',
        'delphixpy/web/selfservice/template',
        'delphixpy/web/selfservice/branch',
        'delphixpy/web/selfservice/usagedata',
        'delphixpy/web/selfservice/usagedata/operationduration',
        'delphixpy/web/selfservice/usagedata/operationcount',
        'delphixpy/web/selfservice/config',
        'delphixpy/web/selfservice/operation',
        'delphixpy/web/selfservice/usage',
        'delphixpy/web/selfservice/usage/template',
        'delphixpy/web/selfservice/usage/branch',
        'delphixpy/web/selfservice/usage/user',
        'delphixpy/web/selfservice/usage/container',
        'delphixpy/web/selfservice/usage/bookmark',
        'delphixpy/web/selfservice/usage/bookmark/tag',
        'delphixpy/web/selfservice/container',
        'delphixpy/web/selfservice/bookmark',
        'delphixpy/web/timeflow',
        'delphixpy/web/timeflow/oracle',
        'delphixpy/web/timeflow/oracle/log',
        'delphixpy/web/timeflow/bookmark',
        'delphixpy/web/maskingjob',
        'delphixpy/web/maskingjob/serviceconfig',
        'delphixpy/web/objects',
        'delphixpy/web/authorization',
        'delphixpy/web/authorization/configuration',
        'delphixpy/web/role',
        'delphixpy/web/toolkit',
        'delphixpy/web/service',
        'delphixpy/web/service/saml',
        'delphixpy/web/service/saml/serviceprovider',
        'delphixpy/web/service/smtp',
        'delphixpy/web/service/userPaths',
        'delphixpy/web/service/minimalPhonehome',
        'delphixpy/web/service/httpConnector',
        'delphixpy/web/service/nfs',
        'delphixpy/web/service/time',
        'delphixpy/web/service/certificate',
        'delphixpy/web/service/sso',
        'delphixpy/web/service/ldap',
        'delphixpy/web/service/ldap/server',
        'delphixpy/web/service/linkingsettings',
        'delphixpy/web/service/phonehome',
        'delphixpy/web/service/dns',
        'delphixpy/web/service/passwordVault',
        'delphixpy/web/service/support',
        'delphixpy/web/service/support/bundle',
        'delphixpy/web/service/support/access',
        'delphixpy/web/service/security',
        'delphixpy/web/service/userInterface',
        'delphixpy/web/service/cloud',
        'delphixpy/web/service/locale',
        'delphixpy/web/service/schema',
        'delphixpy/web/service/insight',
        'delphixpy/web/service/insight/splunkHec',
        'delphixpy/web/service/syslog',
        'delphixpy/web/service/snmp',
        'delphixpy/web/service/snmp/manager',
        'delphixpy/web/service/proxy',
        'delphixpy/web/service/tls',
        'delphixpy/web/service/tls/caCertificate',
        'delphixpy/web/service/tls/csr',
        'delphixpy/web/service/tls/cipherSuite',
        'delphixpy/web/service/tls/endEntityCertificate',
        'delphixpy/web/service/kerberos',
        'delphixpy/web/repository',
        'delphixpy/web/repository/template',
        'delphixpy/web/data',
        'delphixpy/web/snapshot',
        'delphixpy/web/alert',
        'delphixpy/web/alert/profile',
        'delphixpy/web/storage',
        'delphixpy/web/storage/device',
        'delphixpy/web/storage/scrub',
        'delphixpy/web/storage/remove',
        'delphixpy/web/storage/test',
        'delphixpy/web/job',
        'delphixpy/web/source',
        'delphixpy/web/source/operationTemplate',
        'delphixpy/web/sourceconfig',
        'delphixpy/web/namespace',
        'delphixpy/web/about',
        'delphixpy/v1_10_6',
        'delphixpy/v1_10_6/web',
        'delphixpy/v1_10_6/web/environment',
        'delphixpy/v1_10_6/web/environment/oracle',
        'delphixpy/v1_10_6/web/environment/oracle/clusternode',
        'delphixpy/v1_10_6/web/environment/oracle/listener',
        'delphixpy/v1_10_6/web/environment/user',
        'delphixpy/v1_10_6/web/environment/windows',
        'delphixpy/v1_10_6/web/environment/windows/clusternode',
        'delphixpy/v1_10_6/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_6/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_6/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_6/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_6/web/timezone',
        'delphixpy/v1_10_6/web/domain',
        'delphixpy/v1_10_6/web/connectivity',
        'delphixpy/v1_10_6/web/replication',
        'delphixpy/v1_10_6/web/replication/sourcestate',
        'delphixpy/v1_10_6/web/replication/targetstate',
        'delphixpy/v1_10_6/web/replication/spec',
        'delphixpy/v1_10_6/web/replication/serializationpoint',
        'delphixpy/v1_10_6/web/registration',
        'delphixpy/v1_10_6/web/registration/status',
        'delphixpy/v1_10_6/web/fault',
        'delphixpy/v1_10_6/web/fault/effect',
        'delphixpy/v1_10_6/web/network',
        'delphixpy/v1_10_6/web/network/interface',
        'delphixpy/v1_10_6/web/network/route',
        'delphixpy/v1_10_6/web/network/test',
        'delphixpy/v1_10_6/web/network/test/latency',
        'delphixpy/v1_10_6/web/network/test/throughput',
        'delphixpy/v1_10_6/web/network/test/dsp',
        'delphixpy/v1_10_6/web/network/dsp',
        'delphixpy/v1_10_6/web/network/dsp/autotune',
        'delphixpy/v1_10_6/web/transformation',
        'delphixpy/v1_10_6/web/database',
        'delphixpy/v1_10_6/web/database/template',
        'delphixpy/v1_10_6/web/database/performanceHistory',
        'delphixpy/v1_10_6/web/user',
        'delphixpy/v1_10_6/web/delphix',
        'delphixpy/v1_10_6/web/host',
        'delphixpy/v1_10_6/web/host/privilegeElevation',
        'delphixpy/v1_10_6/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_6/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_6/web/usage',
        'delphixpy/v1_10_6/web/system',
        'delphixpy/v1_10_6/web/system/status',
        'delphixpy/v1_10_6/web/system/package',
        'delphixpy/v1_10_6/web/system/version',
        'delphixpy/v1_10_6/web/system/upgradeCheckResult',
        'delphixpy/v1_10_6/web/capacity',
        'delphixpy/v1_10_6/web/capacity/consumer',
        'delphixpy/v1_10_6/web/capacity/consumer/historical',
        'delphixpy/v1_10_6/web/capacity/system',
        'delphixpy/v1_10_6/web/capacity/system/historical',
        'delphixpy/v1_10_6/web/capacity/group',
        'delphixpy/v1_10_6/web/capacity/group/historical',
        'delphixpy/v1_10_6/web/capacity/snapshot',
        'delphixpy/v1_10_6/web/action',
        'delphixpy/v1_10_6/web/analytics',
        'delphixpy/v1_10_6/web/analytics/statistic',
        'delphixpy/v1_10_6/web/group',
        'delphixpy/v1_10_6/web/passwordPolicy',
        'delphixpy/v1_10_6/web/permission',
        'delphixpy/v1_10_6/web/notification',
        'delphixpy/v1_10_6/web/policy',
        'delphixpy/v1_10_6/web/session',
        'delphixpy/v1_10_6/web/selfservice',
        'delphixpy/v1_10_6/web/selfservice/datasource',
        'delphixpy/v1_10_6/web/selfservice/template',
        'delphixpy/v1_10_6/web/selfservice/branch',
        'delphixpy/v1_10_6/web/selfservice/usagedata',
        'delphixpy/v1_10_6/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_6/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_6/web/selfservice/config',
        'delphixpy/v1_10_6/web/selfservice/operation',
        'delphixpy/v1_10_6/web/selfservice/usage',
        'delphixpy/v1_10_6/web/selfservice/usage/template',
        'delphixpy/v1_10_6/web/selfservice/usage/branch',
        'delphixpy/v1_10_6/web/selfservice/usage/user',
        'delphixpy/v1_10_6/web/selfservice/usage/container',
        'delphixpy/v1_10_6/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_6/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_6/web/selfservice/container',
        'delphixpy/v1_10_6/web/selfservice/bookmark',
        'delphixpy/v1_10_6/web/timeflow',
        'delphixpy/v1_10_6/web/timeflow/oracle',
        'delphixpy/v1_10_6/web/timeflow/oracle/log',
        'delphixpy/v1_10_6/web/timeflow/bookmark',
        'delphixpy/v1_10_6/web/maskingjob',
        'delphixpy/v1_10_6/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_6/web/objects',
        'delphixpy/v1_10_6/web/authorization',
        'delphixpy/v1_10_6/web/authorization/configuration',
        'delphixpy/v1_10_6/web/role',
        'delphixpy/v1_10_6/web/toolkit',
        'delphixpy/v1_10_6/web/service',
        'delphixpy/v1_10_6/web/service/saml',
        'delphixpy/v1_10_6/web/service/saml/serviceprovider',
        'delphixpy/v1_10_6/web/service/smtp',
        'delphixpy/v1_10_6/web/service/httpConnector',
        'delphixpy/v1_10_6/web/service/time',
        'delphixpy/v1_10_6/web/service/certificate',
        'delphixpy/v1_10_6/web/service/sso',
        'delphixpy/v1_10_6/web/service/ldap',
        'delphixpy/v1_10_6/web/service/ldap/server',
        'delphixpy/v1_10_6/web/service/linkingsettings',
        'delphixpy/v1_10_6/web/service/phonehome',
        'delphixpy/v1_10_6/web/service/dns',
        'delphixpy/v1_10_6/web/service/support',
        'delphixpy/v1_10_6/web/service/support/bundle',
        'delphixpy/v1_10_6/web/service/support/access',
        'delphixpy/v1_10_6/web/service/security',
        'delphixpy/v1_10_6/web/service/userInterface',
        'delphixpy/v1_10_6/web/service/cloud',
        'delphixpy/v1_10_6/web/service/locale',
        'delphixpy/v1_10_6/web/service/schema',
        'delphixpy/v1_10_6/web/service/insight',
        'delphixpy/v1_10_6/web/service/insight/splunkHec',
        'delphixpy/v1_10_6/web/service/syslog',
        'delphixpy/v1_10_6/web/service/snmp',
        'delphixpy/v1_10_6/web/service/snmp/manager',
        'delphixpy/v1_10_6/web/service/proxy',
        'delphixpy/v1_10_6/web/service/tls',
        'delphixpy/v1_10_6/web/service/tls/caCertificate',
        'delphixpy/v1_10_6/web/service/tls/csr',
        'delphixpy/v1_10_6/web/service/tls/cipherSuite',
        'delphixpy/v1_10_6/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_6/web/service/kerberos',
        'delphixpy/v1_10_6/web/repository',
        'delphixpy/v1_10_6/web/repository/template',
        'delphixpy/v1_10_6/web/data',
        'delphixpy/v1_10_6/web/snapshot',
        'delphixpy/v1_10_6/web/alert',
        'delphixpy/v1_10_6/web/alert/profile',
        'delphixpy/v1_10_6/web/storage',
        'delphixpy/v1_10_6/web/storage/device',
        'delphixpy/v1_10_6/web/storage/scrub',
        'delphixpy/v1_10_6/web/storage/remove',
        'delphixpy/v1_10_6/web/storage/test',
        'delphixpy/v1_10_6/web/job',
        'delphixpy/v1_10_6/web/source',
        'delphixpy/v1_10_6/web/source/operationTemplate',
        'delphixpy/v1_10_6/web/sourceconfig',
        'delphixpy/v1_10_6/web/namespace',
        'delphixpy/v1_10_6/web/about',
        'delphixpy/v1_9_0',
        'delphixpy/v1_9_0/web',
        'delphixpy/v1_9_0/web/environment',
        'delphixpy/v1_9_0/web/environment/oracle',
        'delphixpy/v1_9_0/web/environment/oracle/clusternode',
        'delphixpy/v1_9_0/web/environment/oracle/listener',
        'delphixpy/v1_9_0/web/environment/user',
        'delphixpy/v1_9_0/web/environment/windows',
        'delphixpy/v1_9_0/web/environment/windows/clusternode',
        'delphixpy/v1_9_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_9_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_9_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_9_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_9_0/web/timezone',
        'delphixpy/v1_9_0/web/domain',
        'delphixpy/v1_9_0/web/connectivity',
        'delphixpy/v1_9_0/web/replication',
        'delphixpy/v1_9_0/web/replication/sourcestate',
        'delphixpy/v1_9_0/web/replication/targetstate',
        'delphixpy/v1_9_0/web/replication/spec',
        'delphixpy/v1_9_0/web/replication/serializationpoint',
        'delphixpy/v1_9_0/web/registration',
        'delphixpy/v1_9_0/web/registration/status',
        'delphixpy/v1_9_0/web/fault',
        'delphixpy/v1_9_0/web/fault/effect',
        'delphixpy/v1_9_0/web/network',
        'delphixpy/v1_9_0/web/network/interface',
        'delphixpy/v1_9_0/web/network/route',
        'delphixpy/v1_9_0/web/network/test',
        'delphixpy/v1_9_0/web/network/test/latency',
        'delphixpy/v1_9_0/web/network/test/throughput',
        'delphixpy/v1_9_0/web/network/test/dsp',
        'delphixpy/v1_9_0/web/network/dsp',
        'delphixpy/v1_9_0/web/network/dsp/autotune',
        'delphixpy/v1_9_0/web/transformation',
        'delphixpy/v1_9_0/web/database',
        'delphixpy/v1_9_0/web/database/template',
        'delphixpy/v1_9_0/web/database/performanceHistory',
        'delphixpy/v1_9_0/web/user',
        'delphixpy/v1_9_0/web/delphix',
        'delphixpy/v1_9_0/web/host',
        'delphixpy/v1_9_0/web/host/privilegeElevation',
        'delphixpy/v1_9_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_9_0/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_9_0/web/system',
        'delphixpy/v1_9_0/web/system/package',
        'delphixpy/v1_9_0/web/system/version',
        'delphixpy/v1_9_0/web/system/upgradeCheckResult',
        'delphixpy/v1_9_0/web/capacity',
        'delphixpy/v1_9_0/web/capacity/consumer',
        'delphixpy/v1_9_0/web/capacity/consumer/historical',
        'delphixpy/v1_9_0/web/capacity/system',
        'delphixpy/v1_9_0/web/capacity/system/historical',
        'delphixpy/v1_9_0/web/capacity/group',
        'delphixpy/v1_9_0/web/capacity/group/historical',
        'delphixpy/v1_9_0/web/capacity/snapshot',
        'delphixpy/v1_9_0/web/action',
        'delphixpy/v1_9_0/web/analytics',
        'delphixpy/v1_9_0/web/analytics/statistic',
        'delphixpy/v1_9_0/web/group',
        'delphixpy/v1_9_0/web/passwordPolicy',
        'delphixpy/v1_9_0/web/permission',
        'delphixpy/v1_9_0/web/notification',
        'delphixpy/v1_9_0/web/policy',
        'delphixpy/v1_9_0/web/session',
        'delphixpy/v1_9_0/web/timeflow',
        'delphixpy/v1_9_0/web/timeflow/oracle',
        'delphixpy/v1_9_0/web/timeflow/oracle/log',
        'delphixpy/v1_9_0/web/timeflow/bookmark',
        'delphixpy/v1_9_0/web/maskingjob',
        'delphixpy/v1_9_0/web/maskingjob/serviceconfig',
        'delphixpy/v1_9_0/web/objects',
        'delphixpy/v1_9_0/web/authorization',
        'delphixpy/v1_9_0/web/role',
        'delphixpy/v1_9_0/web/toolkit',
        'delphixpy/v1_9_0/web/jetstream',
        'delphixpy/v1_9_0/web/jetstream/datasource',
        'delphixpy/v1_9_0/web/jetstream/template',
        'delphixpy/v1_9_0/web/jetstream/branch',
        'delphixpy/v1_9_0/web/jetstream/usagedata',
        'delphixpy/v1_9_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_9_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_9_0/web/jetstream/config',
        'delphixpy/v1_9_0/web/jetstream/operation',
        'delphixpy/v1_9_0/web/jetstream/usage',
        'delphixpy/v1_9_0/web/jetstream/usage/template',
        'delphixpy/v1_9_0/web/jetstream/usage/branch',
        'delphixpy/v1_9_0/web/jetstream/usage/user',
        'delphixpy/v1_9_0/web/jetstream/usage/container',
        'delphixpy/v1_9_0/web/jetstream/usage/bookmark',
        'delphixpy/v1_9_0/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_9_0/web/jetstream/container',
        'delphixpy/v1_9_0/web/jetstream/bookmark',
        'delphixpy/v1_9_0/web/service',
        'delphixpy/v1_9_0/web/service/saml',
        'delphixpy/v1_9_0/web/service/saml/serviceprovider',
        'delphixpy/v1_9_0/web/service/smtp',
        'delphixpy/v1_9_0/web/service/httpConnector',
        'delphixpy/v1_9_0/web/service/time',
        'delphixpy/v1_9_0/web/service/certificate',
        'delphixpy/v1_9_0/web/service/ldap',
        'delphixpy/v1_9_0/web/service/ldap/server',
        'delphixpy/v1_9_0/web/service/linkingsettings',
        'delphixpy/v1_9_0/web/service/phonehome',
        'delphixpy/v1_9_0/web/service/dns',
        'delphixpy/v1_9_0/web/service/support',
        'delphixpy/v1_9_0/web/service/support/bundle',
        'delphixpy/v1_9_0/web/service/support/access',
        'delphixpy/v1_9_0/web/service/security',
        'delphixpy/v1_9_0/web/service/locale',
        'delphixpy/v1_9_0/web/service/schema',
        'delphixpy/v1_9_0/web/service/syslog',
        'delphixpy/v1_9_0/web/service/snmp',
        'delphixpy/v1_9_0/web/service/snmp/manager',
        'delphixpy/v1_9_0/web/service/proxy',
        'delphixpy/v1_9_0/web/service/tls',
        'delphixpy/v1_9_0/web/service/tls/cacert',
        'delphixpy/v1_9_0/web/service/kerberos',
        'delphixpy/v1_9_0/web/repository',
        'delphixpy/v1_9_0/web/repository/template',
        'delphixpy/v1_9_0/web/data',
        'delphixpy/v1_9_0/web/snapshot',
        'delphixpy/v1_9_0/web/alert',
        'delphixpy/v1_9_0/web/alert/profile',
        'delphixpy/v1_9_0/web/storage',
        'delphixpy/v1_9_0/web/storage/device',
        'delphixpy/v1_9_0/web/storage/scrub',
        'delphixpy/v1_9_0/web/storage/remove',
        'delphixpy/v1_9_0/web/storage/test',
        'delphixpy/v1_9_0/web/job',
        'delphixpy/v1_9_0/web/source',
        'delphixpy/v1_9_0/web/source/operationTemplate',
        'delphixpy/v1_9_0/web/sourceconfig',
        'delphixpy/v1_9_0/web/namespace',
        'delphixpy/v1_9_0/web/about',
        'delphixpy/v1_9_1',
        'delphixpy/v1_9_1/web',
        'delphixpy/v1_9_1/web/environment',
        'delphixpy/v1_9_1/web/environment/oracle',
        'delphixpy/v1_9_1/web/environment/oracle/clusternode',
        'delphixpy/v1_9_1/web/environment/oracle/listener',
        'delphixpy/v1_9_1/web/environment/user',
        'delphixpy/v1_9_1/web/environment/windows',
        'delphixpy/v1_9_1/web/environment/windows/clusternode',
        'delphixpy/v1_9_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_9_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_9_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_9_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_9_1/web/timezone',
        'delphixpy/v1_9_1/web/domain',
        'delphixpy/v1_9_1/web/connectivity',
        'delphixpy/v1_9_1/web/replication',
        'delphixpy/v1_9_1/web/replication/sourcestate',
        'delphixpy/v1_9_1/web/replication/targetstate',
        'delphixpy/v1_9_1/web/replication/spec',
        'delphixpy/v1_9_1/web/replication/serializationpoint',
        'delphixpy/v1_9_1/web/registration',
        'delphixpy/v1_9_1/web/registration/status',
        'delphixpy/v1_9_1/web/fault',
        'delphixpy/v1_9_1/web/fault/effect',
        'delphixpy/v1_9_1/web/network',
        'delphixpy/v1_9_1/web/network/interface',
        'delphixpy/v1_9_1/web/network/route',
        'delphixpy/v1_9_1/web/network/test',
        'delphixpy/v1_9_1/web/network/test/latency',
        'delphixpy/v1_9_1/web/network/test/throughput',
        'delphixpy/v1_9_1/web/network/test/dsp',
        'delphixpy/v1_9_1/web/network/dsp',
        'delphixpy/v1_9_1/web/network/dsp/autotune',
        'delphixpy/v1_9_1/web/transformation',
        'delphixpy/v1_9_1/web/database',
        'delphixpy/v1_9_1/web/database/template',
        'delphixpy/v1_9_1/web/database/performanceHistory',
        'delphixpy/v1_9_1/web/user',
        'delphixpy/v1_9_1/web/delphix',
        'delphixpy/v1_9_1/web/host',
        'delphixpy/v1_9_1/web/host/privilegeElevation',
        'delphixpy/v1_9_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_9_1/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_9_1/web/system',
        'delphixpy/v1_9_1/web/system/package',
        'delphixpy/v1_9_1/web/system/version',
        'delphixpy/v1_9_1/web/system/upgradeCheckResult',
        'delphixpy/v1_9_1/web/capacity',
        'delphixpy/v1_9_1/web/capacity/consumer',
        'delphixpy/v1_9_1/web/capacity/consumer/historical',
        'delphixpy/v1_9_1/web/capacity/system',
        'delphixpy/v1_9_1/web/capacity/system/historical',
        'delphixpy/v1_9_1/web/capacity/group',
        'delphixpy/v1_9_1/web/capacity/group/historical',
        'delphixpy/v1_9_1/web/capacity/snapshot',
        'delphixpy/v1_9_1/web/action',
        'delphixpy/v1_9_1/web/analytics',
        'delphixpy/v1_9_1/web/analytics/statistic',
        'delphixpy/v1_9_1/web/group',
        'delphixpy/v1_9_1/web/passwordPolicy',
        'delphixpy/v1_9_1/web/permission',
        'delphixpy/v1_9_1/web/notification',
        'delphixpy/v1_9_1/web/policy',
        'delphixpy/v1_9_1/web/session',
        'delphixpy/v1_9_1/web/timeflow',
        'delphixpy/v1_9_1/web/timeflow/oracle',
        'delphixpy/v1_9_1/web/timeflow/oracle/log',
        'delphixpy/v1_9_1/web/timeflow/bookmark',
        'delphixpy/v1_9_1/web/maskingjob',
        'delphixpy/v1_9_1/web/maskingjob/serviceconfig',
        'delphixpy/v1_9_1/web/objects',
        'delphixpy/v1_9_1/web/authorization',
        'delphixpy/v1_9_1/web/role',
        'delphixpy/v1_9_1/web/toolkit',
        'delphixpy/v1_9_1/web/jetstream',
        'delphixpy/v1_9_1/web/jetstream/datasource',
        'delphixpy/v1_9_1/web/jetstream/template',
        'delphixpy/v1_9_1/web/jetstream/branch',
        'delphixpy/v1_9_1/web/jetstream/usagedata',
        'delphixpy/v1_9_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_9_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_9_1/web/jetstream/config',
        'delphixpy/v1_9_1/web/jetstream/operation',
        'delphixpy/v1_9_1/web/jetstream/usage',
        'delphixpy/v1_9_1/web/jetstream/usage/template',
        'delphixpy/v1_9_1/web/jetstream/usage/branch',
        'delphixpy/v1_9_1/web/jetstream/usage/user',
        'delphixpy/v1_9_1/web/jetstream/usage/container',
        'delphixpy/v1_9_1/web/jetstream/usage/bookmark',
        'delphixpy/v1_9_1/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_9_1/web/jetstream/container',
        'delphixpy/v1_9_1/web/jetstream/bookmark',
        'delphixpy/v1_9_1/web/service',
        'delphixpy/v1_9_1/web/service/saml',
        'delphixpy/v1_9_1/web/service/saml/serviceprovider',
        'delphixpy/v1_9_1/web/service/smtp',
        'delphixpy/v1_9_1/web/service/httpConnector',
        'delphixpy/v1_9_1/web/service/time',
        'delphixpy/v1_9_1/web/service/certificate',
        'delphixpy/v1_9_1/web/service/ldap',
        'delphixpy/v1_9_1/web/service/ldap/server',
        'delphixpy/v1_9_1/web/service/linkingsettings',
        'delphixpy/v1_9_1/web/service/phonehome',
        'delphixpy/v1_9_1/web/service/dns',
        'delphixpy/v1_9_1/web/service/support',
        'delphixpy/v1_9_1/web/service/support/bundle',
        'delphixpy/v1_9_1/web/service/support/access',
        'delphixpy/v1_9_1/web/service/security',
        'delphixpy/v1_9_1/web/service/locale',
        'delphixpy/v1_9_1/web/service/schema',
        'delphixpy/v1_9_1/web/service/syslog',
        'delphixpy/v1_9_1/web/service/snmp',
        'delphixpy/v1_9_1/web/service/snmp/manager',
        'delphixpy/v1_9_1/web/service/proxy',
        'delphixpy/v1_9_1/web/service/tls',
        'delphixpy/v1_9_1/web/service/tls/cacert',
        'delphixpy/v1_9_1/web/service/kerberos',
        'delphixpy/v1_9_1/web/repository',
        'delphixpy/v1_9_1/web/repository/template',
        'delphixpy/v1_9_1/web/data',
        'delphixpy/v1_9_1/web/snapshot',
        'delphixpy/v1_9_1/web/alert',
        'delphixpy/v1_9_1/web/alert/profile',
        'delphixpy/v1_9_1/web/storage',
        'delphixpy/v1_9_1/web/storage/device',
        'delphixpy/v1_9_1/web/storage/scrub',
        'delphixpy/v1_9_1/web/storage/remove',
        'delphixpy/v1_9_1/web/storage/test',
        'delphixpy/v1_9_1/web/job',
        'delphixpy/v1_9_1/web/source',
        'delphixpy/v1_9_1/web/source/operationTemplate',
        'delphixpy/v1_9_1/web/sourceconfig',
        'delphixpy/v1_9_1/web/namespace',
        'delphixpy/v1_9_1/web/about',
        'delphixpy/v1_7_0',
        'delphixpy/v1_7_0/web',
        'delphixpy/v1_7_0/web/environment',
        'delphixpy/v1_7_0/web/environment/oracle',
        'delphixpy/v1_7_0/web/environment/oracle/clusternode',
        'delphixpy/v1_7_0/web/environment/oracle/listener',
        'delphixpy/v1_7_0/web/environment/user',
        'delphixpy/v1_7_0/web/environment/windows',
        'delphixpy/v1_7_0/web/environment/windows/clusternode',
        'delphixpy/v1_7_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_7_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_7_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_7_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_7_0/web/timezone',
        'delphixpy/v1_7_0/web/domain',
        'delphixpy/v1_7_0/web/connectivity',
        'delphixpy/v1_7_0/web/replication',
        'delphixpy/v1_7_0/web/replication/sourcestate',
        'delphixpy/v1_7_0/web/replication/targetstate',
        'delphixpy/v1_7_0/web/replication/spec',
        'delphixpy/v1_7_0/web/replication/serializationpoint',
        'delphixpy/v1_7_0/web/registration',
        'delphixpy/v1_7_0/web/registration/status',
        'delphixpy/v1_7_0/web/fault',
        'delphixpy/v1_7_0/web/fault/effect',
        'delphixpy/v1_7_0/web/network',
        'delphixpy/v1_7_0/web/network/interface',
        'delphixpy/v1_7_0/web/network/route',
        'delphixpy/v1_7_0/web/network/test',
        'delphixpy/v1_7_0/web/network/test/latency',
        'delphixpy/v1_7_0/web/network/test/throughput',
        'delphixpy/v1_7_0/web/network/test/dsp',
        'delphixpy/v1_7_0/web/transformation',
        'delphixpy/v1_7_0/web/database',
        'delphixpy/v1_7_0/web/database/template',
        'delphixpy/v1_7_0/web/user',
        'delphixpy/v1_7_0/web/delphix',
        'delphixpy/v1_7_0/web/host',
        'delphixpy/v1_7_0/web/host/privilegeElevation',
        'delphixpy/v1_7_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_7_0/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_7_0/web/system',
        'delphixpy/v1_7_0/web/system/version',
        'delphixpy/v1_7_0/web/capacity',
        'delphixpy/v1_7_0/web/capacity/consumer',
        'delphixpy/v1_7_0/web/capacity/consumer/historical',
        'delphixpy/v1_7_0/web/capacity/system',
        'delphixpy/v1_7_0/web/capacity/system/historical',
        'delphixpy/v1_7_0/web/capacity/group',
        'delphixpy/v1_7_0/web/capacity/group/historical',
        'delphixpy/v1_7_0/web/capacity/snapshot',
        'delphixpy/v1_7_0/web/action',
        'delphixpy/v1_7_0/web/analytics',
        'delphixpy/v1_7_0/web/analytics/statistic',
        'delphixpy/v1_7_0/web/group',
        'delphixpy/v1_7_0/web/permission',
        'delphixpy/v1_7_0/web/notification',
        'delphixpy/v1_7_0/web/policy',
        'delphixpy/v1_7_0/web/session',
        'delphixpy/v1_7_0/web/timeflow',
        'delphixpy/v1_7_0/web/timeflow/oracle',
        'delphixpy/v1_7_0/web/timeflow/oracle/log',
        'delphixpy/v1_7_0/web/timeflow/bookmark',
        'delphixpy/v1_7_0/web/maskingjob',
        'delphixpy/v1_7_0/web/maskingjob/serviceconfig',
        'delphixpy/v1_7_0/web/objects',
        'delphixpy/v1_7_0/web/authorization',
        'delphixpy/v1_7_0/web/role',
        'delphixpy/v1_7_0/web/toolkit',
        'delphixpy/v1_7_0/web/jetstream',
        'delphixpy/v1_7_0/web/jetstream/datasource',
        'delphixpy/v1_7_0/web/jetstream/template',
        'delphixpy/v1_7_0/web/jetstream/branch',
        'delphixpy/v1_7_0/web/jetstream/usagedata',
        'delphixpy/v1_7_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_7_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_7_0/web/jetstream/operation',
        'delphixpy/v1_7_0/web/jetstream/usage',
        'delphixpy/v1_7_0/web/jetstream/usage/template',
        'delphixpy/v1_7_0/web/jetstream/usage/branch',
        'delphixpy/v1_7_0/web/jetstream/usage/user',
        'delphixpy/v1_7_0/web/jetstream/usage/container',
        'delphixpy/v1_7_0/web/jetstream/usage/bookmark',
        'delphixpy/v1_7_0/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_7_0/web/jetstream/container',
        'delphixpy/v1_7_0/web/jetstream/bookmark',
        'delphixpy/v1_7_0/web/service',
        'delphixpy/v1_7_0/web/service/smtp',
        'delphixpy/v1_7_0/web/service/time',
        'delphixpy/v1_7_0/web/service/certificate',
        'delphixpy/v1_7_0/web/service/ldap',
        'delphixpy/v1_7_0/web/service/ldap/server',
        'delphixpy/v1_7_0/web/service/linkingsettings',
        'delphixpy/v1_7_0/web/service/phonehome',
        'delphixpy/v1_7_0/web/service/dns',
        'delphixpy/v1_7_0/web/service/support',
        'delphixpy/v1_7_0/web/service/support/bundle',
        'delphixpy/v1_7_0/web/service/support/access',
        'delphixpy/v1_7_0/web/service/security',
        'delphixpy/v1_7_0/web/service/locale',
        'delphixpy/v1_7_0/web/service/schema',
        'delphixpy/v1_7_0/web/service/syslog',
        'delphixpy/v1_7_0/web/service/snmp',
        'delphixpy/v1_7_0/web/service/snmp/manager',
        'delphixpy/v1_7_0/web/service/proxy',
        'delphixpy/v1_7_0/web/repository',
        'delphixpy/v1_7_0/web/repository/template',
        'delphixpy/v1_7_0/web/data',
        'delphixpy/v1_7_0/web/snapshot',
        'delphixpy/v1_7_0/web/alert',
        'delphixpy/v1_7_0/web/alert/profile',
        'delphixpy/v1_7_0/web/storage',
        'delphixpy/v1_7_0/web/storage/device',
        'delphixpy/v1_7_0/web/storage/scrub',
        'delphixpy/v1_7_0/web/storage/remove',
        'delphixpy/v1_7_0/web/storage/test',
        'delphixpy/v1_7_0/web/job',
        'delphixpy/v1_7_0/web/source',
        'delphixpy/v1_7_0/web/source/operationTemplate',
        'delphixpy/v1_7_0/web/sourceconfig',
        'delphixpy/v1_7_0/web/sourceconfig/oracle',
        'delphixpy/v1_7_0/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_7_0/web/namespace',
        'delphixpy/v1_7_0/web/about',
        'delphixpy/v1_10_0',
        'delphixpy/v1_10_0/web',
        'delphixpy/v1_10_0/web/environment',
        'delphixpy/v1_10_0/web/environment/oracle',
        'delphixpy/v1_10_0/web/environment/oracle/clusternode',
        'delphixpy/v1_10_0/web/environment/oracle/listener',
        'delphixpy/v1_10_0/web/environment/user',
        'delphixpy/v1_10_0/web/environment/windows',
        'delphixpy/v1_10_0/web/environment/windows/clusternode',
        'delphixpy/v1_10_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_0/web/timezone',
        'delphixpy/v1_10_0/web/domain',
        'delphixpy/v1_10_0/web/connectivity',
        'delphixpy/v1_10_0/web/replication',
        'delphixpy/v1_10_0/web/replication/sourcestate',
        'delphixpy/v1_10_0/web/replication/targetstate',
        'delphixpy/v1_10_0/web/replication/spec',
        'delphixpy/v1_10_0/web/replication/serializationpoint',
        'delphixpy/v1_10_0/web/registration',
        'delphixpy/v1_10_0/web/registration/status',
        'delphixpy/v1_10_0/web/fault',
        'delphixpy/v1_10_0/web/fault/effect',
        'delphixpy/v1_10_0/web/network',
        'delphixpy/v1_10_0/web/network/interface',
        'delphixpy/v1_10_0/web/network/route',
        'delphixpy/v1_10_0/web/network/test',
        'delphixpy/v1_10_0/web/network/test/latency',
        'delphixpy/v1_10_0/web/network/test/throughput',
        'delphixpy/v1_10_0/web/network/test/dsp',
        'delphixpy/v1_10_0/web/network/dsp',
        'delphixpy/v1_10_0/web/network/dsp/autotune',
        'delphixpy/v1_10_0/web/transformation',
        'delphixpy/v1_10_0/web/database',
        'delphixpy/v1_10_0/web/database/template',
        'delphixpy/v1_10_0/web/database/performanceHistory',
        'delphixpy/v1_10_0/web/user',
        'delphixpy/v1_10_0/web/delphix',
        'delphixpy/v1_10_0/web/host',
        'delphixpy/v1_10_0/web/host/privilegeElevation',
        'delphixpy/v1_10_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_0/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_0/web/system',
        'delphixpy/v1_10_0/web/system/package',
        'delphixpy/v1_10_0/web/system/version',
        'delphixpy/v1_10_0/web/system/upgradeCheckResult',
        'delphixpy/v1_10_0/web/capacity',
        'delphixpy/v1_10_0/web/capacity/consumer',
        'delphixpy/v1_10_0/web/capacity/consumer/historical',
        'delphixpy/v1_10_0/web/capacity/system',
        'delphixpy/v1_10_0/web/capacity/system/historical',
        'delphixpy/v1_10_0/web/capacity/group',
        'delphixpy/v1_10_0/web/capacity/group/historical',
        'delphixpy/v1_10_0/web/capacity/snapshot',
        'delphixpy/v1_10_0/web/action',
        'delphixpy/v1_10_0/web/analytics',
        'delphixpy/v1_10_0/web/analytics/statistic',
        'delphixpy/v1_10_0/web/group',
        'delphixpy/v1_10_0/web/passwordPolicy',
        'delphixpy/v1_10_0/web/permission',
        'delphixpy/v1_10_0/web/notification',
        'delphixpy/v1_10_0/web/policy',
        'delphixpy/v1_10_0/web/session',
        'delphixpy/v1_10_0/web/selfservice',
        'delphixpy/v1_10_0/web/selfservice/datasource',
        'delphixpy/v1_10_0/web/selfservice/template',
        'delphixpy/v1_10_0/web/selfservice/branch',
        'delphixpy/v1_10_0/web/selfservice/usagedata',
        'delphixpy/v1_10_0/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_0/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_0/web/selfservice/config',
        'delphixpy/v1_10_0/web/selfservice/operation',
        'delphixpy/v1_10_0/web/selfservice/usage',
        'delphixpy/v1_10_0/web/selfservice/usage/template',
        'delphixpy/v1_10_0/web/selfservice/usage/branch',
        'delphixpy/v1_10_0/web/selfservice/usage/user',
        'delphixpy/v1_10_0/web/selfservice/usage/container',
        'delphixpy/v1_10_0/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_0/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_0/web/selfservice/container',
        'delphixpy/v1_10_0/web/selfservice/bookmark',
        'delphixpy/v1_10_0/web/timeflow',
        'delphixpy/v1_10_0/web/timeflow/oracle',
        'delphixpy/v1_10_0/web/timeflow/oracle/log',
        'delphixpy/v1_10_0/web/timeflow/bookmark',
        'delphixpy/v1_10_0/web/maskingjob',
        'delphixpy/v1_10_0/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_0/web/objects',
        'delphixpy/v1_10_0/web/authorization',
        'delphixpy/v1_10_0/web/authorization/configuration',
        'delphixpy/v1_10_0/web/role',
        'delphixpy/v1_10_0/web/toolkit',
        'delphixpy/v1_10_0/web/service',
        'delphixpy/v1_10_0/web/service/saml',
        'delphixpy/v1_10_0/web/service/saml/serviceprovider',
        'delphixpy/v1_10_0/web/service/smtp',
        'delphixpy/v1_10_0/web/service/httpConnector',
        'delphixpy/v1_10_0/web/service/time',
        'delphixpy/v1_10_0/web/service/certificate',
        'delphixpy/v1_10_0/web/service/ldap',
        'delphixpy/v1_10_0/web/service/ldap/server',
        'delphixpy/v1_10_0/web/service/linkingsettings',
        'delphixpy/v1_10_0/web/service/phonehome',
        'delphixpy/v1_10_0/web/service/dns',
        'delphixpy/v1_10_0/web/service/support',
        'delphixpy/v1_10_0/web/service/support/bundle',
        'delphixpy/v1_10_0/web/service/support/access',
        'delphixpy/v1_10_0/web/service/security',
        'delphixpy/v1_10_0/web/service/userInterface',
        'delphixpy/v1_10_0/web/service/locale',
        'delphixpy/v1_10_0/web/service/schema',
        'delphixpy/v1_10_0/web/service/insight',
        'delphixpy/v1_10_0/web/service/insight/splunkHec',
        'delphixpy/v1_10_0/web/service/syslog',
        'delphixpy/v1_10_0/web/service/snmp',
        'delphixpy/v1_10_0/web/service/snmp/manager',
        'delphixpy/v1_10_0/web/service/proxy',
        'delphixpy/v1_10_0/web/service/tls',
        'delphixpy/v1_10_0/web/service/tls/caCertificate',
        'delphixpy/v1_10_0/web/service/tls/csr',
        'delphixpy/v1_10_0/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_0/web/service/kerberos',
        'delphixpy/v1_10_0/web/repository',
        'delphixpy/v1_10_0/web/repository/template',
        'delphixpy/v1_10_0/web/data',
        'delphixpy/v1_10_0/web/snapshot',
        'delphixpy/v1_10_0/web/alert',
        'delphixpy/v1_10_0/web/alert/profile',
        'delphixpy/v1_10_0/web/storage',
        'delphixpy/v1_10_0/web/storage/device',
        'delphixpy/v1_10_0/web/storage/scrub',
        'delphixpy/v1_10_0/web/storage/remove',
        'delphixpy/v1_10_0/web/storage/test',
        'delphixpy/v1_10_0/web/job',
        'delphixpy/v1_10_0/web/source',
        'delphixpy/v1_10_0/web/source/operationTemplate',
        'delphixpy/v1_10_0/web/sourceconfig',
        'delphixpy/v1_10_0/web/namespace',
        'delphixpy/v1_10_0/web/about',
        'delphixpy/v1_5_3',
        'delphixpy/v1_5_3/web',
        'delphixpy/v1_5_3/web/environment',
        'delphixpy/v1_5_3/web/environment/oracle',
        'delphixpy/v1_5_3/web/environment/oracle/clusternode',
        'delphixpy/v1_5_3/web/environment/oracle/listener',
        'delphixpy/v1_5_3/web/environment/user',
        'delphixpy/v1_5_3/web/environment/windows',
        'delphixpy/v1_5_3/web/environment/windows/clusternode',
        'delphixpy/v1_5_3/web/environment/windows/clusterinstance',
        'delphixpy/v1_5_3/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_5_3/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_5_3/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_5_3/web/domain',
        'delphixpy/v1_5_3/web/connectivity',
        'delphixpy/v1_5_3/web/replication',
        'delphixpy/v1_5_3/web/replication/sourcestate',
        'delphixpy/v1_5_3/web/replication/targetstate',
        'delphixpy/v1_5_3/web/replication/spec',
        'delphixpy/v1_5_3/web/replication/serializationpoint',
        'delphixpy/v1_5_3/web/registration',
        'delphixpy/v1_5_3/web/registration/status',
        'delphixpy/v1_5_3/web/fault',
        'delphixpy/v1_5_3/web/fault/effect',
        'delphixpy/v1_5_3/web/network',
        'delphixpy/v1_5_3/web/network/interface',
        'delphixpy/v1_5_3/web/network/route',
        'delphixpy/v1_5_3/web/network/test',
        'delphixpy/v1_5_3/web/network/test/latency',
        'delphixpy/v1_5_3/web/network/test/throughput',
        'delphixpy/v1_5_3/web/network/test/dsp',
        'delphixpy/v1_5_3/web/database',
        'delphixpy/v1_5_3/web/database/template',
        'delphixpy/v1_5_3/web/user',
        'delphixpy/v1_5_3/web/delphix',
        'delphixpy/v1_5_3/web/host',
        'delphixpy/v1_5_3/web/host/privilegeElevation',
        'delphixpy/v1_5_3/web/host/privilegeElevation/profile',
        'delphixpy/v1_5_3/web/system',
        'delphixpy/v1_5_3/web/system/version',
        'delphixpy/v1_5_3/web/capacity',
        'delphixpy/v1_5_3/web/capacity/consumer',
        'delphixpy/v1_5_3/web/capacity/consumer/historical',
        'delphixpy/v1_5_3/web/capacity/system',
        'delphixpy/v1_5_3/web/capacity/system/historical',
        'delphixpy/v1_5_3/web/capacity/group',
        'delphixpy/v1_5_3/web/capacity/group/historical',
        'delphixpy/v1_5_3/web/capacity/snapshot',
        'delphixpy/v1_5_3/web/action',
        'delphixpy/v1_5_3/web/analytics',
        'delphixpy/v1_5_3/web/analytics/statistic',
        'delphixpy/v1_5_3/web/group',
        'delphixpy/v1_5_3/web/permission',
        'delphixpy/v1_5_3/web/notification',
        'delphixpy/v1_5_3/web/policy',
        'delphixpy/v1_5_3/web/session',
        'delphixpy/v1_5_3/web/timeflow',
        'delphixpy/v1_5_3/web/timeflow/oracle',
        'delphixpy/v1_5_3/web/timeflow/oracle/log',
        'delphixpy/v1_5_3/web/timeflow/bookmark',
        'delphixpy/v1_5_3/web/objects',
        'delphixpy/v1_5_3/web/authorization',
        'delphixpy/v1_5_3/web/role',
        'delphixpy/v1_5_3/web/toolkit',
        'delphixpy/v1_5_3/web/jetstream',
        'delphixpy/v1_5_3/web/jetstream/datasource',
        'delphixpy/v1_5_3/web/jetstream/template',
        'delphixpy/v1_5_3/web/jetstream/branch',
        'delphixpy/v1_5_3/web/jetstream/usagedata',
        'delphixpy/v1_5_3/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_5_3/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_5_3/web/jetstream/operation',
        'delphixpy/v1_5_3/web/jetstream/usage',
        'delphixpy/v1_5_3/web/jetstream/usage/template',
        'delphixpy/v1_5_3/web/jetstream/usage/branch',
        'delphixpy/v1_5_3/web/jetstream/usage/user',
        'delphixpy/v1_5_3/web/jetstream/usage/container',
        'delphixpy/v1_5_3/web/jetstream/usage/bookmark',
        'delphixpy/v1_5_3/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_5_3/web/jetstream/container',
        'delphixpy/v1_5_3/web/jetstream/bookmark',
        'delphixpy/v1_5_3/web/service',
        'delphixpy/v1_5_3/web/service/smtp',
        'delphixpy/v1_5_3/web/service/time',
        'delphixpy/v1_5_3/web/service/certificate',
        'delphixpy/v1_5_3/web/service/ldap',
        'delphixpy/v1_5_3/web/service/ldap/server',
        'delphixpy/v1_5_3/web/service/linkingsettings',
        'delphixpy/v1_5_3/web/service/phonehome',
        'delphixpy/v1_5_3/web/service/dns',
        'delphixpy/v1_5_3/web/service/support',
        'delphixpy/v1_5_3/web/service/support/bundle',
        'delphixpy/v1_5_3/web/service/support/access',
        'delphixpy/v1_5_3/web/service/security',
        'delphixpy/v1_5_3/web/service/locale',
        'delphixpy/v1_5_3/web/service/schema',
        'delphixpy/v1_5_3/web/service/syslog',
        'delphixpy/v1_5_3/web/service/snmp',
        'delphixpy/v1_5_3/web/service/snmp/manager',
        'delphixpy/v1_5_3/web/service/proxy',
        'delphixpy/v1_5_3/web/repository',
        'delphixpy/v1_5_3/web/repository/template',
        'delphixpy/v1_5_3/web/data',
        'delphixpy/v1_5_3/web/snapshot',
        'delphixpy/v1_5_3/web/alert',
        'delphixpy/v1_5_3/web/alert/profile',
        'delphixpy/v1_5_3/web/storage',
        'delphixpy/v1_5_3/web/storage/device',
        'delphixpy/v1_5_3/web/storage/scrub',
        'delphixpy/v1_5_3/web/storage/remove',
        'delphixpy/v1_5_3/web/storage/test',
        'delphixpy/v1_5_3/web/job',
        'delphixpy/v1_5_3/web/source',
        'delphixpy/v1_5_3/web/source/operationTemplate',
        'delphixpy/v1_5_3/web/sourceconfig',
        'delphixpy/v1_5_3/web/sourceconfig/oracle',
        'delphixpy/v1_5_3/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_5_3/web/namespace',
        'delphixpy/v1_5_3/web/about',
        'delphixpy/v1_11_1',
        'delphixpy/v1_11_1/web',
        'delphixpy/v1_11_1/web/environment',
        'delphixpy/v1_11_1/web/environment/oracle',
        'delphixpy/v1_11_1/web/environment/oracle/clusternode',
        'delphixpy/v1_11_1/web/environment/oracle/listener',
        'delphixpy/v1_11_1/web/environment/user',
        'delphixpy/v1_11_1/web/environment/windows',
        'delphixpy/v1_11_1/web/environment/windows/clusternode',
        'delphixpy/v1_11_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_11_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_11_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_11_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_11_1/web/timezone',
        'delphixpy/v1_11_1/web/theme',
        'delphixpy/v1_11_1/web/domain',
        'delphixpy/v1_11_1/web/connectivity',
        'delphixpy/v1_11_1/web/replication',
        'delphixpy/v1_11_1/web/replication/sourcestate',
        'delphixpy/v1_11_1/web/replication/targetstate',
        'delphixpy/v1_11_1/web/replication/spec',
        'delphixpy/v1_11_1/web/replication/serializationpoint',
        'delphixpy/v1_11_1/web/registration',
        'delphixpy/v1_11_1/web/registration/status',
        'delphixpy/v1_11_1/web/fault',
        'delphixpy/v1_11_1/web/fault/effect',
        'delphixpy/v1_11_1/web/network',
        'delphixpy/v1_11_1/web/network/interface',
        'delphixpy/v1_11_1/web/network/route',
        'delphixpy/v1_11_1/web/network/test',
        'delphixpy/v1_11_1/web/network/test/latency',
        'delphixpy/v1_11_1/web/network/test/throughput',
        'delphixpy/v1_11_1/web/network/test/dsp',
        'delphixpy/v1_11_1/web/network/dsp',
        'delphixpy/v1_11_1/web/network/dsp/autotune',
        'delphixpy/v1_11_1/web/transformation',
        'delphixpy/v1_11_1/web/database',
        'delphixpy/v1_11_1/web/database/template',
        'delphixpy/v1_11_1/web/database/performanceHistory',
        'delphixpy/v1_11_1/web/user',
        'delphixpy/v1_11_1/web/delphix',
        'delphixpy/v1_11_1/web/host',
        'delphixpy/v1_11_1/web/host/privilegeElevation',
        'delphixpy/v1_11_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_11_1/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_11_1/web/usage',
        'delphixpy/v1_11_1/web/system',
        'delphixpy/v1_11_1/web/system/status',
        'delphixpy/v1_11_1/web/system/verification',
        'delphixpy/v1_11_1/web/system/verification/reports',
        'delphixpy/v1_11_1/web/system/verification/reports/steps',
        'delphixpy/v1_11_1/web/system/package',
        'delphixpy/v1_11_1/web/system/version',
        'delphixpy/v1_11_1/web/system/upgradeCheckResult',
        'delphixpy/v1_11_1/web/capacity',
        'delphixpy/v1_11_1/web/capacity/consumer',
        'delphixpy/v1_11_1/web/capacity/consumer/historical',
        'delphixpy/v1_11_1/web/capacity/system',
        'delphixpy/v1_11_1/web/capacity/system/historical',
        'delphixpy/v1_11_1/web/capacity/group',
        'delphixpy/v1_11_1/web/capacity/group/historical',
        'delphixpy/v1_11_1/web/capacity/snapshot',
        'delphixpy/v1_11_1/web/action',
        'delphixpy/v1_11_1/web/analytics',
        'delphixpy/v1_11_1/web/analytics/statistic',
        'delphixpy/v1_11_1/web/group',
        'delphixpy/v1_11_1/web/passwordPolicy',
        'delphixpy/v1_11_1/web/permission',
        'delphixpy/v1_11_1/web/notification',
        'delphixpy/v1_11_1/web/policy',
        'delphixpy/v1_11_1/web/session',
        'delphixpy/v1_11_1/web/selfservice',
        'delphixpy/v1_11_1/web/selfservice/datasource',
        'delphixpy/v1_11_1/web/selfservice/template',
        'delphixpy/v1_11_1/web/selfservice/branch',
        'delphixpy/v1_11_1/web/selfservice/usagedata',
        'delphixpy/v1_11_1/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_11_1/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_11_1/web/selfservice/config',
        'delphixpy/v1_11_1/web/selfservice/operation',
        'delphixpy/v1_11_1/web/selfservice/usage',
        'delphixpy/v1_11_1/web/selfservice/usage/template',
        'delphixpy/v1_11_1/web/selfservice/usage/branch',
        'delphixpy/v1_11_1/web/selfservice/usage/user',
        'delphixpy/v1_11_1/web/selfservice/usage/container',
        'delphixpy/v1_11_1/web/selfservice/usage/bookmark',
        'delphixpy/v1_11_1/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_11_1/web/selfservice/container',
        'delphixpy/v1_11_1/web/selfservice/bookmark',
        'delphixpy/v1_11_1/web/timeflow',
        'delphixpy/v1_11_1/web/timeflow/oracle',
        'delphixpy/v1_11_1/web/timeflow/oracle/log',
        'delphixpy/v1_11_1/web/timeflow/bookmark',
        'delphixpy/v1_11_1/web/maskingjob',
        'delphixpy/v1_11_1/web/maskingjob/serviceconfig',
        'delphixpy/v1_11_1/web/objects',
        'delphixpy/v1_11_1/web/authorization',
        'delphixpy/v1_11_1/web/authorization/configuration',
        'delphixpy/v1_11_1/web/role',
        'delphixpy/v1_11_1/web/toolkit',
        'delphixpy/v1_11_1/web/service',
        'delphixpy/v1_11_1/web/service/saml',
        'delphixpy/v1_11_1/web/service/saml/serviceprovider',
        'delphixpy/v1_11_1/web/service/smtp',
        'delphixpy/v1_11_1/web/service/userPaths',
        'delphixpy/v1_11_1/web/service/minimalPhonehome',
        'delphixpy/v1_11_1/web/service/httpConnector',
        'delphixpy/v1_11_1/web/service/nfs',
        'delphixpy/v1_11_1/web/service/time',
        'delphixpy/v1_11_1/web/service/certificate',
        'delphixpy/v1_11_1/web/service/sso',
        'delphixpy/v1_11_1/web/service/ldap',
        'delphixpy/v1_11_1/web/service/ldap/server',
        'delphixpy/v1_11_1/web/service/linkingsettings',
        'delphixpy/v1_11_1/web/service/phonehome',
        'delphixpy/v1_11_1/web/service/dns',
        'delphixpy/v1_11_1/web/service/support',
        'delphixpy/v1_11_1/web/service/support/bundle',
        'delphixpy/v1_11_1/web/service/support/access',
        'delphixpy/v1_11_1/web/service/security',
        'delphixpy/v1_11_1/web/service/userInterface',
        'delphixpy/v1_11_1/web/service/cloud',
        'delphixpy/v1_11_1/web/service/locale',
        'delphixpy/v1_11_1/web/service/schema',
        'delphixpy/v1_11_1/web/service/insight',
        'delphixpy/v1_11_1/web/service/insight/splunkHec',
        'delphixpy/v1_11_1/web/service/syslog',
        'delphixpy/v1_11_1/web/service/snmp',
        'delphixpy/v1_11_1/web/service/snmp/manager',
        'delphixpy/v1_11_1/web/service/proxy',
        'delphixpy/v1_11_1/web/service/tls',
        'delphixpy/v1_11_1/web/service/tls/caCertificate',
        'delphixpy/v1_11_1/web/service/tls/csr',
        'delphixpy/v1_11_1/web/service/tls/cipherSuite',
        'delphixpy/v1_11_1/web/service/tls/endEntityCertificate',
        'delphixpy/v1_11_1/web/service/kerberos',
        'delphixpy/v1_11_1/web/repository',
        'delphixpy/v1_11_1/web/repository/template',
        'delphixpy/v1_11_1/web/data',
        'delphixpy/v1_11_1/web/snapshot',
        'delphixpy/v1_11_1/web/alert',
        'delphixpy/v1_11_1/web/alert/profile',
        'delphixpy/v1_11_1/web/storage',
        'delphixpy/v1_11_1/web/storage/device',
        'delphixpy/v1_11_1/web/storage/scrub',
        'delphixpy/v1_11_1/web/storage/remove',
        'delphixpy/v1_11_1/web/storage/test',
        'delphixpy/v1_11_1/web/job',
        'delphixpy/v1_11_1/web/source',
        'delphixpy/v1_11_1/web/source/operationTemplate',
        'delphixpy/v1_11_1/web/sourceconfig',
        'delphixpy/v1_11_1/web/namespace',
        'delphixpy/v1_11_1/web/about',
        'delphixpy/v1_8_0',
        'delphixpy/v1_8_0/web',
        'delphixpy/v1_8_0/web/environment',
        'delphixpy/v1_8_0/web/environment/oracle',
        'delphixpy/v1_8_0/web/environment/oracle/clusternode',
        'delphixpy/v1_8_0/web/environment/oracle/listener',
        'delphixpy/v1_8_0/web/environment/user',
        'delphixpy/v1_8_0/web/environment/windows',
        'delphixpy/v1_8_0/web/environment/windows/clusternode',
        'delphixpy/v1_8_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_8_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_8_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_8_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_8_0/web/timezone',
        'delphixpy/v1_8_0/web/domain',
        'delphixpy/v1_8_0/web/connectivity',
        'delphixpy/v1_8_0/web/replication',
        'delphixpy/v1_8_0/web/replication/sourcestate',
        'delphixpy/v1_8_0/web/replication/targetstate',
        'delphixpy/v1_8_0/web/replication/spec',
        'delphixpy/v1_8_0/web/replication/serializationpoint',
        'delphixpy/v1_8_0/web/registration',
        'delphixpy/v1_8_0/web/registration/status',
        'delphixpy/v1_8_0/web/fault',
        'delphixpy/v1_8_0/web/fault/effect',
        'delphixpy/v1_8_0/web/network',
        'delphixpy/v1_8_0/web/network/interface',
        'delphixpy/v1_8_0/web/network/route',
        'delphixpy/v1_8_0/web/network/test',
        'delphixpy/v1_8_0/web/network/test/latency',
        'delphixpy/v1_8_0/web/network/test/throughput',
        'delphixpy/v1_8_0/web/network/test/dsp',
        'delphixpy/v1_8_0/web/transformation',
        'delphixpy/v1_8_0/web/database',
        'delphixpy/v1_8_0/web/database/template',
        'delphixpy/v1_8_0/web/user',
        'delphixpy/v1_8_0/web/delphix',
        'delphixpy/v1_8_0/web/host',
        'delphixpy/v1_8_0/web/host/privilegeElevation',
        'delphixpy/v1_8_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_8_0/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_8_0/web/system',
        'delphixpy/v1_8_0/web/system/version',
        'delphixpy/v1_8_0/web/capacity',
        'delphixpy/v1_8_0/web/capacity/consumer',
        'delphixpy/v1_8_0/web/capacity/consumer/historical',
        'delphixpy/v1_8_0/web/capacity/system',
        'delphixpy/v1_8_0/web/capacity/system/historical',
        'delphixpy/v1_8_0/web/capacity/group',
        'delphixpy/v1_8_0/web/capacity/group/historical',
        'delphixpy/v1_8_0/web/capacity/snapshot',
        'delphixpy/v1_8_0/web/action',
        'delphixpy/v1_8_0/web/analytics',
        'delphixpy/v1_8_0/web/analytics/statistic',
        'delphixpy/v1_8_0/web/group',
        'delphixpy/v1_8_0/web/permission',
        'delphixpy/v1_8_0/web/notification',
        'delphixpy/v1_8_0/web/policy',
        'delphixpy/v1_8_0/web/session',
        'delphixpy/v1_8_0/web/timeflow',
        'delphixpy/v1_8_0/web/timeflow/oracle',
        'delphixpy/v1_8_0/web/timeflow/oracle/log',
        'delphixpy/v1_8_0/web/timeflow/bookmark',
        'delphixpy/v1_8_0/web/maskingjob',
        'delphixpy/v1_8_0/web/maskingjob/serviceconfig',
        'delphixpy/v1_8_0/web/objects',
        'delphixpy/v1_8_0/web/authorization',
        'delphixpy/v1_8_0/web/role',
        'delphixpy/v1_8_0/web/toolkit',
        'delphixpy/v1_8_0/web/jetstream',
        'delphixpy/v1_8_0/web/jetstream/datasource',
        'delphixpy/v1_8_0/web/jetstream/template',
        'delphixpy/v1_8_0/web/jetstream/branch',
        'delphixpy/v1_8_0/web/jetstream/usagedata',
        'delphixpy/v1_8_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_8_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_8_0/web/jetstream/operation',
        'delphixpy/v1_8_0/web/jetstream/usage',
        'delphixpy/v1_8_0/web/jetstream/usage/template',
        'delphixpy/v1_8_0/web/jetstream/usage/branch',
        'delphixpy/v1_8_0/web/jetstream/usage/user',
        'delphixpy/v1_8_0/web/jetstream/usage/container',
        'delphixpy/v1_8_0/web/jetstream/usage/bookmark',
        'delphixpy/v1_8_0/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_8_0/web/jetstream/container',
        'delphixpy/v1_8_0/web/jetstream/bookmark',
        'delphixpy/v1_8_0/web/service',
        'delphixpy/v1_8_0/web/service/saml',
        'delphixpy/v1_8_0/web/service/saml/serviceprovider',
        'delphixpy/v1_8_0/web/service/smtp',
        'delphixpy/v1_8_0/web/service/time',
        'delphixpy/v1_8_0/web/service/certificate',
        'delphixpy/v1_8_0/web/service/ldap',
        'delphixpy/v1_8_0/web/service/ldap/server',
        'delphixpy/v1_8_0/web/service/linkingsettings',
        'delphixpy/v1_8_0/web/service/phonehome',
        'delphixpy/v1_8_0/web/service/dns',
        'delphixpy/v1_8_0/web/service/support',
        'delphixpy/v1_8_0/web/service/support/bundle',
        'delphixpy/v1_8_0/web/service/support/access',
        'delphixpy/v1_8_0/web/service/security',
        'delphixpy/v1_8_0/web/service/locale',
        'delphixpy/v1_8_0/web/service/schema',
        'delphixpy/v1_8_0/web/service/syslog',
        'delphixpy/v1_8_0/web/service/snmp',
        'delphixpy/v1_8_0/web/service/snmp/manager',
        'delphixpy/v1_8_0/web/service/proxy',
        'delphixpy/v1_8_0/web/repository',
        'delphixpy/v1_8_0/web/repository/template',
        'delphixpy/v1_8_0/web/data',
        'delphixpy/v1_8_0/web/snapshot',
        'delphixpy/v1_8_0/web/alert',
        'delphixpy/v1_8_0/web/alert/profile',
        'delphixpy/v1_8_0/web/storage',
        'delphixpy/v1_8_0/web/storage/device',
        'delphixpy/v1_8_0/web/storage/scrub',
        'delphixpy/v1_8_0/web/storage/remove',
        'delphixpy/v1_8_0/web/storage/test',
        'delphixpy/v1_8_0/web/job',
        'delphixpy/v1_8_0/web/source',
        'delphixpy/v1_8_0/web/source/operationTemplate',
        'delphixpy/v1_8_0/web/sourceconfig',
        'delphixpy/v1_8_0/web/sourceconfig/oracle',
        'delphixpy/v1_8_0/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_8_0/web/namespace',
        'delphixpy/v1_8_0/web/about',
        'delphixpy/v1_6_1',
        'delphixpy/v1_6_1/web',
        'delphixpy/v1_6_1/web/environment',
        'delphixpy/v1_6_1/web/environment/oracle',
        'delphixpy/v1_6_1/web/environment/oracle/clusternode',
        'delphixpy/v1_6_1/web/environment/oracle/listener',
        'delphixpy/v1_6_1/web/environment/user',
        'delphixpy/v1_6_1/web/environment/windows',
        'delphixpy/v1_6_1/web/environment/windows/clusternode',
        'delphixpy/v1_6_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_6_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_6_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_6_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_6_1/web/domain',
        'delphixpy/v1_6_1/web/connectivity',
        'delphixpy/v1_6_1/web/replication',
        'delphixpy/v1_6_1/web/replication/sourcestate',
        'delphixpy/v1_6_1/web/replication/targetstate',
        'delphixpy/v1_6_1/web/replication/spec',
        'delphixpy/v1_6_1/web/replication/serializationpoint',
        'delphixpy/v1_6_1/web/registration',
        'delphixpy/v1_6_1/web/registration/status',
        'delphixpy/v1_6_1/web/fault',
        'delphixpy/v1_6_1/web/fault/effect',
        'delphixpy/v1_6_1/web/network',
        'delphixpy/v1_6_1/web/network/interface',
        'delphixpy/v1_6_1/web/network/route',
        'delphixpy/v1_6_1/web/network/test',
        'delphixpy/v1_6_1/web/network/test/latency',
        'delphixpy/v1_6_1/web/network/test/throughput',
        'delphixpy/v1_6_1/web/network/test/dsp',
        'delphixpy/v1_6_1/web/database',
        'delphixpy/v1_6_1/web/database/template',
        'delphixpy/v1_6_1/web/user',
        'delphixpy/v1_6_1/web/delphix',
        'delphixpy/v1_6_1/web/host',
        'delphixpy/v1_6_1/web/host/privilegeElevation',
        'delphixpy/v1_6_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_6_1/web/system',
        'delphixpy/v1_6_1/web/system/version',
        'delphixpy/v1_6_1/web/capacity',
        'delphixpy/v1_6_1/web/capacity/consumer',
        'delphixpy/v1_6_1/web/capacity/consumer/historical',
        'delphixpy/v1_6_1/web/capacity/system',
        'delphixpy/v1_6_1/web/capacity/system/historical',
        'delphixpy/v1_6_1/web/capacity/group',
        'delphixpy/v1_6_1/web/capacity/group/historical',
        'delphixpy/v1_6_1/web/capacity/snapshot',
        'delphixpy/v1_6_1/web/action',
        'delphixpy/v1_6_1/web/analytics',
        'delphixpy/v1_6_1/web/analytics/statistic',
        'delphixpy/v1_6_1/web/group',
        'delphixpy/v1_6_1/web/permission',
        'delphixpy/v1_6_1/web/notification',
        'delphixpy/v1_6_1/web/policy',
        'delphixpy/v1_6_1/web/session',
        'delphixpy/v1_6_1/web/timeflow',
        'delphixpy/v1_6_1/web/timeflow/oracle',
        'delphixpy/v1_6_1/web/timeflow/oracle/log',
        'delphixpy/v1_6_1/web/timeflow/bookmark',
        'delphixpy/v1_6_1/web/objects',
        'delphixpy/v1_6_1/web/authorization',
        'delphixpy/v1_6_1/web/role',
        'delphixpy/v1_6_1/web/toolkit',
        'delphixpy/v1_6_1/web/jetstream',
        'delphixpy/v1_6_1/web/jetstream/datasource',
        'delphixpy/v1_6_1/web/jetstream/template',
        'delphixpy/v1_6_1/web/jetstream/branch',
        'delphixpy/v1_6_1/web/jetstream/usagedata',
        'delphixpy/v1_6_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_6_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_6_1/web/jetstream/operation',
        'delphixpy/v1_6_1/web/jetstream/usage',
        'delphixpy/v1_6_1/web/jetstream/usage/template',
        'delphixpy/v1_6_1/web/jetstream/usage/branch',
        'delphixpy/v1_6_1/web/jetstream/usage/user',
        'delphixpy/v1_6_1/web/jetstream/usage/container',
        'delphixpy/v1_6_1/web/jetstream/usage/bookmark',
        'delphixpy/v1_6_1/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_6_1/web/jetstream/container',
        'delphixpy/v1_6_1/web/jetstream/bookmark',
        'delphixpy/v1_6_1/web/service',
        'delphixpy/v1_6_1/web/service/smtp',
        'delphixpy/v1_6_1/web/service/time',
        'delphixpy/v1_6_1/web/service/certificate',
        'delphixpy/v1_6_1/web/service/ldap',
        'delphixpy/v1_6_1/web/service/ldap/server',
        'delphixpy/v1_6_1/web/service/linkingsettings',
        'delphixpy/v1_6_1/web/service/phonehome',
        'delphixpy/v1_6_1/web/service/dns',
        'delphixpy/v1_6_1/web/service/support',
        'delphixpy/v1_6_1/web/service/support/bundle',
        'delphixpy/v1_6_1/web/service/support/access',
        'delphixpy/v1_6_1/web/service/security',
        'delphixpy/v1_6_1/web/service/locale',
        'delphixpy/v1_6_1/web/service/schema',
        'delphixpy/v1_6_1/web/service/syslog',
        'delphixpy/v1_6_1/web/service/snmp',
        'delphixpy/v1_6_1/web/service/snmp/manager',
        'delphixpy/v1_6_1/web/service/proxy',
        'delphixpy/v1_6_1/web/repository',
        'delphixpy/v1_6_1/web/repository/template',
        'delphixpy/v1_6_1/web/data',
        'delphixpy/v1_6_1/web/snapshot',
        'delphixpy/v1_6_1/web/alert',
        'delphixpy/v1_6_1/web/alert/profile',
        'delphixpy/v1_6_1/web/storage',
        'delphixpy/v1_6_1/web/storage/device',
        'delphixpy/v1_6_1/web/storage/scrub',
        'delphixpy/v1_6_1/web/storage/remove',
        'delphixpy/v1_6_1/web/storage/test',
        'delphixpy/v1_6_1/web/job',
        'delphixpy/v1_6_1/web/source',
        'delphixpy/v1_6_1/web/source/operationTemplate',
        'delphixpy/v1_6_1/web/sourceconfig',
        'delphixpy/v1_6_1/web/sourceconfig/oracle',
        'delphixpy/v1_6_1/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_6_1/web/namespace',
        'delphixpy/v1_6_1/web/about',
        'delphixpy/v1_5_1',
        'delphixpy/v1_5_1/web',
        'delphixpy/v1_5_1/web/environment',
        'delphixpy/v1_5_1/web/environment/oracle',
        'delphixpy/v1_5_1/web/environment/oracle/clusternode',
        'delphixpy/v1_5_1/web/environment/oracle/listener',
        'delphixpy/v1_5_1/web/environment/user',
        'delphixpy/v1_5_1/web/environment/windows',
        'delphixpy/v1_5_1/web/environment/windows/clusternode',
        'delphixpy/v1_5_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_5_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_5_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_5_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_5_1/web/domain',
        'delphixpy/v1_5_1/web/connectivity',
        'delphixpy/v1_5_1/web/replication',
        'delphixpy/v1_5_1/web/replication/sourcestate',
        'delphixpy/v1_5_1/web/replication/targetstate',
        'delphixpy/v1_5_1/web/replication/spec',
        'delphixpy/v1_5_1/web/replication/serializationpoint',
        'delphixpy/v1_5_1/web/registration',
        'delphixpy/v1_5_1/web/registration/status',
        'delphixpy/v1_5_1/web/fault',
        'delphixpy/v1_5_1/web/fault/effect',
        'delphixpy/v1_5_1/web/network',
        'delphixpy/v1_5_1/web/network/interface',
        'delphixpy/v1_5_1/web/network/route',
        'delphixpy/v1_5_1/web/network/test',
        'delphixpy/v1_5_1/web/network/test/latency',
        'delphixpy/v1_5_1/web/network/test/throughput',
        'delphixpy/v1_5_1/web/network/test/dsp',
        'delphixpy/v1_5_1/web/database',
        'delphixpy/v1_5_1/web/database/template',
        'delphixpy/v1_5_1/web/user',
        'delphixpy/v1_5_1/web/delphix',
        'delphixpy/v1_5_1/web/host',
        'delphixpy/v1_5_1/web/host/privilegeElevation',
        'delphixpy/v1_5_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_5_1/web/system',
        'delphixpy/v1_5_1/web/system/version',
        'delphixpy/v1_5_1/web/capacity',
        'delphixpy/v1_5_1/web/capacity/consumer',
        'delphixpy/v1_5_1/web/capacity/consumer/historical',
        'delphixpy/v1_5_1/web/capacity/system',
        'delphixpy/v1_5_1/web/capacity/system/historical',
        'delphixpy/v1_5_1/web/capacity/group',
        'delphixpy/v1_5_1/web/capacity/group/historical',
        'delphixpy/v1_5_1/web/capacity/snapshot',
        'delphixpy/v1_5_1/web/action',
        'delphixpy/v1_5_1/web/analytics',
        'delphixpy/v1_5_1/web/analytics/statistic',
        'delphixpy/v1_5_1/web/group',
        'delphixpy/v1_5_1/web/permission',
        'delphixpy/v1_5_1/web/notification',
        'delphixpy/v1_5_1/web/policy',
        'delphixpy/v1_5_1/web/session',
        'delphixpy/v1_5_1/web/timeflow',
        'delphixpy/v1_5_1/web/timeflow/oracle',
        'delphixpy/v1_5_1/web/timeflow/oracle/log',
        'delphixpy/v1_5_1/web/timeflow/bookmark',
        'delphixpy/v1_5_1/web/objects',
        'delphixpy/v1_5_1/web/authorization',
        'delphixpy/v1_5_1/web/role',
        'delphixpy/v1_5_1/web/toolkit',
        'delphixpy/v1_5_1/web/jetstream',
        'delphixpy/v1_5_1/web/jetstream/datasource',
        'delphixpy/v1_5_1/web/jetstream/template',
        'delphixpy/v1_5_1/web/jetstream/branch',
        'delphixpy/v1_5_1/web/jetstream/usagedata',
        'delphixpy/v1_5_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_5_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_5_1/web/jetstream/operation',
        'delphixpy/v1_5_1/web/jetstream/usage',
        'delphixpy/v1_5_1/web/jetstream/usage/template',
        'delphixpy/v1_5_1/web/jetstream/usage/branch',
        'delphixpy/v1_5_1/web/jetstream/usage/user',
        'delphixpy/v1_5_1/web/jetstream/usage/container',
        'delphixpy/v1_5_1/web/jetstream/usage/bookmark',
        'delphixpy/v1_5_1/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_5_1/web/jetstream/container',
        'delphixpy/v1_5_1/web/jetstream/bookmark',
        'delphixpy/v1_5_1/web/service',
        'delphixpy/v1_5_1/web/service/smtp',
        'delphixpy/v1_5_1/web/service/time',
        'delphixpy/v1_5_1/web/service/certificate',
        'delphixpy/v1_5_1/web/service/ldap',
        'delphixpy/v1_5_1/web/service/ldap/server',
        'delphixpy/v1_5_1/web/service/linkingsettings',
        'delphixpy/v1_5_1/web/service/phonehome',
        'delphixpy/v1_5_1/web/service/dns',
        'delphixpy/v1_5_1/web/service/support',
        'delphixpy/v1_5_1/web/service/support/bundle',
        'delphixpy/v1_5_1/web/service/support/access',
        'delphixpy/v1_5_1/web/service/security',
        'delphixpy/v1_5_1/web/service/locale',
        'delphixpy/v1_5_1/web/service/schema',
        'delphixpy/v1_5_1/web/service/syslog',
        'delphixpy/v1_5_1/web/service/snmp',
        'delphixpy/v1_5_1/web/service/snmp/manager',
        'delphixpy/v1_5_1/web/service/proxy',
        'delphixpy/v1_5_1/web/repository',
        'delphixpy/v1_5_1/web/repository/template',
        'delphixpy/v1_5_1/web/data',
        'delphixpy/v1_5_1/web/snapshot',
        'delphixpy/v1_5_1/web/alert',
        'delphixpy/v1_5_1/web/alert/profile',
        'delphixpy/v1_5_1/web/storage',
        'delphixpy/v1_5_1/web/storage/device',
        'delphixpy/v1_5_1/web/storage/scrub',
        'delphixpy/v1_5_1/web/storage/test',
        'delphixpy/v1_5_1/web/job',
        'delphixpy/v1_5_1/web/source',
        'delphixpy/v1_5_1/web/source/operationTemplate',
        'delphixpy/v1_5_1/web/sourceconfig',
        'delphixpy/v1_5_1/web/sourceconfig/oracle',
        'delphixpy/v1_5_1/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_5_1/web/namespace',
        'delphixpy/v1_5_1/web/about',
        'delphixpy/v1_8_1',
        'delphixpy/v1_8_1/web',
        'delphixpy/v1_8_1/web/environment',
        'delphixpy/v1_8_1/web/environment/oracle',
        'delphixpy/v1_8_1/web/environment/oracle/clusternode',
        'delphixpy/v1_8_1/web/environment/oracle/listener',
        'delphixpy/v1_8_1/web/environment/user',
        'delphixpy/v1_8_1/web/environment/windows',
        'delphixpy/v1_8_1/web/environment/windows/clusternode',
        'delphixpy/v1_8_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_8_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_8_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_8_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_8_1/web/timezone',
        'delphixpy/v1_8_1/web/domain',
        'delphixpy/v1_8_1/web/connectivity',
        'delphixpy/v1_8_1/web/replication',
        'delphixpy/v1_8_1/web/replication/sourcestate',
        'delphixpy/v1_8_1/web/replication/targetstate',
        'delphixpy/v1_8_1/web/replication/spec',
        'delphixpy/v1_8_1/web/replication/serializationpoint',
        'delphixpy/v1_8_1/web/registration',
        'delphixpy/v1_8_1/web/registration/status',
        'delphixpy/v1_8_1/web/fault',
        'delphixpy/v1_8_1/web/fault/effect',
        'delphixpy/v1_8_1/web/network',
        'delphixpy/v1_8_1/web/network/interface',
        'delphixpy/v1_8_1/web/network/route',
        'delphixpy/v1_8_1/web/network/test',
        'delphixpy/v1_8_1/web/network/test/latency',
        'delphixpy/v1_8_1/web/network/test/throughput',
        'delphixpy/v1_8_1/web/network/test/dsp',
        'delphixpy/v1_8_1/web/transformation',
        'delphixpy/v1_8_1/web/database',
        'delphixpy/v1_8_1/web/database/template',
        'delphixpy/v1_8_1/web/user',
        'delphixpy/v1_8_1/web/delphix',
        'delphixpy/v1_8_1/web/host',
        'delphixpy/v1_8_1/web/host/privilegeElevation',
        'delphixpy/v1_8_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_8_1/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_8_1/web/system',
        'delphixpy/v1_8_1/web/system/version',
        'delphixpy/v1_8_1/web/capacity',
        'delphixpy/v1_8_1/web/capacity/consumer',
        'delphixpy/v1_8_1/web/capacity/consumer/historical',
        'delphixpy/v1_8_1/web/capacity/system',
        'delphixpy/v1_8_1/web/capacity/system/historical',
        'delphixpy/v1_8_1/web/capacity/group',
        'delphixpy/v1_8_1/web/capacity/group/historical',
        'delphixpy/v1_8_1/web/capacity/snapshot',
        'delphixpy/v1_8_1/web/action',
        'delphixpy/v1_8_1/web/analytics',
        'delphixpy/v1_8_1/web/analytics/statistic',
        'delphixpy/v1_8_1/web/group',
        'delphixpy/v1_8_1/web/permission',
        'delphixpy/v1_8_1/web/notification',
        'delphixpy/v1_8_1/web/policy',
        'delphixpy/v1_8_1/web/session',
        'delphixpy/v1_8_1/web/timeflow',
        'delphixpy/v1_8_1/web/timeflow/oracle',
        'delphixpy/v1_8_1/web/timeflow/oracle/log',
        'delphixpy/v1_8_1/web/timeflow/bookmark',
        'delphixpy/v1_8_1/web/maskingjob',
        'delphixpy/v1_8_1/web/maskingjob/serviceconfig',
        'delphixpy/v1_8_1/web/objects',
        'delphixpy/v1_8_1/web/authorization',
        'delphixpy/v1_8_1/web/role',
        'delphixpy/v1_8_1/web/toolkit',
        'delphixpy/v1_8_1/web/jetstream',
        'delphixpy/v1_8_1/web/jetstream/datasource',
        'delphixpy/v1_8_1/web/jetstream/template',
        'delphixpy/v1_8_1/web/jetstream/branch',
        'delphixpy/v1_8_1/web/jetstream/usagedata',
        'delphixpy/v1_8_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_8_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_8_1/web/jetstream/operation',
        'delphixpy/v1_8_1/web/jetstream/usage',
        'delphixpy/v1_8_1/web/jetstream/usage/template',
        'delphixpy/v1_8_1/web/jetstream/usage/branch',
        'delphixpy/v1_8_1/web/jetstream/usage/user',
        'delphixpy/v1_8_1/web/jetstream/usage/container',
        'delphixpy/v1_8_1/web/jetstream/usage/bookmark',
        'delphixpy/v1_8_1/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_8_1/web/jetstream/container',
        'delphixpy/v1_8_1/web/jetstream/bookmark',
        'delphixpy/v1_8_1/web/service',
        'delphixpy/v1_8_1/web/service/saml',
        'delphixpy/v1_8_1/web/service/saml/serviceprovider',
        'delphixpy/v1_8_1/web/service/smtp',
        'delphixpy/v1_8_1/web/service/time',
        'delphixpy/v1_8_1/web/service/certificate',
        'delphixpy/v1_8_1/web/service/ldap',
        'delphixpy/v1_8_1/web/service/ldap/server',
        'delphixpy/v1_8_1/web/service/linkingsettings',
        'delphixpy/v1_8_1/web/service/phonehome',
        'delphixpy/v1_8_1/web/service/dns',
        'delphixpy/v1_8_1/web/service/support',
        'delphixpy/v1_8_1/web/service/support/bundle',
        'delphixpy/v1_8_1/web/service/support/access',
        'delphixpy/v1_8_1/web/service/security',
        'delphixpy/v1_8_1/web/service/locale',
        'delphixpy/v1_8_1/web/service/schema',
        'delphixpy/v1_8_1/web/service/syslog',
        'delphixpy/v1_8_1/web/service/snmp',
        'delphixpy/v1_8_1/web/service/snmp/manager',
        'delphixpy/v1_8_1/web/service/proxy',
        'delphixpy/v1_8_1/web/repository',
        'delphixpy/v1_8_1/web/repository/template',
        'delphixpy/v1_8_1/web/data',
        'delphixpy/v1_8_1/web/snapshot',
        'delphixpy/v1_8_1/web/alert',
        'delphixpy/v1_8_1/web/alert/profile',
        'delphixpy/v1_8_1/web/storage',
        'delphixpy/v1_8_1/web/storage/device',
        'delphixpy/v1_8_1/web/storage/scrub',
        'delphixpy/v1_8_1/web/storage/remove',
        'delphixpy/v1_8_1/web/storage/test',
        'delphixpy/v1_8_1/web/job',
        'delphixpy/v1_8_1/web/source',
        'delphixpy/v1_8_1/web/source/operationTemplate',
        'delphixpy/v1_8_1/web/sourceconfig',
        'delphixpy/v1_8_1/web/sourceconfig/oracle',
        'delphixpy/v1_8_1/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_8_1/web/namespace',
        'delphixpy/v1_8_1/web/about',
        'delphixpy/v1_10_2',
        'delphixpy/v1_10_2/web',
        'delphixpy/v1_10_2/web/environment',
        'delphixpy/v1_10_2/web/environment/oracle',
        'delphixpy/v1_10_2/web/environment/oracle/clusternode',
        'delphixpy/v1_10_2/web/environment/oracle/listener',
        'delphixpy/v1_10_2/web/environment/user',
        'delphixpy/v1_10_2/web/environment/windows',
        'delphixpy/v1_10_2/web/environment/windows/clusternode',
        'delphixpy/v1_10_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_2/web/timezone',
        'delphixpy/v1_10_2/web/domain',
        'delphixpy/v1_10_2/web/connectivity',
        'delphixpy/v1_10_2/web/replication',
        'delphixpy/v1_10_2/web/replication/sourcestate',
        'delphixpy/v1_10_2/web/replication/targetstate',
        'delphixpy/v1_10_2/web/replication/spec',
        'delphixpy/v1_10_2/web/replication/serializationpoint',
        'delphixpy/v1_10_2/web/registration',
        'delphixpy/v1_10_2/web/registration/status',
        'delphixpy/v1_10_2/web/fault',
        'delphixpy/v1_10_2/web/fault/effect',
        'delphixpy/v1_10_2/web/network',
        'delphixpy/v1_10_2/web/network/interface',
        'delphixpy/v1_10_2/web/network/route',
        'delphixpy/v1_10_2/web/network/test',
        'delphixpy/v1_10_2/web/network/test/latency',
        'delphixpy/v1_10_2/web/network/test/throughput',
        'delphixpy/v1_10_2/web/network/test/dsp',
        'delphixpy/v1_10_2/web/network/dsp',
        'delphixpy/v1_10_2/web/network/dsp/autotune',
        'delphixpy/v1_10_2/web/transformation',
        'delphixpy/v1_10_2/web/database',
        'delphixpy/v1_10_2/web/database/template',
        'delphixpy/v1_10_2/web/database/performanceHistory',
        'delphixpy/v1_10_2/web/user',
        'delphixpy/v1_10_2/web/delphix',
        'delphixpy/v1_10_2/web/host',
        'delphixpy/v1_10_2/web/host/privilegeElevation',
        'delphixpy/v1_10_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_2/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_2/web/system',
        'delphixpy/v1_10_2/web/system/status',
        'delphixpy/v1_10_2/web/system/package',
        'delphixpy/v1_10_2/web/system/version',
        'delphixpy/v1_10_2/web/system/upgradeCheckResult',
        'delphixpy/v1_10_2/web/capacity',
        'delphixpy/v1_10_2/web/capacity/consumer',
        'delphixpy/v1_10_2/web/capacity/consumer/historical',
        'delphixpy/v1_10_2/web/capacity/system',
        'delphixpy/v1_10_2/web/capacity/system/historical',
        'delphixpy/v1_10_2/web/capacity/group',
        'delphixpy/v1_10_2/web/capacity/group/historical',
        'delphixpy/v1_10_2/web/capacity/snapshot',
        'delphixpy/v1_10_2/web/action',
        'delphixpy/v1_10_2/web/analytics',
        'delphixpy/v1_10_2/web/analytics/statistic',
        'delphixpy/v1_10_2/web/group',
        'delphixpy/v1_10_2/web/passwordPolicy',
        'delphixpy/v1_10_2/web/permission',
        'delphixpy/v1_10_2/web/notification',
        'delphixpy/v1_10_2/web/policy',
        'delphixpy/v1_10_2/web/session',
        'delphixpy/v1_10_2/web/selfservice',
        'delphixpy/v1_10_2/web/selfservice/datasource',
        'delphixpy/v1_10_2/web/selfservice/template',
        'delphixpy/v1_10_2/web/selfservice/branch',
        'delphixpy/v1_10_2/web/selfservice/usagedata',
        'delphixpy/v1_10_2/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_2/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_2/web/selfservice/config',
        'delphixpy/v1_10_2/web/selfservice/operation',
        'delphixpy/v1_10_2/web/selfservice/usage',
        'delphixpy/v1_10_2/web/selfservice/usage/template',
        'delphixpy/v1_10_2/web/selfservice/usage/branch',
        'delphixpy/v1_10_2/web/selfservice/usage/user',
        'delphixpy/v1_10_2/web/selfservice/usage/container',
        'delphixpy/v1_10_2/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_2/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_2/web/selfservice/container',
        'delphixpy/v1_10_2/web/selfservice/bookmark',
        'delphixpy/v1_10_2/web/timeflow',
        'delphixpy/v1_10_2/web/timeflow/oracle',
        'delphixpy/v1_10_2/web/timeflow/oracle/log',
        'delphixpy/v1_10_2/web/timeflow/bookmark',
        'delphixpy/v1_10_2/web/maskingjob',
        'delphixpy/v1_10_2/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_2/web/objects',
        'delphixpy/v1_10_2/web/authorization',
        'delphixpy/v1_10_2/web/authorization/configuration',
        'delphixpy/v1_10_2/web/role',
        'delphixpy/v1_10_2/web/toolkit',
        'delphixpy/v1_10_2/web/service',
        'delphixpy/v1_10_2/web/service/saml',
        'delphixpy/v1_10_2/web/service/saml/serviceprovider',
        'delphixpy/v1_10_2/web/service/smtp',
        'delphixpy/v1_10_2/web/service/httpConnector',
        'delphixpy/v1_10_2/web/service/time',
        'delphixpy/v1_10_2/web/service/certificate',
        'delphixpy/v1_10_2/web/service/ldap',
        'delphixpy/v1_10_2/web/service/ldap/server',
        'delphixpy/v1_10_2/web/service/linkingsettings',
        'delphixpy/v1_10_2/web/service/phonehome',
        'delphixpy/v1_10_2/web/service/dns',
        'delphixpy/v1_10_2/web/service/support',
        'delphixpy/v1_10_2/web/service/support/bundle',
        'delphixpy/v1_10_2/web/service/support/access',
        'delphixpy/v1_10_2/web/service/security',
        'delphixpy/v1_10_2/web/service/userInterface',
        'delphixpy/v1_10_2/web/service/cloud',
        'delphixpy/v1_10_2/web/service/locale',
        'delphixpy/v1_10_2/web/service/schema',
        'delphixpy/v1_10_2/web/service/insight',
        'delphixpy/v1_10_2/web/service/insight/splunkHec',
        'delphixpy/v1_10_2/web/service/syslog',
        'delphixpy/v1_10_2/web/service/snmp',
        'delphixpy/v1_10_2/web/service/snmp/manager',
        'delphixpy/v1_10_2/web/service/proxy',
        'delphixpy/v1_10_2/web/service/tls',
        'delphixpy/v1_10_2/web/service/tls/caCertificate',
        'delphixpy/v1_10_2/web/service/tls/csr',
        'delphixpy/v1_10_2/web/service/tls/cipherSuite',
        'delphixpy/v1_10_2/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_2/web/service/kerberos',
        'delphixpy/v1_10_2/web/repository',
        'delphixpy/v1_10_2/web/repository/template',
        'delphixpy/v1_10_2/web/data',
        'delphixpy/v1_10_2/web/snapshot',
        'delphixpy/v1_10_2/web/alert',
        'delphixpy/v1_10_2/web/alert/profile',
        'delphixpy/v1_10_2/web/storage',
        'delphixpy/v1_10_2/web/storage/device',
        'delphixpy/v1_10_2/web/storage/scrub',
        'delphixpy/v1_10_2/web/storage/remove',
        'delphixpy/v1_10_2/web/storage/test',
        'delphixpy/v1_10_2/web/job',
        'delphixpy/v1_10_2/web/source',
        'delphixpy/v1_10_2/web/source/operationTemplate',
        'delphixpy/v1_10_2/web/sourceconfig',
        'delphixpy/v1_10_2/web/namespace',
        'delphixpy/v1_10_2/web/about',
        'delphixpy/v1_7_1',
        'delphixpy/v1_7_1/web',
        'delphixpy/v1_7_1/web/environment',
        'delphixpy/v1_7_1/web/environment/oracle',
        'delphixpy/v1_7_1/web/environment/oracle/clusternode',
        'delphixpy/v1_7_1/web/environment/oracle/listener',
        'delphixpy/v1_7_1/web/environment/user',
        'delphixpy/v1_7_1/web/environment/windows',
        'delphixpy/v1_7_1/web/environment/windows/clusternode',
        'delphixpy/v1_7_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_7_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_7_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_7_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_7_1/web/timezone',
        'delphixpy/v1_7_1/web/domain',
        'delphixpy/v1_7_1/web/connectivity',
        'delphixpy/v1_7_1/web/replication',
        'delphixpy/v1_7_1/web/replication/sourcestate',
        'delphixpy/v1_7_1/web/replication/targetstate',
        'delphixpy/v1_7_1/web/replication/spec',
        'delphixpy/v1_7_1/web/replication/serializationpoint',
        'delphixpy/v1_7_1/web/registration',
        'delphixpy/v1_7_1/web/registration/status',
        'delphixpy/v1_7_1/web/fault',
        'delphixpy/v1_7_1/web/fault/effect',
        'delphixpy/v1_7_1/web/network',
        'delphixpy/v1_7_1/web/network/interface',
        'delphixpy/v1_7_1/web/network/route',
        'delphixpy/v1_7_1/web/network/test',
        'delphixpy/v1_7_1/web/network/test/latency',
        'delphixpy/v1_7_1/web/network/test/throughput',
        'delphixpy/v1_7_1/web/network/test/dsp',
        'delphixpy/v1_7_1/web/transformation',
        'delphixpy/v1_7_1/web/database',
        'delphixpy/v1_7_1/web/database/template',
        'delphixpy/v1_7_1/web/user',
        'delphixpy/v1_7_1/web/delphix',
        'delphixpy/v1_7_1/web/host',
        'delphixpy/v1_7_1/web/host/privilegeElevation',
        'delphixpy/v1_7_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_7_1/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_7_1/web/system',
        'delphixpy/v1_7_1/web/system/version',
        'delphixpy/v1_7_1/web/capacity',
        'delphixpy/v1_7_1/web/capacity/consumer',
        'delphixpy/v1_7_1/web/capacity/consumer/historical',
        'delphixpy/v1_7_1/web/capacity/system',
        'delphixpy/v1_7_1/web/capacity/system/historical',
        'delphixpy/v1_7_1/web/capacity/group',
        'delphixpy/v1_7_1/web/capacity/group/historical',
        'delphixpy/v1_7_1/web/capacity/snapshot',
        'delphixpy/v1_7_1/web/action',
        'delphixpy/v1_7_1/web/analytics',
        'delphixpy/v1_7_1/web/analytics/statistic',
        'delphixpy/v1_7_1/web/group',
        'delphixpy/v1_7_1/web/permission',
        'delphixpy/v1_7_1/web/notification',
        'delphixpy/v1_7_1/web/policy',
        'delphixpy/v1_7_1/web/session',
        'delphixpy/v1_7_1/web/timeflow',
        'delphixpy/v1_7_1/web/timeflow/oracle',
        'delphixpy/v1_7_1/web/timeflow/oracle/log',
        'delphixpy/v1_7_1/web/timeflow/bookmark',
        'delphixpy/v1_7_1/web/maskingjob',
        'delphixpy/v1_7_1/web/maskingjob/serviceconfig',
        'delphixpy/v1_7_1/web/objects',
        'delphixpy/v1_7_1/web/authorization',
        'delphixpy/v1_7_1/web/role',
        'delphixpy/v1_7_1/web/toolkit',
        'delphixpy/v1_7_1/web/jetstream',
        'delphixpy/v1_7_1/web/jetstream/datasource',
        'delphixpy/v1_7_1/web/jetstream/template',
        'delphixpy/v1_7_1/web/jetstream/branch',
        'delphixpy/v1_7_1/web/jetstream/usagedata',
        'delphixpy/v1_7_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_7_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_7_1/web/jetstream/operation',
        'delphixpy/v1_7_1/web/jetstream/usage',
        'delphixpy/v1_7_1/web/jetstream/usage/template',
        'delphixpy/v1_7_1/web/jetstream/usage/branch',
        'delphixpy/v1_7_1/web/jetstream/usage/user',
        'delphixpy/v1_7_1/web/jetstream/usage/container',
        'delphixpy/v1_7_1/web/jetstream/usage/bookmark',
        'delphixpy/v1_7_1/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_7_1/web/jetstream/container',
        'delphixpy/v1_7_1/web/jetstream/bookmark',
        'delphixpy/v1_7_1/web/service',
        'delphixpy/v1_7_1/web/service/smtp',
        'delphixpy/v1_7_1/web/service/time',
        'delphixpy/v1_7_1/web/service/certificate',
        'delphixpy/v1_7_1/web/service/ldap',
        'delphixpy/v1_7_1/web/service/ldap/server',
        'delphixpy/v1_7_1/web/service/linkingsettings',
        'delphixpy/v1_7_1/web/service/phonehome',
        'delphixpy/v1_7_1/web/service/dns',
        'delphixpy/v1_7_1/web/service/support',
        'delphixpy/v1_7_1/web/service/support/bundle',
        'delphixpy/v1_7_1/web/service/support/access',
        'delphixpy/v1_7_1/web/service/security',
        'delphixpy/v1_7_1/web/service/locale',
        'delphixpy/v1_7_1/web/service/schema',
        'delphixpy/v1_7_1/web/service/syslog',
        'delphixpy/v1_7_1/web/service/snmp',
        'delphixpy/v1_7_1/web/service/snmp/manager',
        'delphixpy/v1_7_1/web/service/proxy',
        'delphixpy/v1_7_1/web/repository',
        'delphixpy/v1_7_1/web/repository/template',
        'delphixpy/v1_7_1/web/data',
        'delphixpy/v1_7_1/web/snapshot',
        'delphixpy/v1_7_1/web/alert',
        'delphixpy/v1_7_1/web/alert/profile',
        'delphixpy/v1_7_1/web/storage',
        'delphixpy/v1_7_1/web/storage/device',
        'delphixpy/v1_7_1/web/storage/scrub',
        'delphixpy/v1_7_1/web/storage/remove',
        'delphixpy/v1_7_1/web/storage/test',
        'delphixpy/v1_7_1/web/job',
        'delphixpy/v1_7_1/web/source',
        'delphixpy/v1_7_1/web/source/operationTemplate',
        'delphixpy/v1_7_1/web/sourceconfig',
        'delphixpy/v1_7_1/web/sourceconfig/oracle',
        'delphixpy/v1_7_1/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_7_1/web/namespace',
        'delphixpy/v1_7_1/web/about',
        'delphixpy/v1_4_0',
        'delphixpy/v1_4_0/web',
        'delphixpy/v1_4_0/web/environment',
        'delphixpy/v1_4_0/web/environment/oracle',
        'delphixpy/v1_4_0/web/environment/oracle/clusternode',
        'delphixpy/v1_4_0/web/environment/oracle/listener',
        'delphixpy/v1_4_0/web/environment/user',
        'delphixpy/v1_4_0/web/environment/windows',
        'delphixpy/v1_4_0/web/environment/windows/clusternode',
        'delphixpy/v1_4_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_4_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_4_0/web/domain',
        'delphixpy/v1_4_0/web/connectivity',
        'delphixpy/v1_4_0/web/replication',
        'delphixpy/v1_4_0/web/replication/spec',
        'delphixpy/v1_4_0/web/registration',
        'delphixpy/v1_4_0/web/fault',
        'delphixpy/v1_4_0/web/fault/effect',
        'delphixpy/v1_4_0/web/network',
        'delphixpy/v1_4_0/web/network/interface',
        'delphixpy/v1_4_0/web/network/route',
        'delphixpy/v1_4_0/web/network/test',
        'delphixpy/v1_4_0/web/network/test/latency',
        'delphixpy/v1_4_0/web/network/test/throughput',
        'delphixpy/v1_4_0/web/database',
        'delphixpy/v1_4_0/web/database/template',
        'delphixpy/v1_4_0/web/user',
        'delphixpy/v1_4_0/web/delphix',
        'delphixpy/v1_4_0/web/host',
        'delphixpy/v1_4_0/web/host/privilegeElevation',
        'delphixpy/v1_4_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_4_0/web/system',
        'delphixpy/v1_4_0/web/system/version',
        'delphixpy/v1_4_0/web/capacity',
        'delphixpy/v1_4_0/web/capacity/consumer',
        'delphixpy/v1_4_0/web/capacity/consumer/historical',
        'delphixpy/v1_4_0/web/capacity/system',
        'delphixpy/v1_4_0/web/capacity/system/historical',
        'delphixpy/v1_4_0/web/capacity/group',
        'delphixpy/v1_4_0/web/capacity/group/historical',
        'delphixpy/v1_4_0/web/capacity/snapshot',
        'delphixpy/v1_4_0/web/action',
        'delphixpy/v1_4_0/web/analytics',
        'delphixpy/v1_4_0/web/analytics/statistic',
        'delphixpy/v1_4_0/web/group',
        'delphixpy/v1_4_0/web/permission',
        'delphixpy/v1_4_0/web/notification',
        'delphixpy/v1_4_0/web/policy',
        'delphixpy/v1_4_0/web/session',
        'delphixpy/v1_4_0/web/timeflow',
        'delphixpy/v1_4_0/web/timeflow/bookmark',
        'delphixpy/v1_4_0/web/objects',
        'delphixpy/v1_4_0/web/authorization',
        'delphixpy/v1_4_0/web/role',
        'delphixpy/v1_4_0/web/toolkit',
        'delphixpy/v1_4_0/web/jetstream',
        'delphixpy/v1_4_0/web/jetstream/datasource',
        'delphixpy/v1_4_0/web/jetstream/template',
        'delphixpy/v1_4_0/web/jetstream/branch',
        'delphixpy/v1_4_0/web/jetstream/usagedata',
        'delphixpy/v1_4_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_4_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_4_0/web/jetstream/operation',
        'delphixpy/v1_4_0/web/jetstream/capacity',
        'delphixpy/v1_4_0/web/jetstream/capacity/template',
        'delphixpy/v1_4_0/web/jetstream/capacity/branch',
        'delphixpy/v1_4_0/web/jetstream/capacity/container',
        'delphixpy/v1_4_0/web/jetstream/capacity/bookmark',
        'delphixpy/v1_4_0/web/jetstream/capacity/bookmark/tag',
        'delphixpy/v1_4_0/web/jetstream/container',
        'delphixpy/v1_4_0/web/jetstream/preferences',
        'delphixpy/v1_4_0/web/jetstream/bookmark',
        'delphixpy/v1_4_0/web/service',
        'delphixpy/v1_4_0/web/service/smtp',
        'delphixpy/v1_4_0/web/service/time',
        'delphixpy/v1_4_0/web/service/certificate',
        'delphixpy/v1_4_0/web/service/ldap',
        'delphixpy/v1_4_0/web/service/ldap/server',
        'delphixpy/v1_4_0/web/service/linkingsettings',
        'delphixpy/v1_4_0/web/service/phonehome',
        'delphixpy/v1_4_0/web/service/dns',
        'delphixpy/v1_4_0/web/service/support',
        'delphixpy/v1_4_0/web/service/support/bundle',
        'delphixpy/v1_4_0/web/service/support/access',
        'delphixpy/v1_4_0/web/service/security',
        'delphixpy/v1_4_0/web/service/locale',
        'delphixpy/v1_4_0/web/service/syslog',
        'delphixpy/v1_4_0/web/service/snmp',
        'delphixpy/v1_4_0/web/service/snmp/manager',
        'delphixpy/v1_4_0/web/service/proxy',
        'delphixpy/v1_4_0/web/repository',
        'delphixpy/v1_4_0/web/data',
        'delphixpy/v1_4_0/web/snapshot',
        'delphixpy/v1_4_0/web/alert',
        'delphixpy/v1_4_0/web/alert/profile',
        'delphixpy/v1_4_0/web/storage',
        'delphixpy/v1_4_0/web/storage/device',
        'delphixpy/v1_4_0/web/storage/scrub',
        'delphixpy/v1_4_0/web/job',
        'delphixpy/v1_4_0/web/source',
        'delphixpy/v1_4_0/web/sourceconfig',
        'delphixpy/v1_4_0/web/sourceconfig/oracle',
        'delphixpy/v1_4_0/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_4_0/web/namespace',
        'delphixpy/v1_4_0/web/about',
        'delphixpy/v1_11_0',
        'delphixpy/v1_11_0/web',
        'delphixpy/v1_11_0/web/environment',
        'delphixpy/v1_11_0/web/environment/oracle',
        'delphixpy/v1_11_0/web/environment/oracle/clusternode',
        'delphixpy/v1_11_0/web/environment/oracle/listener',
        'delphixpy/v1_11_0/web/environment/user',
        'delphixpy/v1_11_0/web/environment/windows',
        'delphixpy/v1_11_0/web/environment/windows/clusternode',
        'delphixpy/v1_11_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_11_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_11_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_11_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_11_0/web/timezone',
        'delphixpy/v1_11_0/web/theme',
        'delphixpy/v1_11_0/web/domain',
        'delphixpy/v1_11_0/web/connectivity',
        'delphixpy/v1_11_0/web/replication',
        'delphixpy/v1_11_0/web/replication/sourcestate',
        'delphixpy/v1_11_0/web/replication/targetstate',
        'delphixpy/v1_11_0/web/replication/spec',
        'delphixpy/v1_11_0/web/replication/serializationpoint',
        'delphixpy/v1_11_0/web/registration',
        'delphixpy/v1_11_0/web/registration/status',
        'delphixpy/v1_11_0/web/fault',
        'delphixpy/v1_11_0/web/fault/effect',
        'delphixpy/v1_11_0/web/network',
        'delphixpy/v1_11_0/web/network/interface',
        'delphixpy/v1_11_0/web/network/route',
        'delphixpy/v1_11_0/web/network/test',
        'delphixpy/v1_11_0/web/network/test/latency',
        'delphixpy/v1_11_0/web/network/test/throughput',
        'delphixpy/v1_11_0/web/network/test/dsp',
        'delphixpy/v1_11_0/web/network/dsp',
        'delphixpy/v1_11_0/web/network/dsp/autotune',
        'delphixpy/v1_11_0/web/transformation',
        'delphixpy/v1_11_0/web/database',
        'delphixpy/v1_11_0/web/database/template',
        'delphixpy/v1_11_0/web/database/performanceHistory',
        'delphixpy/v1_11_0/web/user',
        'delphixpy/v1_11_0/web/delphix',
        'delphixpy/v1_11_0/web/host',
        'delphixpy/v1_11_0/web/host/privilegeElevation',
        'delphixpy/v1_11_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_11_0/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_11_0/web/usage',
        'delphixpy/v1_11_0/web/system',
        'delphixpy/v1_11_0/web/system/status',
        'delphixpy/v1_11_0/web/system/verification',
        'delphixpy/v1_11_0/web/system/verification/reports',
        'delphixpy/v1_11_0/web/system/verification/reports/steps',
        'delphixpy/v1_11_0/web/system/package',
        'delphixpy/v1_11_0/web/system/version',
        'delphixpy/v1_11_0/web/system/upgradeCheckResult',
        'delphixpy/v1_11_0/web/capacity',
        'delphixpy/v1_11_0/web/capacity/consumer',
        'delphixpy/v1_11_0/web/capacity/consumer/historical',
        'delphixpy/v1_11_0/web/capacity/system',
        'delphixpy/v1_11_0/web/capacity/system/historical',
        'delphixpy/v1_11_0/web/capacity/group',
        'delphixpy/v1_11_0/web/capacity/group/historical',
        'delphixpy/v1_11_0/web/capacity/snapshot',
        'delphixpy/v1_11_0/web/action',
        'delphixpy/v1_11_0/web/analytics',
        'delphixpy/v1_11_0/web/analytics/statistic',
        'delphixpy/v1_11_0/web/group',
        'delphixpy/v1_11_0/web/passwordPolicy',
        'delphixpy/v1_11_0/web/permission',
        'delphixpy/v1_11_0/web/notification',
        'delphixpy/v1_11_0/web/policy',
        'delphixpy/v1_11_0/web/session',
        'delphixpy/v1_11_0/web/selfservice',
        'delphixpy/v1_11_0/web/selfservice/datasource',
        'delphixpy/v1_11_0/web/selfservice/template',
        'delphixpy/v1_11_0/web/selfservice/branch',
        'delphixpy/v1_11_0/web/selfservice/usagedata',
        'delphixpy/v1_11_0/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_11_0/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_11_0/web/selfservice/config',
        'delphixpy/v1_11_0/web/selfservice/operation',
        'delphixpy/v1_11_0/web/selfservice/usage',
        'delphixpy/v1_11_0/web/selfservice/usage/template',
        'delphixpy/v1_11_0/web/selfservice/usage/branch',
        'delphixpy/v1_11_0/web/selfservice/usage/user',
        'delphixpy/v1_11_0/web/selfservice/usage/container',
        'delphixpy/v1_11_0/web/selfservice/usage/bookmark',
        'delphixpy/v1_11_0/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_11_0/web/selfservice/container',
        'delphixpy/v1_11_0/web/selfservice/bookmark',
        'delphixpy/v1_11_0/web/timeflow',
        'delphixpy/v1_11_0/web/timeflow/oracle',
        'delphixpy/v1_11_0/web/timeflow/oracle/log',
        'delphixpy/v1_11_0/web/timeflow/bookmark',
        'delphixpy/v1_11_0/web/maskingjob',
        'delphixpy/v1_11_0/web/maskingjob/serviceconfig',
        'delphixpy/v1_11_0/web/objects',
        'delphixpy/v1_11_0/web/authorization',
        'delphixpy/v1_11_0/web/authorization/configuration',
        'delphixpy/v1_11_0/web/role',
        'delphixpy/v1_11_0/web/toolkit',
        'delphixpy/v1_11_0/web/service',
        'delphixpy/v1_11_0/web/service/saml',
        'delphixpy/v1_11_0/web/service/saml/serviceprovider',
        'delphixpy/v1_11_0/web/service/smtp',
        'delphixpy/v1_11_0/web/service/userPaths',
        'delphixpy/v1_11_0/web/service/httpConnector',
        'delphixpy/v1_11_0/web/service/nfs',
        'delphixpy/v1_11_0/web/service/time',
        'delphixpy/v1_11_0/web/service/certificate',
        'delphixpy/v1_11_0/web/service/sso',
        'delphixpy/v1_11_0/web/service/ldap',
        'delphixpy/v1_11_0/web/service/ldap/server',
        'delphixpy/v1_11_0/web/service/linkingsettings',
        'delphixpy/v1_11_0/web/service/phonehome',
        'delphixpy/v1_11_0/web/service/dns',
        'delphixpy/v1_11_0/web/service/support',
        'delphixpy/v1_11_0/web/service/support/bundle',
        'delphixpy/v1_11_0/web/service/support/access',
        'delphixpy/v1_11_0/web/service/security',
        'delphixpy/v1_11_0/web/service/userInterface',
        'delphixpy/v1_11_0/web/service/cloud',
        'delphixpy/v1_11_0/web/service/locale',
        'delphixpy/v1_11_0/web/service/schema',
        'delphixpy/v1_11_0/web/service/insight',
        'delphixpy/v1_11_0/web/service/insight/splunkHec',
        'delphixpy/v1_11_0/web/service/syslog',
        'delphixpy/v1_11_0/web/service/snmp',
        'delphixpy/v1_11_0/web/service/snmp/manager',
        'delphixpy/v1_11_0/web/service/proxy',
        'delphixpy/v1_11_0/web/service/tls',
        'delphixpy/v1_11_0/web/service/tls/caCertificate',
        'delphixpy/v1_11_0/web/service/tls/csr',
        'delphixpy/v1_11_0/web/service/tls/cipherSuite',
        'delphixpy/v1_11_0/web/service/tls/endEntityCertificate',
        'delphixpy/v1_11_0/web/service/kerberos',
        'delphixpy/v1_11_0/web/repository',
        'delphixpy/v1_11_0/web/repository/template',
        'delphixpy/v1_11_0/web/data',
        'delphixpy/v1_11_0/web/snapshot',
        'delphixpy/v1_11_0/web/alert',
        'delphixpy/v1_11_0/web/alert/profile',
        'delphixpy/v1_11_0/web/storage',
        'delphixpy/v1_11_0/web/storage/device',
        'delphixpy/v1_11_0/web/storage/scrub',
        'delphixpy/v1_11_0/web/storage/remove',
        'delphixpy/v1_11_0/web/storage/test',
        'delphixpy/v1_11_0/web/job',
        'delphixpy/v1_11_0/web/source',
        'delphixpy/v1_11_0/web/source/operationTemplate',
        'delphixpy/v1_11_0/web/sourceconfig',
        'delphixpy/v1_11_0/web/namespace',
        'delphixpy/v1_11_0/web/about',
        'delphixpy/v1_10_5',
        'delphixpy/v1_10_5/web',
        'delphixpy/v1_10_5/web/environment',
        'delphixpy/v1_10_5/web/environment/oracle',
        'delphixpy/v1_10_5/web/environment/oracle/clusternode',
        'delphixpy/v1_10_5/web/environment/oracle/listener',
        'delphixpy/v1_10_5/web/environment/user',
        'delphixpy/v1_10_5/web/environment/windows',
        'delphixpy/v1_10_5/web/environment/windows/clusternode',
        'delphixpy/v1_10_5/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_5/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_5/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_5/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_5/web/timezone',
        'delphixpy/v1_10_5/web/domain',
        'delphixpy/v1_10_5/web/connectivity',
        'delphixpy/v1_10_5/web/replication',
        'delphixpy/v1_10_5/web/replication/sourcestate',
        'delphixpy/v1_10_5/web/replication/targetstate',
        'delphixpy/v1_10_5/web/replication/spec',
        'delphixpy/v1_10_5/web/replication/serializationpoint',
        'delphixpy/v1_10_5/web/registration',
        'delphixpy/v1_10_5/web/registration/status',
        'delphixpy/v1_10_5/web/fault',
        'delphixpy/v1_10_5/web/fault/effect',
        'delphixpy/v1_10_5/web/network',
        'delphixpy/v1_10_5/web/network/interface',
        'delphixpy/v1_10_5/web/network/route',
        'delphixpy/v1_10_5/web/network/test',
        'delphixpy/v1_10_5/web/network/test/latency',
        'delphixpy/v1_10_5/web/network/test/throughput',
        'delphixpy/v1_10_5/web/network/test/dsp',
        'delphixpy/v1_10_5/web/network/dsp',
        'delphixpy/v1_10_5/web/network/dsp/autotune',
        'delphixpy/v1_10_5/web/transformation',
        'delphixpy/v1_10_5/web/database',
        'delphixpy/v1_10_5/web/database/template',
        'delphixpy/v1_10_5/web/database/performanceHistory',
        'delphixpy/v1_10_5/web/user',
        'delphixpy/v1_10_5/web/delphix',
        'delphixpy/v1_10_5/web/host',
        'delphixpy/v1_10_5/web/host/privilegeElevation',
        'delphixpy/v1_10_5/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_5/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_5/web/usage',
        'delphixpy/v1_10_5/web/system',
        'delphixpy/v1_10_5/web/system/status',
        'delphixpy/v1_10_5/web/system/package',
        'delphixpy/v1_10_5/web/system/version',
        'delphixpy/v1_10_5/web/system/upgradeCheckResult',
        'delphixpy/v1_10_5/web/capacity',
        'delphixpy/v1_10_5/web/capacity/consumer',
        'delphixpy/v1_10_5/web/capacity/consumer/historical',
        'delphixpy/v1_10_5/web/capacity/system',
        'delphixpy/v1_10_5/web/capacity/system/historical',
        'delphixpy/v1_10_5/web/capacity/group',
        'delphixpy/v1_10_5/web/capacity/group/historical',
        'delphixpy/v1_10_5/web/capacity/snapshot',
        'delphixpy/v1_10_5/web/action',
        'delphixpy/v1_10_5/web/analytics',
        'delphixpy/v1_10_5/web/analytics/statistic',
        'delphixpy/v1_10_5/web/group',
        'delphixpy/v1_10_5/web/passwordPolicy',
        'delphixpy/v1_10_5/web/permission',
        'delphixpy/v1_10_5/web/notification',
        'delphixpy/v1_10_5/web/policy',
        'delphixpy/v1_10_5/web/session',
        'delphixpy/v1_10_5/web/selfservice',
        'delphixpy/v1_10_5/web/selfservice/datasource',
        'delphixpy/v1_10_5/web/selfservice/template',
        'delphixpy/v1_10_5/web/selfservice/branch',
        'delphixpy/v1_10_5/web/selfservice/usagedata',
        'delphixpy/v1_10_5/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_5/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_5/web/selfservice/config',
        'delphixpy/v1_10_5/web/selfservice/operation',
        'delphixpy/v1_10_5/web/selfservice/usage',
        'delphixpy/v1_10_5/web/selfservice/usage/template',
        'delphixpy/v1_10_5/web/selfservice/usage/branch',
        'delphixpy/v1_10_5/web/selfservice/usage/user',
        'delphixpy/v1_10_5/web/selfservice/usage/container',
        'delphixpy/v1_10_5/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_5/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_5/web/selfservice/container',
        'delphixpy/v1_10_5/web/selfservice/bookmark',
        'delphixpy/v1_10_5/web/timeflow',
        'delphixpy/v1_10_5/web/timeflow/oracle',
        'delphixpy/v1_10_5/web/timeflow/oracle/log',
        'delphixpy/v1_10_5/web/timeflow/bookmark',
        'delphixpy/v1_10_5/web/maskingjob',
        'delphixpy/v1_10_5/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_5/web/objects',
        'delphixpy/v1_10_5/web/authorization',
        'delphixpy/v1_10_5/web/authorization/configuration',
        'delphixpy/v1_10_5/web/role',
        'delphixpy/v1_10_5/web/toolkit',
        'delphixpy/v1_10_5/web/service',
        'delphixpy/v1_10_5/web/service/saml',
        'delphixpy/v1_10_5/web/service/saml/serviceprovider',
        'delphixpy/v1_10_5/web/service/smtp',
        'delphixpy/v1_10_5/web/service/httpConnector',
        'delphixpy/v1_10_5/web/service/time',
        'delphixpy/v1_10_5/web/service/certificate',
        'delphixpy/v1_10_5/web/service/sso',
        'delphixpy/v1_10_5/web/service/ldap',
        'delphixpy/v1_10_5/web/service/ldap/server',
        'delphixpy/v1_10_5/web/service/linkingsettings',
        'delphixpy/v1_10_5/web/service/phonehome',
        'delphixpy/v1_10_5/web/service/dns',
        'delphixpy/v1_10_5/web/service/support',
        'delphixpy/v1_10_5/web/service/support/bundle',
        'delphixpy/v1_10_5/web/service/support/access',
        'delphixpy/v1_10_5/web/service/security',
        'delphixpy/v1_10_5/web/service/userInterface',
        'delphixpy/v1_10_5/web/service/cloud',
        'delphixpy/v1_10_5/web/service/locale',
        'delphixpy/v1_10_5/web/service/schema',
        'delphixpy/v1_10_5/web/service/insight',
        'delphixpy/v1_10_5/web/service/insight/splunkHec',
        'delphixpy/v1_10_5/web/service/syslog',
        'delphixpy/v1_10_5/web/service/snmp',
        'delphixpy/v1_10_5/web/service/snmp/manager',
        'delphixpy/v1_10_5/web/service/proxy',
        'delphixpy/v1_10_5/web/service/tls',
        'delphixpy/v1_10_5/web/service/tls/caCertificate',
        'delphixpy/v1_10_5/web/service/tls/csr',
        'delphixpy/v1_10_5/web/service/tls/cipherSuite',
        'delphixpy/v1_10_5/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_5/web/service/kerberos',
        'delphixpy/v1_10_5/web/repository',
        'delphixpy/v1_10_5/web/repository/template',
        'delphixpy/v1_10_5/web/data',
        'delphixpy/v1_10_5/web/snapshot',
        'delphixpy/v1_10_5/web/alert',
        'delphixpy/v1_10_5/web/alert/profile',
        'delphixpy/v1_10_5/web/storage',
        'delphixpy/v1_10_5/web/storage/device',
        'delphixpy/v1_10_5/web/storage/scrub',
        'delphixpy/v1_10_5/web/storage/remove',
        'delphixpy/v1_10_5/web/storage/test',
        'delphixpy/v1_10_5/web/job',
        'delphixpy/v1_10_5/web/source',
        'delphixpy/v1_10_5/web/source/operationTemplate',
        'delphixpy/v1_10_5/web/sourceconfig',
        'delphixpy/v1_10_5/web/namespace',
        'delphixpy/v1_10_5/web/about',
        'delphixpy/v1_4_2',
        'delphixpy/v1_4_2/web',
        'delphixpy/v1_4_2/web/environment',
        'delphixpy/v1_4_2/web/environment/oracle',
        'delphixpy/v1_4_2/web/environment/oracle/clusternode',
        'delphixpy/v1_4_2/web/environment/oracle/listener',
        'delphixpy/v1_4_2/web/environment/user',
        'delphixpy/v1_4_2/web/environment/windows',
        'delphixpy/v1_4_2/web/environment/windows/clusternode',
        'delphixpy/v1_4_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_4_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_4_2/web/domain',
        'delphixpy/v1_4_2/web/connectivity',
        'delphixpy/v1_4_2/web/replication',
        'delphixpy/v1_4_2/web/replication/spec',
        'delphixpy/v1_4_2/web/registration',
        'delphixpy/v1_4_2/web/registration/status',
        'delphixpy/v1_4_2/web/fault',
        'delphixpy/v1_4_2/web/fault/effect',
        'delphixpy/v1_4_2/web/network',
        'delphixpy/v1_4_2/web/network/interface',
        'delphixpy/v1_4_2/web/network/route',
        'delphixpy/v1_4_2/web/network/test',
        'delphixpy/v1_4_2/web/network/test/latency',
        'delphixpy/v1_4_2/web/network/test/throughput',
        'delphixpy/v1_4_2/web/database',
        'delphixpy/v1_4_2/web/database/template',
        'delphixpy/v1_4_2/web/user',
        'delphixpy/v1_4_2/web/delphix',
        'delphixpy/v1_4_2/web/host',
        'delphixpy/v1_4_2/web/host/privilegeElevation',
        'delphixpy/v1_4_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_4_2/web/system',
        'delphixpy/v1_4_2/web/system/version',
        'delphixpy/v1_4_2/web/capacity',
        'delphixpy/v1_4_2/web/capacity/consumer',
        'delphixpy/v1_4_2/web/capacity/consumer/historical',
        'delphixpy/v1_4_2/web/capacity/system',
        'delphixpy/v1_4_2/web/capacity/system/historical',
        'delphixpy/v1_4_2/web/capacity/group',
        'delphixpy/v1_4_2/web/capacity/group/historical',
        'delphixpy/v1_4_2/web/capacity/snapshot',
        'delphixpy/v1_4_2/web/action',
        'delphixpy/v1_4_2/web/analytics',
        'delphixpy/v1_4_2/web/analytics/statistic',
        'delphixpy/v1_4_2/web/group',
        'delphixpy/v1_4_2/web/permission',
        'delphixpy/v1_4_2/web/notification',
        'delphixpy/v1_4_2/web/policy',
        'delphixpy/v1_4_2/web/session',
        'delphixpy/v1_4_2/web/timeflow',
        'delphixpy/v1_4_2/web/timeflow/bookmark',
        'delphixpy/v1_4_2/web/objects',
        'delphixpy/v1_4_2/web/authorization',
        'delphixpy/v1_4_2/web/role',
        'delphixpy/v1_4_2/web/toolkit',
        'delphixpy/v1_4_2/web/jetstream',
        'delphixpy/v1_4_2/web/jetstream/datasource',
        'delphixpy/v1_4_2/web/jetstream/template',
        'delphixpy/v1_4_2/web/jetstream/branch',
        'delphixpy/v1_4_2/web/jetstream/usagedata',
        'delphixpy/v1_4_2/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_4_2/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_4_2/web/jetstream/operation',
        'delphixpy/v1_4_2/web/jetstream/capacity',
        'delphixpy/v1_4_2/web/jetstream/capacity/template',
        'delphixpy/v1_4_2/web/jetstream/capacity/branch',
        'delphixpy/v1_4_2/web/jetstream/capacity/container',
        'delphixpy/v1_4_2/web/jetstream/capacity/bookmark',
        'delphixpy/v1_4_2/web/jetstream/capacity/bookmark/tag',
        'delphixpy/v1_4_2/web/jetstream/container',
        'delphixpy/v1_4_2/web/jetstream/preferences',
        'delphixpy/v1_4_2/web/jetstream/bookmark',
        'delphixpy/v1_4_2/web/service',
        'delphixpy/v1_4_2/web/service/smtp',
        'delphixpy/v1_4_2/web/service/time',
        'delphixpy/v1_4_2/web/service/certificate',
        'delphixpy/v1_4_2/web/service/ldap',
        'delphixpy/v1_4_2/web/service/ldap/server',
        'delphixpy/v1_4_2/web/service/linkingsettings',
        'delphixpy/v1_4_2/web/service/phonehome',
        'delphixpy/v1_4_2/web/service/dns',
        'delphixpy/v1_4_2/web/service/support',
        'delphixpy/v1_4_2/web/service/support/bundle',
        'delphixpy/v1_4_2/web/service/support/access',
        'delphixpy/v1_4_2/web/service/security',
        'delphixpy/v1_4_2/web/service/locale',
        'delphixpy/v1_4_2/web/service/syslog',
        'delphixpy/v1_4_2/web/service/snmp',
        'delphixpy/v1_4_2/web/service/snmp/manager',
        'delphixpy/v1_4_2/web/service/proxy',
        'delphixpy/v1_4_2/web/repository',
        'delphixpy/v1_4_2/web/data',
        'delphixpy/v1_4_2/web/snapshot',
        'delphixpy/v1_4_2/web/alert',
        'delphixpy/v1_4_2/web/alert/profile',
        'delphixpy/v1_4_2/web/storage',
        'delphixpy/v1_4_2/web/storage/device',
        'delphixpy/v1_4_2/web/storage/scrub',
        'delphixpy/v1_4_2/web/job',
        'delphixpy/v1_4_2/web/source',
        'delphixpy/v1_4_2/web/sourceconfig',
        'delphixpy/v1_4_2/web/sourceconfig/oracle',
        'delphixpy/v1_4_2/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_4_2/web/namespace',
        'delphixpy/v1_4_2/web/about',
        'delphixpy/v1_10_1',
        'delphixpy/v1_10_1/web',
        'delphixpy/v1_10_1/web/environment',
        'delphixpy/v1_10_1/web/environment/oracle',
        'delphixpy/v1_10_1/web/environment/oracle/clusternode',
        'delphixpy/v1_10_1/web/environment/oracle/listener',
        'delphixpy/v1_10_1/web/environment/user',
        'delphixpy/v1_10_1/web/environment/windows',
        'delphixpy/v1_10_1/web/environment/windows/clusternode',
        'delphixpy/v1_10_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_1/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_1/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_1/web/timezone',
        'delphixpy/v1_10_1/web/domain',
        'delphixpy/v1_10_1/web/connectivity',
        'delphixpy/v1_10_1/web/replication',
        'delphixpy/v1_10_1/web/replication/sourcestate',
        'delphixpy/v1_10_1/web/replication/targetstate',
        'delphixpy/v1_10_1/web/replication/spec',
        'delphixpy/v1_10_1/web/replication/serializationpoint',
        'delphixpy/v1_10_1/web/registration',
        'delphixpy/v1_10_1/web/registration/status',
        'delphixpy/v1_10_1/web/fault',
        'delphixpy/v1_10_1/web/fault/effect',
        'delphixpy/v1_10_1/web/network',
        'delphixpy/v1_10_1/web/network/interface',
        'delphixpy/v1_10_1/web/network/route',
        'delphixpy/v1_10_1/web/network/test',
        'delphixpy/v1_10_1/web/network/test/latency',
        'delphixpy/v1_10_1/web/network/test/throughput',
        'delphixpy/v1_10_1/web/network/test/dsp',
        'delphixpy/v1_10_1/web/network/dsp',
        'delphixpy/v1_10_1/web/network/dsp/autotune',
        'delphixpy/v1_10_1/web/transformation',
        'delphixpy/v1_10_1/web/database',
        'delphixpy/v1_10_1/web/database/template',
        'delphixpy/v1_10_1/web/database/performanceHistory',
        'delphixpy/v1_10_1/web/user',
        'delphixpy/v1_10_1/web/delphix',
        'delphixpy/v1_10_1/web/host',
        'delphixpy/v1_10_1/web/host/privilegeElevation',
        'delphixpy/v1_10_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_1/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_1/web/system',
        'delphixpy/v1_10_1/web/system/status',
        'delphixpy/v1_10_1/web/system/package',
        'delphixpy/v1_10_1/web/system/version',
        'delphixpy/v1_10_1/web/system/upgradeCheckResult',
        'delphixpy/v1_10_1/web/capacity',
        'delphixpy/v1_10_1/web/capacity/consumer',
        'delphixpy/v1_10_1/web/capacity/consumer/historical',
        'delphixpy/v1_10_1/web/capacity/system',
        'delphixpy/v1_10_1/web/capacity/system/historical',
        'delphixpy/v1_10_1/web/capacity/group',
        'delphixpy/v1_10_1/web/capacity/group/historical',
        'delphixpy/v1_10_1/web/capacity/snapshot',
        'delphixpy/v1_10_1/web/action',
        'delphixpy/v1_10_1/web/analytics',
        'delphixpy/v1_10_1/web/analytics/statistic',
        'delphixpy/v1_10_1/web/group',
        'delphixpy/v1_10_1/web/passwordPolicy',
        'delphixpy/v1_10_1/web/permission',
        'delphixpy/v1_10_1/web/notification',
        'delphixpy/v1_10_1/web/policy',
        'delphixpy/v1_10_1/web/session',
        'delphixpy/v1_10_1/web/selfservice',
        'delphixpy/v1_10_1/web/selfservice/datasource',
        'delphixpy/v1_10_1/web/selfservice/template',
        'delphixpy/v1_10_1/web/selfservice/branch',
        'delphixpy/v1_10_1/web/selfservice/usagedata',
        'delphixpy/v1_10_1/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_1/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_1/web/selfservice/config',
        'delphixpy/v1_10_1/web/selfservice/operation',
        'delphixpy/v1_10_1/web/selfservice/usage',
        'delphixpy/v1_10_1/web/selfservice/usage/template',
        'delphixpy/v1_10_1/web/selfservice/usage/branch',
        'delphixpy/v1_10_1/web/selfservice/usage/user',
        'delphixpy/v1_10_1/web/selfservice/usage/container',
        'delphixpy/v1_10_1/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_1/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_1/web/selfservice/container',
        'delphixpy/v1_10_1/web/selfservice/bookmark',
        'delphixpy/v1_10_1/web/timeflow',
        'delphixpy/v1_10_1/web/timeflow/oracle',
        'delphixpy/v1_10_1/web/timeflow/oracle/log',
        'delphixpy/v1_10_1/web/timeflow/bookmark',
        'delphixpy/v1_10_1/web/maskingjob',
        'delphixpy/v1_10_1/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_1/web/objects',
        'delphixpy/v1_10_1/web/authorization',
        'delphixpy/v1_10_1/web/authorization/configuration',
        'delphixpy/v1_10_1/web/role',
        'delphixpy/v1_10_1/web/toolkit',
        'delphixpy/v1_10_1/web/service',
        'delphixpy/v1_10_1/web/service/saml',
        'delphixpy/v1_10_1/web/service/saml/serviceprovider',
        'delphixpy/v1_10_1/web/service/smtp',
        'delphixpy/v1_10_1/web/service/httpConnector',
        'delphixpy/v1_10_1/web/service/time',
        'delphixpy/v1_10_1/web/service/certificate',
        'delphixpy/v1_10_1/web/service/ldap',
        'delphixpy/v1_10_1/web/service/ldap/server',
        'delphixpy/v1_10_1/web/service/linkingsettings',
        'delphixpy/v1_10_1/web/service/phonehome',
        'delphixpy/v1_10_1/web/service/dns',
        'delphixpy/v1_10_1/web/service/support',
        'delphixpy/v1_10_1/web/service/support/bundle',
        'delphixpy/v1_10_1/web/service/support/access',
        'delphixpy/v1_10_1/web/service/security',
        'delphixpy/v1_10_1/web/service/userInterface',
        'delphixpy/v1_10_1/web/service/locale',
        'delphixpy/v1_10_1/web/service/schema',
        'delphixpy/v1_10_1/web/service/insight',
        'delphixpy/v1_10_1/web/service/insight/splunkHec',
        'delphixpy/v1_10_1/web/service/syslog',
        'delphixpy/v1_10_1/web/service/snmp',
        'delphixpy/v1_10_1/web/service/snmp/manager',
        'delphixpy/v1_10_1/web/service/proxy',
        'delphixpy/v1_10_1/web/service/tls',
        'delphixpy/v1_10_1/web/service/tls/caCertificate',
        'delphixpy/v1_10_1/web/service/tls/csr',
        'delphixpy/v1_10_1/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_1/web/service/kerberos',
        'delphixpy/v1_10_1/web/repository',
        'delphixpy/v1_10_1/web/repository/template',
        'delphixpy/v1_10_1/web/data',
        'delphixpy/v1_10_1/web/snapshot',
        'delphixpy/v1_10_1/web/alert',
        'delphixpy/v1_10_1/web/alert/profile',
        'delphixpy/v1_10_1/web/storage',
        'delphixpy/v1_10_1/web/storage/device',
        'delphixpy/v1_10_1/web/storage/scrub',
        'delphixpy/v1_10_1/web/storage/remove',
        'delphixpy/v1_10_1/web/storage/test',
        'delphixpy/v1_10_1/web/job',
        'delphixpy/v1_10_1/web/source',
        'delphixpy/v1_10_1/web/source/operationTemplate',
        'delphixpy/v1_10_1/web/sourceconfig',
        'delphixpy/v1_10_1/web/namespace',
        'delphixpy/v1_10_1/web/about',
        'delphixpy/v1_9_2',
        'delphixpy/v1_9_2/web',
        'delphixpy/v1_9_2/web/environment',
        'delphixpy/v1_9_2/web/environment/oracle',
        'delphixpy/v1_9_2/web/environment/oracle/clusternode',
        'delphixpy/v1_9_2/web/environment/oracle/listener',
        'delphixpy/v1_9_2/web/environment/user',
        'delphixpy/v1_9_2/web/environment/windows',
        'delphixpy/v1_9_2/web/environment/windows/clusternode',
        'delphixpy/v1_9_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_9_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_9_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_9_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_9_2/web/timezone',
        'delphixpy/v1_9_2/web/domain',
        'delphixpy/v1_9_2/web/connectivity',
        'delphixpy/v1_9_2/web/replication',
        'delphixpy/v1_9_2/web/replication/sourcestate',
        'delphixpy/v1_9_2/web/replication/targetstate',
        'delphixpy/v1_9_2/web/replication/spec',
        'delphixpy/v1_9_2/web/replication/serializationpoint',
        'delphixpy/v1_9_2/web/registration',
        'delphixpy/v1_9_2/web/registration/status',
        'delphixpy/v1_9_2/web/fault',
        'delphixpy/v1_9_2/web/fault/effect',
        'delphixpy/v1_9_2/web/network',
        'delphixpy/v1_9_2/web/network/interface',
        'delphixpy/v1_9_2/web/network/route',
        'delphixpy/v1_9_2/web/network/test',
        'delphixpy/v1_9_2/web/network/test/latency',
        'delphixpy/v1_9_2/web/network/test/throughput',
        'delphixpy/v1_9_2/web/network/test/dsp',
        'delphixpy/v1_9_2/web/network/dsp',
        'delphixpy/v1_9_2/web/network/dsp/autotune',
        'delphixpy/v1_9_2/web/transformation',
        'delphixpy/v1_9_2/web/database',
        'delphixpy/v1_9_2/web/database/template',
        'delphixpy/v1_9_2/web/database/performanceHistory',
        'delphixpy/v1_9_2/web/user',
        'delphixpy/v1_9_2/web/delphix',
        'delphixpy/v1_9_2/web/host',
        'delphixpy/v1_9_2/web/host/privilegeElevation',
        'delphixpy/v1_9_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_9_2/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_9_2/web/system',
        'delphixpy/v1_9_2/web/system/package',
        'delphixpy/v1_9_2/web/system/version',
        'delphixpy/v1_9_2/web/system/upgradeCheckResult',
        'delphixpy/v1_9_2/web/capacity',
        'delphixpy/v1_9_2/web/capacity/consumer',
        'delphixpy/v1_9_2/web/capacity/consumer/historical',
        'delphixpy/v1_9_2/web/capacity/system',
        'delphixpy/v1_9_2/web/capacity/system/historical',
        'delphixpy/v1_9_2/web/capacity/group',
        'delphixpy/v1_9_2/web/capacity/group/historical',
        'delphixpy/v1_9_2/web/capacity/snapshot',
        'delphixpy/v1_9_2/web/action',
        'delphixpy/v1_9_2/web/analytics',
        'delphixpy/v1_9_2/web/analytics/statistic',
        'delphixpy/v1_9_2/web/group',
        'delphixpy/v1_9_2/web/passwordPolicy',
        'delphixpy/v1_9_2/web/permission',
        'delphixpy/v1_9_2/web/notification',
        'delphixpy/v1_9_2/web/policy',
        'delphixpy/v1_9_2/web/session',
        'delphixpy/v1_9_2/web/selfservice',
        'delphixpy/v1_9_2/web/selfservice/datasource',
        'delphixpy/v1_9_2/web/selfservice/template',
        'delphixpy/v1_9_2/web/selfservice/branch',
        'delphixpy/v1_9_2/web/selfservice/usagedata',
        'delphixpy/v1_9_2/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_9_2/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_9_2/web/selfservice/config',
        'delphixpy/v1_9_2/web/selfservice/operation',
        'delphixpy/v1_9_2/web/selfservice/usage',
        'delphixpy/v1_9_2/web/selfservice/usage/template',
        'delphixpy/v1_9_2/web/selfservice/usage/branch',
        'delphixpy/v1_9_2/web/selfservice/usage/user',
        'delphixpy/v1_9_2/web/selfservice/usage/container',
        'delphixpy/v1_9_2/web/selfservice/usage/bookmark',
        'delphixpy/v1_9_2/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_9_2/web/selfservice/container',
        'delphixpy/v1_9_2/web/selfservice/bookmark',
        'delphixpy/v1_9_2/web/timeflow',
        'delphixpy/v1_9_2/web/timeflow/oracle',
        'delphixpy/v1_9_2/web/timeflow/oracle/log',
        'delphixpy/v1_9_2/web/timeflow/bookmark',
        'delphixpy/v1_9_2/web/maskingjob',
        'delphixpy/v1_9_2/web/maskingjob/serviceconfig',
        'delphixpy/v1_9_2/web/objects',
        'delphixpy/v1_9_2/web/authorization',
        'delphixpy/v1_9_2/web/role',
        'delphixpy/v1_9_2/web/toolkit',
        'delphixpy/v1_9_2/web/service',
        'delphixpy/v1_9_2/web/service/saml',
        'delphixpy/v1_9_2/web/service/saml/serviceprovider',
        'delphixpy/v1_9_2/web/service/smtp',
        'delphixpy/v1_9_2/web/service/httpConnector',
        'delphixpy/v1_9_2/web/service/time',
        'delphixpy/v1_9_2/web/service/certificate',
        'delphixpy/v1_9_2/web/service/ldap',
        'delphixpy/v1_9_2/web/service/ldap/server',
        'delphixpy/v1_9_2/web/service/linkingsettings',
        'delphixpy/v1_9_2/web/service/phonehome',
        'delphixpy/v1_9_2/web/service/dns',
        'delphixpy/v1_9_2/web/service/support',
        'delphixpy/v1_9_2/web/service/support/bundle',
        'delphixpy/v1_9_2/web/service/support/access',
        'delphixpy/v1_9_2/web/service/security',
        'delphixpy/v1_9_2/web/service/userInterface',
        'delphixpy/v1_9_2/web/service/locale',
        'delphixpy/v1_9_2/web/service/schema',
        'delphixpy/v1_9_2/web/service/syslog',
        'delphixpy/v1_9_2/web/service/snmp',
        'delphixpy/v1_9_2/web/service/snmp/manager',
        'delphixpy/v1_9_2/web/service/proxy',
        'delphixpy/v1_9_2/web/service/tls',
        'delphixpy/v1_9_2/web/service/tls/caCertificate',
        'delphixpy/v1_9_2/web/service/tls/csr',
        'delphixpy/v1_9_2/web/service/tls/endEntityCertificate',
        'delphixpy/v1_9_2/web/service/kerberos',
        'delphixpy/v1_9_2/web/repository',
        'delphixpy/v1_9_2/web/repository/template',
        'delphixpy/v1_9_2/web/data',
        'delphixpy/v1_9_2/web/snapshot',
        'delphixpy/v1_9_2/web/insight',
        'delphixpy/v1_9_2/web/insight/splunkHec',
        'delphixpy/v1_9_2/web/alert',
        'delphixpy/v1_9_2/web/alert/profile',
        'delphixpy/v1_9_2/web/storage',
        'delphixpy/v1_9_2/web/storage/device',
        'delphixpy/v1_9_2/web/storage/scrub',
        'delphixpy/v1_9_2/web/storage/remove',
        'delphixpy/v1_9_2/web/storage/test',
        'delphixpy/v1_9_2/web/job',
        'delphixpy/v1_9_2/web/source',
        'delphixpy/v1_9_2/web/source/operationTemplate',
        'delphixpy/v1_9_2/web/sourceconfig',
        'delphixpy/v1_9_2/web/namespace',
        'delphixpy/v1_9_2/web/about',
        'delphixpy/v1_10_4',
        'delphixpy/v1_10_4/web',
        'delphixpy/v1_10_4/web/environment',
        'delphixpy/v1_10_4/web/environment/oracle',
        'delphixpy/v1_10_4/web/environment/oracle/clusternode',
        'delphixpy/v1_10_4/web/environment/oracle/listener',
        'delphixpy/v1_10_4/web/environment/user',
        'delphixpy/v1_10_4/web/environment/windows',
        'delphixpy/v1_10_4/web/environment/windows/clusternode',
        'delphixpy/v1_10_4/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_4/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_4/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_4/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_4/web/timezone',
        'delphixpy/v1_10_4/web/domain',
        'delphixpy/v1_10_4/web/connectivity',
        'delphixpy/v1_10_4/web/replication',
        'delphixpy/v1_10_4/web/replication/sourcestate',
        'delphixpy/v1_10_4/web/replication/targetstate',
        'delphixpy/v1_10_4/web/replication/spec',
        'delphixpy/v1_10_4/web/replication/serializationpoint',
        'delphixpy/v1_10_4/web/registration',
        'delphixpy/v1_10_4/web/registration/status',
        'delphixpy/v1_10_4/web/fault',
        'delphixpy/v1_10_4/web/fault/effect',
        'delphixpy/v1_10_4/web/network',
        'delphixpy/v1_10_4/web/network/interface',
        'delphixpy/v1_10_4/web/network/route',
        'delphixpy/v1_10_4/web/network/test',
        'delphixpy/v1_10_4/web/network/test/latency',
        'delphixpy/v1_10_4/web/network/test/throughput',
        'delphixpy/v1_10_4/web/network/test/dsp',
        'delphixpy/v1_10_4/web/network/dsp',
        'delphixpy/v1_10_4/web/network/dsp/autotune',
        'delphixpy/v1_10_4/web/transformation',
        'delphixpy/v1_10_4/web/database',
        'delphixpy/v1_10_4/web/database/template',
        'delphixpy/v1_10_4/web/database/performanceHistory',
        'delphixpy/v1_10_4/web/user',
        'delphixpy/v1_10_4/web/delphix',
        'delphixpy/v1_10_4/web/host',
        'delphixpy/v1_10_4/web/host/privilegeElevation',
        'delphixpy/v1_10_4/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_4/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_4/web/usage',
        'delphixpy/v1_10_4/web/system',
        'delphixpy/v1_10_4/web/system/status',
        'delphixpy/v1_10_4/web/system/package',
        'delphixpy/v1_10_4/web/system/version',
        'delphixpy/v1_10_4/web/system/upgradeCheckResult',
        'delphixpy/v1_10_4/web/capacity',
        'delphixpy/v1_10_4/web/capacity/consumer',
        'delphixpy/v1_10_4/web/capacity/consumer/historical',
        'delphixpy/v1_10_4/web/capacity/system',
        'delphixpy/v1_10_4/web/capacity/system/historical',
        'delphixpy/v1_10_4/web/capacity/group',
        'delphixpy/v1_10_4/web/capacity/group/historical',
        'delphixpy/v1_10_4/web/capacity/snapshot',
        'delphixpy/v1_10_4/web/action',
        'delphixpy/v1_10_4/web/analytics',
        'delphixpy/v1_10_4/web/analytics/statistic',
        'delphixpy/v1_10_4/web/group',
        'delphixpy/v1_10_4/web/passwordPolicy',
        'delphixpy/v1_10_4/web/permission',
        'delphixpy/v1_10_4/web/notification',
        'delphixpy/v1_10_4/web/policy',
        'delphixpy/v1_10_4/web/session',
        'delphixpy/v1_10_4/web/selfservice',
        'delphixpy/v1_10_4/web/selfservice/datasource',
        'delphixpy/v1_10_4/web/selfservice/template',
        'delphixpy/v1_10_4/web/selfservice/branch',
        'delphixpy/v1_10_4/web/selfservice/usagedata',
        'delphixpy/v1_10_4/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_4/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_4/web/selfservice/config',
        'delphixpy/v1_10_4/web/selfservice/operation',
        'delphixpy/v1_10_4/web/selfservice/usage',
        'delphixpy/v1_10_4/web/selfservice/usage/template',
        'delphixpy/v1_10_4/web/selfservice/usage/branch',
        'delphixpy/v1_10_4/web/selfservice/usage/user',
        'delphixpy/v1_10_4/web/selfservice/usage/container',
        'delphixpy/v1_10_4/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_4/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_4/web/selfservice/container',
        'delphixpy/v1_10_4/web/selfservice/bookmark',
        'delphixpy/v1_10_4/web/timeflow',
        'delphixpy/v1_10_4/web/timeflow/oracle',
        'delphixpy/v1_10_4/web/timeflow/oracle/log',
        'delphixpy/v1_10_4/web/timeflow/bookmark',
        'delphixpy/v1_10_4/web/maskingjob',
        'delphixpy/v1_10_4/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_4/web/objects',
        'delphixpy/v1_10_4/web/authorization',
        'delphixpy/v1_10_4/web/authorization/configuration',
        'delphixpy/v1_10_4/web/role',
        'delphixpy/v1_10_4/web/toolkit',
        'delphixpy/v1_10_4/web/service',
        'delphixpy/v1_10_4/web/service/saml',
        'delphixpy/v1_10_4/web/service/saml/serviceprovider',
        'delphixpy/v1_10_4/web/service/smtp',
        'delphixpy/v1_10_4/web/service/httpConnector',
        'delphixpy/v1_10_4/web/service/time',
        'delphixpy/v1_10_4/web/service/certificate',
        'delphixpy/v1_10_4/web/service/sso',
        'delphixpy/v1_10_4/web/service/ldap',
        'delphixpy/v1_10_4/web/service/ldap/server',
        'delphixpy/v1_10_4/web/service/linkingsettings',
        'delphixpy/v1_10_4/web/service/phonehome',
        'delphixpy/v1_10_4/web/service/dns',
        'delphixpy/v1_10_4/web/service/support',
        'delphixpy/v1_10_4/web/service/support/bundle',
        'delphixpy/v1_10_4/web/service/support/access',
        'delphixpy/v1_10_4/web/service/security',
        'delphixpy/v1_10_4/web/service/userInterface',
        'delphixpy/v1_10_4/web/service/cloud',
        'delphixpy/v1_10_4/web/service/locale',
        'delphixpy/v1_10_4/web/service/schema',
        'delphixpy/v1_10_4/web/service/insight',
        'delphixpy/v1_10_4/web/service/insight/splunkHec',
        'delphixpy/v1_10_4/web/service/syslog',
        'delphixpy/v1_10_4/web/service/snmp',
        'delphixpy/v1_10_4/web/service/snmp/manager',
        'delphixpy/v1_10_4/web/service/proxy',
        'delphixpy/v1_10_4/web/service/tls',
        'delphixpy/v1_10_4/web/service/tls/caCertificate',
        'delphixpy/v1_10_4/web/service/tls/csr',
        'delphixpy/v1_10_4/web/service/tls/cipherSuite',
        'delphixpy/v1_10_4/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_4/web/service/kerberos',
        'delphixpy/v1_10_4/web/repository',
        'delphixpy/v1_10_4/web/repository/template',
        'delphixpy/v1_10_4/web/data',
        'delphixpy/v1_10_4/web/snapshot',
        'delphixpy/v1_10_4/web/alert',
        'delphixpy/v1_10_4/web/alert/profile',
        'delphixpy/v1_10_4/web/storage',
        'delphixpy/v1_10_4/web/storage/device',
        'delphixpy/v1_10_4/web/storage/scrub',
        'delphixpy/v1_10_4/web/storage/remove',
        'delphixpy/v1_10_4/web/storage/test',
        'delphixpy/v1_10_4/web/job',
        'delphixpy/v1_10_4/web/source',
        'delphixpy/v1_10_4/web/source/operationTemplate',
        'delphixpy/v1_10_4/web/sourceconfig',
        'delphixpy/v1_10_4/web/namespace',
        'delphixpy/v1_10_4/web/about',
        'delphixpy/v1_5_0',
        'delphixpy/v1_5_0/web',
        'delphixpy/v1_5_0/web/environment',
        'delphixpy/v1_5_0/web/environment/oracle',
        'delphixpy/v1_5_0/web/environment/oracle/clusternode',
        'delphixpy/v1_5_0/web/environment/oracle/listener',
        'delphixpy/v1_5_0/web/environment/user',
        'delphixpy/v1_5_0/web/environment/windows',
        'delphixpy/v1_5_0/web/environment/windows/clusternode',
        'delphixpy/v1_5_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_5_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_5_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_5_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_5_0/web/domain',
        'delphixpy/v1_5_0/web/connectivity',
        'delphixpy/v1_5_0/web/replication',
        'delphixpy/v1_5_0/web/replication/sourcestate',
        'delphixpy/v1_5_0/web/replication/targetstate',
        'delphixpy/v1_5_0/web/replication/spec',
        'delphixpy/v1_5_0/web/replication/serializationpoint',
        'delphixpy/v1_5_0/web/registration',
        'delphixpy/v1_5_0/web/registration/status',
        'delphixpy/v1_5_0/web/fault',
        'delphixpy/v1_5_0/web/fault/effect',
        'delphixpy/v1_5_0/web/network',
        'delphixpy/v1_5_0/web/network/interface',
        'delphixpy/v1_5_0/web/network/route',
        'delphixpy/v1_5_0/web/network/test',
        'delphixpy/v1_5_0/web/network/test/latency',
        'delphixpy/v1_5_0/web/network/test/throughput',
        'delphixpy/v1_5_0/web/network/test/dsp',
        'delphixpy/v1_5_0/web/database',
        'delphixpy/v1_5_0/web/database/template',
        'delphixpy/v1_5_0/web/user',
        'delphixpy/v1_5_0/web/delphix',
        'delphixpy/v1_5_0/web/host',
        'delphixpy/v1_5_0/web/host/privilegeElevation',
        'delphixpy/v1_5_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_5_0/web/system',
        'delphixpy/v1_5_0/web/system/version',
        'delphixpy/v1_5_0/web/capacity',
        'delphixpy/v1_5_0/web/capacity/consumer',
        'delphixpy/v1_5_0/web/capacity/consumer/historical',
        'delphixpy/v1_5_0/web/capacity/system',
        'delphixpy/v1_5_0/web/capacity/system/historical',
        'delphixpy/v1_5_0/web/capacity/group',
        'delphixpy/v1_5_0/web/capacity/group/historical',
        'delphixpy/v1_5_0/web/capacity/snapshot',
        'delphixpy/v1_5_0/web/action',
        'delphixpy/v1_5_0/web/analytics',
        'delphixpy/v1_5_0/web/analytics/statistic',
        'delphixpy/v1_5_0/web/group',
        'delphixpy/v1_5_0/web/permission',
        'delphixpy/v1_5_0/web/notification',
        'delphixpy/v1_5_0/web/policy',
        'delphixpy/v1_5_0/web/session',
        'delphixpy/v1_5_0/web/timeflow',
        'delphixpy/v1_5_0/web/timeflow/oracle',
        'delphixpy/v1_5_0/web/timeflow/oracle/log',
        'delphixpy/v1_5_0/web/timeflow/bookmark',
        'delphixpy/v1_5_0/web/objects',
        'delphixpy/v1_5_0/web/authorization',
        'delphixpy/v1_5_0/web/role',
        'delphixpy/v1_5_0/web/toolkit',
        'delphixpy/v1_5_0/web/jetstream',
        'delphixpy/v1_5_0/web/jetstream/datasource',
        'delphixpy/v1_5_0/web/jetstream/template',
        'delphixpy/v1_5_0/web/jetstream/branch',
        'delphixpy/v1_5_0/web/jetstream/usagedata',
        'delphixpy/v1_5_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_5_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_5_0/web/jetstream/operation',
        'delphixpy/v1_5_0/web/jetstream/usage',
        'delphixpy/v1_5_0/web/jetstream/usage/template',
        'delphixpy/v1_5_0/web/jetstream/usage/branch',
        'delphixpy/v1_5_0/web/jetstream/usage/user',
        'delphixpy/v1_5_0/web/jetstream/usage/container',
        'delphixpy/v1_5_0/web/jetstream/usage/bookmark',
        'delphixpy/v1_5_0/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_5_0/web/jetstream/container',
        'delphixpy/v1_5_0/web/jetstream/bookmark',
        'delphixpy/v1_5_0/web/service',
        'delphixpy/v1_5_0/web/service/smtp',
        'delphixpy/v1_5_0/web/service/time',
        'delphixpy/v1_5_0/web/service/certificate',
        'delphixpy/v1_5_0/web/service/ldap',
        'delphixpy/v1_5_0/web/service/ldap/server',
        'delphixpy/v1_5_0/web/service/linkingsettings',
        'delphixpy/v1_5_0/web/service/phonehome',
        'delphixpy/v1_5_0/web/service/dns',
        'delphixpy/v1_5_0/web/service/support',
        'delphixpy/v1_5_0/web/service/support/bundle',
        'delphixpy/v1_5_0/web/service/support/access',
        'delphixpy/v1_5_0/web/service/security',
        'delphixpy/v1_5_0/web/service/locale',
        'delphixpy/v1_5_0/web/service/schema',
        'delphixpy/v1_5_0/web/service/syslog',
        'delphixpy/v1_5_0/web/service/snmp',
        'delphixpy/v1_5_0/web/service/snmp/manager',
        'delphixpy/v1_5_0/web/service/proxy',
        'delphixpy/v1_5_0/web/repository',
        'delphixpy/v1_5_0/web/repository/template',
        'delphixpy/v1_5_0/web/data',
        'delphixpy/v1_5_0/web/snapshot',
        'delphixpy/v1_5_0/web/alert',
        'delphixpy/v1_5_0/web/alert/profile',
        'delphixpy/v1_5_0/web/storage',
        'delphixpy/v1_5_0/web/storage/device',
        'delphixpy/v1_5_0/web/storage/scrub',
        'delphixpy/v1_5_0/web/storage/test',
        'delphixpy/v1_5_0/web/job',
        'delphixpy/v1_5_0/web/source',
        'delphixpy/v1_5_0/web/source/operationTemplate',
        'delphixpy/v1_5_0/web/sourceconfig',
        'delphixpy/v1_5_0/web/sourceconfig/oracle',
        'delphixpy/v1_5_0/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_5_0/web/namespace',
        'delphixpy/v1_5_0/web/about',
        'delphixpy/v1_10_3',
        'delphixpy/v1_10_3/web',
        'delphixpy/v1_10_3/web/environment',
        'delphixpy/v1_10_3/web/environment/oracle',
        'delphixpy/v1_10_3/web/environment/oracle/clusternode',
        'delphixpy/v1_10_3/web/environment/oracle/listener',
        'delphixpy/v1_10_3/web/environment/user',
        'delphixpy/v1_10_3/web/environment/windows',
        'delphixpy/v1_10_3/web/environment/windows/clusternode',
        'delphixpy/v1_10_3/web/environment/windows/clusterinstance',
        'delphixpy/v1_10_3/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_10_3/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_10_3/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_10_3/web/timezone',
        'delphixpy/v1_10_3/web/domain',
        'delphixpy/v1_10_3/web/connectivity',
        'delphixpy/v1_10_3/web/replication',
        'delphixpy/v1_10_3/web/replication/sourcestate',
        'delphixpy/v1_10_3/web/replication/targetstate',
        'delphixpy/v1_10_3/web/replication/spec',
        'delphixpy/v1_10_3/web/replication/serializationpoint',
        'delphixpy/v1_10_3/web/registration',
        'delphixpy/v1_10_3/web/registration/status',
        'delphixpy/v1_10_3/web/fault',
        'delphixpy/v1_10_3/web/fault/effect',
        'delphixpy/v1_10_3/web/network',
        'delphixpy/v1_10_3/web/network/interface',
        'delphixpy/v1_10_3/web/network/route',
        'delphixpy/v1_10_3/web/network/test',
        'delphixpy/v1_10_3/web/network/test/latency',
        'delphixpy/v1_10_3/web/network/test/throughput',
        'delphixpy/v1_10_3/web/network/test/dsp',
        'delphixpy/v1_10_3/web/network/dsp',
        'delphixpy/v1_10_3/web/network/dsp/autotune',
        'delphixpy/v1_10_3/web/transformation',
        'delphixpy/v1_10_3/web/database',
        'delphixpy/v1_10_3/web/database/template',
        'delphixpy/v1_10_3/web/database/performanceHistory',
        'delphixpy/v1_10_3/web/user',
        'delphixpy/v1_10_3/web/delphix',
        'delphixpy/v1_10_3/web/host',
        'delphixpy/v1_10_3/web/host/privilegeElevation',
        'delphixpy/v1_10_3/web/host/privilegeElevation/profile',
        'delphixpy/v1_10_3/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_10_3/web/usage',
        'delphixpy/v1_10_3/web/system',
        'delphixpy/v1_10_3/web/system/status',
        'delphixpy/v1_10_3/web/system/package',
        'delphixpy/v1_10_3/web/system/version',
        'delphixpy/v1_10_3/web/system/upgradeCheckResult',
        'delphixpy/v1_10_3/web/capacity',
        'delphixpy/v1_10_3/web/capacity/consumer',
        'delphixpy/v1_10_3/web/capacity/consumer/historical',
        'delphixpy/v1_10_3/web/capacity/system',
        'delphixpy/v1_10_3/web/capacity/system/historical',
        'delphixpy/v1_10_3/web/capacity/group',
        'delphixpy/v1_10_3/web/capacity/group/historical',
        'delphixpy/v1_10_3/web/capacity/snapshot',
        'delphixpy/v1_10_3/web/action',
        'delphixpy/v1_10_3/web/analytics',
        'delphixpy/v1_10_3/web/analytics/statistic',
        'delphixpy/v1_10_3/web/group',
        'delphixpy/v1_10_3/web/passwordPolicy',
        'delphixpy/v1_10_3/web/permission',
        'delphixpy/v1_10_3/web/notification',
        'delphixpy/v1_10_3/web/policy',
        'delphixpy/v1_10_3/web/session',
        'delphixpy/v1_10_3/web/selfservice',
        'delphixpy/v1_10_3/web/selfservice/datasource',
        'delphixpy/v1_10_3/web/selfservice/template',
        'delphixpy/v1_10_3/web/selfservice/branch',
        'delphixpy/v1_10_3/web/selfservice/usagedata',
        'delphixpy/v1_10_3/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_10_3/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_10_3/web/selfservice/config',
        'delphixpy/v1_10_3/web/selfservice/operation',
        'delphixpy/v1_10_3/web/selfservice/usage',
        'delphixpy/v1_10_3/web/selfservice/usage/template',
        'delphixpy/v1_10_3/web/selfservice/usage/branch',
        'delphixpy/v1_10_3/web/selfservice/usage/user',
        'delphixpy/v1_10_3/web/selfservice/usage/container',
        'delphixpy/v1_10_3/web/selfservice/usage/bookmark',
        'delphixpy/v1_10_3/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_10_3/web/selfservice/container',
        'delphixpy/v1_10_3/web/selfservice/bookmark',
        'delphixpy/v1_10_3/web/timeflow',
        'delphixpy/v1_10_3/web/timeflow/oracle',
        'delphixpy/v1_10_3/web/timeflow/oracle/log',
        'delphixpy/v1_10_3/web/timeflow/bookmark',
        'delphixpy/v1_10_3/web/maskingjob',
        'delphixpy/v1_10_3/web/maskingjob/serviceconfig',
        'delphixpy/v1_10_3/web/objects',
        'delphixpy/v1_10_3/web/authorization',
        'delphixpy/v1_10_3/web/authorization/configuration',
        'delphixpy/v1_10_3/web/role',
        'delphixpy/v1_10_3/web/toolkit',
        'delphixpy/v1_10_3/web/service',
        'delphixpy/v1_10_3/web/service/saml',
        'delphixpy/v1_10_3/web/service/saml/serviceprovider',
        'delphixpy/v1_10_3/web/service/smtp',
        'delphixpy/v1_10_3/web/service/httpConnector',
        'delphixpy/v1_10_3/web/service/time',
        'delphixpy/v1_10_3/web/service/certificate',
        'delphixpy/v1_10_3/web/service/sso',
        'delphixpy/v1_10_3/web/service/ldap',
        'delphixpy/v1_10_3/web/service/ldap/server',
        'delphixpy/v1_10_3/web/service/linkingsettings',
        'delphixpy/v1_10_3/web/service/phonehome',
        'delphixpy/v1_10_3/web/service/dns',
        'delphixpy/v1_10_3/web/service/support',
        'delphixpy/v1_10_3/web/service/support/bundle',
        'delphixpy/v1_10_3/web/service/support/access',
        'delphixpy/v1_10_3/web/service/security',
        'delphixpy/v1_10_3/web/service/userInterface',
        'delphixpy/v1_10_3/web/service/cloud',
        'delphixpy/v1_10_3/web/service/locale',
        'delphixpy/v1_10_3/web/service/schema',
        'delphixpy/v1_10_3/web/service/insight',
        'delphixpy/v1_10_3/web/service/insight/splunkHec',
        'delphixpy/v1_10_3/web/service/syslog',
        'delphixpy/v1_10_3/web/service/snmp',
        'delphixpy/v1_10_3/web/service/snmp/manager',
        'delphixpy/v1_10_3/web/service/proxy',
        'delphixpy/v1_10_3/web/service/tls',
        'delphixpy/v1_10_3/web/service/tls/caCertificate',
        'delphixpy/v1_10_3/web/service/tls/csr',
        'delphixpy/v1_10_3/web/service/tls/cipherSuite',
        'delphixpy/v1_10_3/web/service/tls/endEntityCertificate',
        'delphixpy/v1_10_3/web/service/kerberos',
        'delphixpy/v1_10_3/web/repository',
        'delphixpy/v1_10_3/web/repository/template',
        'delphixpy/v1_10_3/web/data',
        'delphixpy/v1_10_3/web/snapshot',
        'delphixpy/v1_10_3/web/alert',
        'delphixpy/v1_10_3/web/alert/profile',
        'delphixpy/v1_10_3/web/storage',
        'delphixpy/v1_10_3/web/storage/device',
        'delphixpy/v1_10_3/web/storage/scrub',
        'delphixpy/v1_10_3/web/storage/remove',
        'delphixpy/v1_10_3/web/storage/test',
        'delphixpy/v1_10_3/web/job',
        'delphixpy/v1_10_3/web/source',
        'delphixpy/v1_10_3/web/source/operationTemplate',
        'delphixpy/v1_10_3/web/sourceconfig',
        'delphixpy/v1_10_3/web/namespace',
        'delphixpy/v1_10_3/web/about',
        'delphixpy/v1_6_0',
        'delphixpy/v1_6_0/web',
        'delphixpy/v1_6_0/web/environment',
        'delphixpy/v1_6_0/web/environment/oracle',
        'delphixpy/v1_6_0/web/environment/oracle/clusternode',
        'delphixpy/v1_6_0/web/environment/oracle/listener',
        'delphixpy/v1_6_0/web/environment/user',
        'delphixpy/v1_6_0/web/environment/windows',
        'delphixpy/v1_6_0/web/environment/windows/clusternode',
        'delphixpy/v1_6_0/web/environment/windows/clusterinstance',
        'delphixpy/v1_6_0/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_6_0/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_6_0/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_6_0/web/domain',
        'delphixpy/v1_6_0/web/connectivity',
        'delphixpy/v1_6_0/web/replication',
        'delphixpy/v1_6_0/web/replication/sourcestate',
        'delphixpy/v1_6_0/web/replication/targetstate',
        'delphixpy/v1_6_0/web/replication/spec',
        'delphixpy/v1_6_0/web/replication/serializationpoint',
        'delphixpy/v1_6_0/web/registration',
        'delphixpy/v1_6_0/web/registration/status',
        'delphixpy/v1_6_0/web/fault',
        'delphixpy/v1_6_0/web/fault/effect',
        'delphixpy/v1_6_0/web/network',
        'delphixpy/v1_6_0/web/network/interface',
        'delphixpy/v1_6_0/web/network/route',
        'delphixpy/v1_6_0/web/network/test',
        'delphixpy/v1_6_0/web/network/test/latency',
        'delphixpy/v1_6_0/web/network/test/throughput',
        'delphixpy/v1_6_0/web/network/test/dsp',
        'delphixpy/v1_6_0/web/database',
        'delphixpy/v1_6_0/web/database/template',
        'delphixpy/v1_6_0/web/user',
        'delphixpy/v1_6_0/web/delphix',
        'delphixpy/v1_6_0/web/host',
        'delphixpy/v1_6_0/web/host/privilegeElevation',
        'delphixpy/v1_6_0/web/host/privilegeElevation/profile',
        'delphixpy/v1_6_0/web/system',
        'delphixpy/v1_6_0/web/system/version',
        'delphixpy/v1_6_0/web/capacity',
        'delphixpy/v1_6_0/web/capacity/consumer',
        'delphixpy/v1_6_0/web/capacity/consumer/historical',
        'delphixpy/v1_6_0/web/capacity/system',
        'delphixpy/v1_6_0/web/capacity/system/historical',
        'delphixpy/v1_6_0/web/capacity/group',
        'delphixpy/v1_6_0/web/capacity/group/historical',
        'delphixpy/v1_6_0/web/capacity/snapshot',
        'delphixpy/v1_6_0/web/action',
        'delphixpy/v1_6_0/web/analytics',
        'delphixpy/v1_6_0/web/analytics/statistic',
        'delphixpy/v1_6_0/web/group',
        'delphixpy/v1_6_0/web/permission',
        'delphixpy/v1_6_0/web/notification',
        'delphixpy/v1_6_0/web/policy',
        'delphixpy/v1_6_0/web/session',
        'delphixpy/v1_6_0/web/timeflow',
        'delphixpy/v1_6_0/web/timeflow/oracle',
        'delphixpy/v1_6_0/web/timeflow/oracle/log',
        'delphixpy/v1_6_0/web/timeflow/bookmark',
        'delphixpy/v1_6_0/web/objects',
        'delphixpy/v1_6_0/web/authorization',
        'delphixpy/v1_6_0/web/role',
        'delphixpy/v1_6_0/web/toolkit',
        'delphixpy/v1_6_0/web/jetstream',
        'delphixpy/v1_6_0/web/jetstream/datasource',
        'delphixpy/v1_6_0/web/jetstream/template',
        'delphixpy/v1_6_0/web/jetstream/branch',
        'delphixpy/v1_6_0/web/jetstream/usagedata',
        'delphixpy/v1_6_0/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_6_0/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_6_0/web/jetstream/operation',
        'delphixpy/v1_6_0/web/jetstream/usage',
        'delphixpy/v1_6_0/web/jetstream/usage/template',
        'delphixpy/v1_6_0/web/jetstream/usage/branch',
        'delphixpy/v1_6_0/web/jetstream/usage/user',
        'delphixpy/v1_6_0/web/jetstream/usage/container',
        'delphixpy/v1_6_0/web/jetstream/usage/bookmark',
        'delphixpy/v1_6_0/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_6_0/web/jetstream/container',
        'delphixpy/v1_6_0/web/jetstream/bookmark',
        'delphixpy/v1_6_0/web/service',
        'delphixpy/v1_6_0/web/service/smtp',
        'delphixpy/v1_6_0/web/service/time',
        'delphixpy/v1_6_0/web/service/certificate',
        'delphixpy/v1_6_0/web/service/ldap',
        'delphixpy/v1_6_0/web/service/ldap/server',
        'delphixpy/v1_6_0/web/service/linkingsettings',
        'delphixpy/v1_6_0/web/service/phonehome',
        'delphixpy/v1_6_0/web/service/dns',
        'delphixpy/v1_6_0/web/service/support',
        'delphixpy/v1_6_0/web/service/support/bundle',
        'delphixpy/v1_6_0/web/service/support/access',
        'delphixpy/v1_6_0/web/service/security',
        'delphixpy/v1_6_0/web/service/locale',
        'delphixpy/v1_6_0/web/service/schema',
        'delphixpy/v1_6_0/web/service/syslog',
        'delphixpy/v1_6_0/web/service/snmp',
        'delphixpy/v1_6_0/web/service/snmp/manager',
        'delphixpy/v1_6_0/web/service/proxy',
        'delphixpy/v1_6_0/web/repository',
        'delphixpy/v1_6_0/web/repository/template',
        'delphixpy/v1_6_0/web/data',
        'delphixpy/v1_6_0/web/snapshot',
        'delphixpy/v1_6_0/web/alert',
        'delphixpy/v1_6_0/web/alert/profile',
        'delphixpy/v1_6_0/web/storage',
        'delphixpy/v1_6_0/web/storage/device',
        'delphixpy/v1_6_0/web/storage/scrub',
        'delphixpy/v1_6_0/web/storage/remove',
        'delphixpy/v1_6_0/web/storage/test',
        'delphixpy/v1_6_0/web/job',
        'delphixpy/v1_6_0/web/source',
        'delphixpy/v1_6_0/web/source/operationTemplate',
        'delphixpy/v1_6_0/web/sourceconfig',
        'delphixpy/v1_6_0/web/sourceconfig/oracle',
        'delphixpy/v1_6_0/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_6_0/web/namespace',
        'delphixpy/v1_6_0/web/about',
        'delphixpy/v1_11_2',
        'delphixpy/v1_11_2/web',
        'delphixpy/v1_11_2/web/environment',
        'delphixpy/v1_11_2/web/environment/oracle',
        'delphixpy/v1_11_2/web/environment/oracle/clusternode',
        'delphixpy/v1_11_2/web/environment/oracle/listener',
        'delphixpy/v1_11_2/web/environment/user',
        'delphixpy/v1_11_2/web/environment/windows',
        'delphixpy/v1_11_2/web/environment/windows/clusternode',
        'delphixpy/v1_11_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_11_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_11_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_11_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_11_2/web/timezone',
        'delphixpy/v1_11_2/web/theme',
        'delphixpy/v1_11_2/web/domain',
        'delphixpy/v1_11_2/web/connectivity',
        'delphixpy/v1_11_2/web/replication',
        'delphixpy/v1_11_2/web/replication/sourcestate',
        'delphixpy/v1_11_2/web/replication/targetstate',
        'delphixpy/v1_11_2/web/replication/spec',
        'delphixpy/v1_11_2/web/replication/serializationpoint',
        'delphixpy/v1_11_2/web/registration',
        'delphixpy/v1_11_2/web/registration/status',
        'delphixpy/v1_11_2/web/fault',
        'delphixpy/v1_11_2/web/fault/effect',
        'delphixpy/v1_11_2/web/network',
        'delphixpy/v1_11_2/web/network/interface',
        'delphixpy/v1_11_2/web/network/route',
        'delphixpy/v1_11_2/web/network/test',
        'delphixpy/v1_11_2/web/network/test/latency',
        'delphixpy/v1_11_2/web/network/test/throughput',
        'delphixpy/v1_11_2/web/network/test/dsp',
        'delphixpy/v1_11_2/web/network/dsp',
        'delphixpy/v1_11_2/web/network/dsp/autotune',
        'delphixpy/v1_11_2/web/transformation',
        'delphixpy/v1_11_2/web/database',
        'delphixpy/v1_11_2/web/database/template',
        'delphixpy/v1_11_2/web/database/performanceHistory',
        'delphixpy/v1_11_2/web/user',
        'delphixpy/v1_11_2/web/delphix',
        'delphixpy/v1_11_2/web/host',
        'delphixpy/v1_11_2/web/host/privilegeElevation',
        'delphixpy/v1_11_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_11_2/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_11_2/web/usage',
        'delphixpy/v1_11_2/web/system',
        'delphixpy/v1_11_2/web/system/status',
        'delphixpy/v1_11_2/web/system/verification',
        'delphixpy/v1_11_2/web/system/verification/reports',
        'delphixpy/v1_11_2/web/system/verification/reports/steps',
        'delphixpy/v1_11_2/web/system/package',
        'delphixpy/v1_11_2/web/system/version',
        'delphixpy/v1_11_2/web/system/upgradeCheckResult',
        'delphixpy/v1_11_2/web/capacity',
        'delphixpy/v1_11_2/web/capacity/consumer',
        'delphixpy/v1_11_2/web/capacity/consumer/historical',
        'delphixpy/v1_11_2/web/capacity/system',
        'delphixpy/v1_11_2/web/capacity/system/historical',
        'delphixpy/v1_11_2/web/capacity/group',
        'delphixpy/v1_11_2/web/capacity/group/historical',
        'delphixpy/v1_11_2/web/capacity/snapshot',
        'delphixpy/v1_11_2/web/action',
        'delphixpy/v1_11_2/web/analytics',
        'delphixpy/v1_11_2/web/analytics/statistic',
        'delphixpy/v1_11_2/web/group',
        'delphixpy/v1_11_2/web/passwordPolicy',
        'delphixpy/v1_11_2/web/permission',
        'delphixpy/v1_11_2/web/notification',
        'delphixpy/v1_11_2/web/policy',
        'delphixpy/v1_11_2/web/session',
        'delphixpy/v1_11_2/web/selfservice',
        'delphixpy/v1_11_2/web/selfservice/datasource',
        'delphixpy/v1_11_2/web/selfservice/template',
        'delphixpy/v1_11_2/web/selfservice/branch',
        'delphixpy/v1_11_2/web/selfservice/usagedata',
        'delphixpy/v1_11_2/web/selfservice/usagedata/operationduration',
        'delphixpy/v1_11_2/web/selfservice/usagedata/operationcount',
        'delphixpy/v1_11_2/web/selfservice/config',
        'delphixpy/v1_11_2/web/selfservice/operation',
        'delphixpy/v1_11_2/web/selfservice/usage',
        'delphixpy/v1_11_2/web/selfservice/usage/template',
        'delphixpy/v1_11_2/web/selfservice/usage/branch',
        'delphixpy/v1_11_2/web/selfservice/usage/user',
        'delphixpy/v1_11_2/web/selfservice/usage/container',
        'delphixpy/v1_11_2/web/selfservice/usage/bookmark',
        'delphixpy/v1_11_2/web/selfservice/usage/bookmark/tag',
        'delphixpy/v1_11_2/web/selfservice/container',
        'delphixpy/v1_11_2/web/selfservice/bookmark',
        'delphixpy/v1_11_2/web/timeflow',
        'delphixpy/v1_11_2/web/timeflow/oracle',
        'delphixpy/v1_11_2/web/timeflow/oracle/log',
        'delphixpy/v1_11_2/web/timeflow/bookmark',
        'delphixpy/v1_11_2/web/maskingjob',
        'delphixpy/v1_11_2/web/maskingjob/serviceconfig',
        'delphixpy/v1_11_2/web/objects',
        'delphixpy/v1_11_2/web/authorization',
        'delphixpy/v1_11_2/web/authorization/configuration',
        'delphixpy/v1_11_2/web/role',
        'delphixpy/v1_11_2/web/toolkit',
        'delphixpy/v1_11_2/web/service',
        'delphixpy/v1_11_2/web/service/saml',
        'delphixpy/v1_11_2/web/service/saml/serviceprovider',
        'delphixpy/v1_11_2/web/service/smtp',
        'delphixpy/v1_11_2/web/service/userPaths',
        'delphixpy/v1_11_2/web/service/minimalPhonehome',
        'delphixpy/v1_11_2/web/service/httpConnector',
        'delphixpy/v1_11_2/web/service/nfs',
        'delphixpy/v1_11_2/web/service/time',
        'delphixpy/v1_11_2/web/service/certificate',
        'delphixpy/v1_11_2/web/service/sso',
        'delphixpy/v1_11_2/web/service/ldap',
        'delphixpy/v1_11_2/web/service/ldap/server',
        'delphixpy/v1_11_2/web/service/linkingsettings',
        'delphixpy/v1_11_2/web/service/phonehome',
        'delphixpy/v1_11_2/web/service/dns',
        'delphixpy/v1_11_2/web/service/passwordVault',
        'delphixpy/v1_11_2/web/service/support',
        'delphixpy/v1_11_2/web/service/support/bundle',
        'delphixpy/v1_11_2/web/service/support/access',
        'delphixpy/v1_11_2/web/service/security',
        'delphixpy/v1_11_2/web/service/userInterface',
        'delphixpy/v1_11_2/web/service/cloud',
        'delphixpy/v1_11_2/web/service/locale',
        'delphixpy/v1_11_2/web/service/schema',
        'delphixpy/v1_11_2/web/service/insight',
        'delphixpy/v1_11_2/web/service/insight/splunkHec',
        'delphixpy/v1_11_2/web/service/syslog',
        'delphixpy/v1_11_2/web/service/snmp',
        'delphixpy/v1_11_2/web/service/snmp/manager',
        'delphixpy/v1_11_2/web/service/proxy',
        'delphixpy/v1_11_2/web/service/tls',
        'delphixpy/v1_11_2/web/service/tls/caCertificate',
        'delphixpy/v1_11_2/web/service/tls/csr',
        'delphixpy/v1_11_2/web/service/tls/cipherSuite',
        'delphixpy/v1_11_2/web/service/tls/endEntityCertificate',
        'delphixpy/v1_11_2/web/service/kerberos',
        'delphixpy/v1_11_2/web/repository',
        'delphixpy/v1_11_2/web/repository/template',
        'delphixpy/v1_11_2/web/data',
        'delphixpy/v1_11_2/web/snapshot',
        'delphixpy/v1_11_2/web/alert',
        'delphixpy/v1_11_2/web/alert/profile',
        'delphixpy/v1_11_2/web/storage',
        'delphixpy/v1_11_2/web/storage/device',
        'delphixpy/v1_11_2/web/storage/scrub',
        'delphixpy/v1_11_2/web/storage/remove',
        'delphixpy/v1_11_2/web/storage/test',
        'delphixpy/v1_11_2/web/job',
        'delphixpy/v1_11_2/web/source',
        'delphixpy/v1_11_2/web/source/operationTemplate',
        'delphixpy/v1_11_2/web/sourceconfig',
        'delphixpy/v1_11_2/web/namespace',
        'delphixpy/v1_11_2/web/about',
        'delphixpy/v1_4_3',
        'delphixpy/v1_4_3/web',
        'delphixpy/v1_4_3/web/environment',
        'delphixpy/v1_4_3/web/environment/oracle',
        'delphixpy/v1_4_3/web/environment/oracle/clusternode',
        'delphixpy/v1_4_3/web/environment/oracle/listener',
        'delphixpy/v1_4_3/web/environment/user',
        'delphixpy/v1_4_3/web/environment/windows',
        'delphixpy/v1_4_3/web/environment/windows/clusternode',
        'delphixpy/v1_4_3/web/environment/windows/clusterinstance',
        'delphixpy/v1_4_3/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_4_3/web/domain',
        'delphixpy/v1_4_3/web/connectivity',
        'delphixpy/v1_4_3/web/replication',
        'delphixpy/v1_4_3/web/replication/spec',
        'delphixpy/v1_4_3/web/registration',
        'delphixpy/v1_4_3/web/registration/status',
        'delphixpy/v1_4_3/web/fault',
        'delphixpy/v1_4_3/web/fault/effect',
        'delphixpy/v1_4_3/web/network',
        'delphixpy/v1_4_3/web/network/interface',
        'delphixpy/v1_4_3/web/network/route',
        'delphixpy/v1_4_3/web/network/test',
        'delphixpy/v1_4_3/web/network/test/latency',
        'delphixpy/v1_4_3/web/network/test/throughput',
        'delphixpy/v1_4_3/web/database',
        'delphixpy/v1_4_3/web/database/template',
        'delphixpy/v1_4_3/web/user',
        'delphixpy/v1_4_3/web/delphix',
        'delphixpy/v1_4_3/web/host',
        'delphixpy/v1_4_3/web/host/privilegeElevation',
        'delphixpy/v1_4_3/web/host/privilegeElevation/profile',
        'delphixpy/v1_4_3/web/system',
        'delphixpy/v1_4_3/web/system/version',
        'delphixpy/v1_4_3/web/capacity',
        'delphixpy/v1_4_3/web/capacity/consumer',
        'delphixpy/v1_4_3/web/capacity/consumer/historical',
        'delphixpy/v1_4_3/web/capacity/system',
        'delphixpy/v1_4_3/web/capacity/system/historical',
        'delphixpy/v1_4_3/web/capacity/group',
        'delphixpy/v1_4_3/web/capacity/group/historical',
        'delphixpy/v1_4_3/web/capacity/snapshot',
        'delphixpy/v1_4_3/web/action',
        'delphixpy/v1_4_3/web/analytics',
        'delphixpy/v1_4_3/web/analytics/statistic',
        'delphixpy/v1_4_3/web/group',
        'delphixpy/v1_4_3/web/permission',
        'delphixpy/v1_4_3/web/notification',
        'delphixpy/v1_4_3/web/policy',
        'delphixpy/v1_4_3/web/session',
        'delphixpy/v1_4_3/web/timeflow',
        'delphixpy/v1_4_3/web/timeflow/bookmark',
        'delphixpy/v1_4_3/web/objects',
        'delphixpy/v1_4_3/web/authorization',
        'delphixpy/v1_4_3/web/role',
        'delphixpy/v1_4_3/web/toolkit',
        'delphixpy/v1_4_3/web/jetstream',
        'delphixpy/v1_4_3/web/jetstream/datasource',
        'delphixpy/v1_4_3/web/jetstream/template',
        'delphixpy/v1_4_3/web/jetstream/branch',
        'delphixpy/v1_4_3/web/jetstream/usagedata',
        'delphixpy/v1_4_3/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_4_3/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_4_3/web/jetstream/operation',
        'delphixpy/v1_4_3/web/jetstream/capacity',
        'delphixpy/v1_4_3/web/jetstream/capacity/template',
        'delphixpy/v1_4_3/web/jetstream/capacity/branch',
        'delphixpy/v1_4_3/web/jetstream/capacity/container',
        'delphixpy/v1_4_3/web/jetstream/capacity/bookmark',
        'delphixpy/v1_4_3/web/jetstream/capacity/bookmark/tag',
        'delphixpy/v1_4_3/web/jetstream/container',
        'delphixpy/v1_4_3/web/jetstream/preferences',
        'delphixpy/v1_4_3/web/jetstream/bookmark',
        'delphixpy/v1_4_3/web/service',
        'delphixpy/v1_4_3/web/service/smtp',
        'delphixpy/v1_4_3/web/service/time',
        'delphixpy/v1_4_3/web/service/certificate',
        'delphixpy/v1_4_3/web/service/ldap',
        'delphixpy/v1_4_3/web/service/ldap/server',
        'delphixpy/v1_4_3/web/service/linkingsettings',
        'delphixpy/v1_4_3/web/service/phonehome',
        'delphixpy/v1_4_3/web/service/dns',
        'delphixpy/v1_4_3/web/service/support',
        'delphixpy/v1_4_3/web/service/support/bundle',
        'delphixpy/v1_4_3/web/service/support/access',
        'delphixpy/v1_4_3/web/service/security',
        'delphixpy/v1_4_3/web/service/locale',
        'delphixpy/v1_4_3/web/service/syslog',
        'delphixpy/v1_4_3/web/service/snmp',
        'delphixpy/v1_4_3/web/service/snmp/manager',
        'delphixpy/v1_4_3/web/service/proxy',
        'delphixpy/v1_4_3/web/repository',
        'delphixpy/v1_4_3/web/data',
        'delphixpy/v1_4_3/web/snapshot',
        'delphixpy/v1_4_3/web/alert',
        'delphixpy/v1_4_3/web/alert/profile',
        'delphixpy/v1_4_3/web/storage',
        'delphixpy/v1_4_3/web/storage/device',
        'delphixpy/v1_4_3/web/storage/scrub',
        'delphixpy/v1_4_3/web/job',
        'delphixpy/v1_4_3/web/source',
        'delphixpy/v1_4_3/web/sourceconfig',
        'delphixpy/v1_4_3/web/sourceconfig/oracle',
        'delphixpy/v1_4_3/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_4_3/web/namespace',
        'delphixpy/v1_4_3/web/about',
        'delphixpy/v1_6_2',
        'delphixpy/v1_6_2/web',
        'delphixpy/v1_6_2/web/environment',
        'delphixpy/v1_6_2/web/environment/oracle',
        'delphixpy/v1_6_2/web/environment/oracle/clusternode',
        'delphixpy/v1_6_2/web/environment/oracle/listener',
        'delphixpy/v1_6_2/web/environment/user',
        'delphixpy/v1_6_2/web/environment/windows',
        'delphixpy/v1_6_2/web/environment/windows/clusternode',
        'delphixpy/v1_6_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_6_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_6_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_6_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_6_2/web/domain',
        'delphixpy/v1_6_2/web/connectivity',
        'delphixpy/v1_6_2/web/replication',
        'delphixpy/v1_6_2/web/replication/sourcestate',
        'delphixpy/v1_6_2/web/replication/targetstate',
        'delphixpy/v1_6_2/web/replication/spec',
        'delphixpy/v1_6_2/web/replication/serializationpoint',
        'delphixpy/v1_6_2/web/registration',
        'delphixpy/v1_6_2/web/registration/status',
        'delphixpy/v1_6_2/web/fault',
        'delphixpy/v1_6_2/web/fault/effect',
        'delphixpy/v1_6_2/web/network',
        'delphixpy/v1_6_2/web/network/interface',
        'delphixpy/v1_6_2/web/network/route',
        'delphixpy/v1_6_2/web/network/test',
        'delphixpy/v1_6_2/web/network/test/latency',
        'delphixpy/v1_6_2/web/network/test/throughput',
        'delphixpy/v1_6_2/web/network/test/dsp',
        'delphixpy/v1_6_2/web/database',
        'delphixpy/v1_6_2/web/database/template',
        'delphixpy/v1_6_2/web/user',
        'delphixpy/v1_6_2/web/delphix',
        'delphixpy/v1_6_2/web/host',
        'delphixpy/v1_6_2/web/host/privilegeElevation',
        'delphixpy/v1_6_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_6_2/web/system',
        'delphixpy/v1_6_2/web/system/version',
        'delphixpy/v1_6_2/web/capacity',
        'delphixpy/v1_6_2/web/capacity/consumer',
        'delphixpy/v1_6_2/web/capacity/consumer/historical',
        'delphixpy/v1_6_2/web/capacity/system',
        'delphixpy/v1_6_2/web/capacity/system/historical',
        'delphixpy/v1_6_2/web/capacity/group',
        'delphixpy/v1_6_2/web/capacity/group/historical',
        'delphixpy/v1_6_2/web/capacity/snapshot',
        'delphixpy/v1_6_2/web/action',
        'delphixpy/v1_6_2/web/analytics',
        'delphixpy/v1_6_2/web/analytics/statistic',
        'delphixpy/v1_6_2/web/group',
        'delphixpy/v1_6_2/web/permission',
        'delphixpy/v1_6_2/web/notification',
        'delphixpy/v1_6_2/web/policy',
        'delphixpy/v1_6_2/web/session',
        'delphixpy/v1_6_2/web/timeflow',
        'delphixpy/v1_6_2/web/timeflow/oracle',
        'delphixpy/v1_6_2/web/timeflow/oracle/log',
        'delphixpy/v1_6_2/web/timeflow/bookmark',
        'delphixpy/v1_6_2/web/objects',
        'delphixpy/v1_6_2/web/authorization',
        'delphixpy/v1_6_2/web/role',
        'delphixpy/v1_6_2/web/toolkit',
        'delphixpy/v1_6_2/web/jetstream',
        'delphixpy/v1_6_2/web/jetstream/datasource',
        'delphixpy/v1_6_2/web/jetstream/template',
        'delphixpy/v1_6_2/web/jetstream/branch',
        'delphixpy/v1_6_2/web/jetstream/usagedata',
        'delphixpy/v1_6_2/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_6_2/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_6_2/web/jetstream/operation',
        'delphixpy/v1_6_2/web/jetstream/usage',
        'delphixpy/v1_6_2/web/jetstream/usage/template',
        'delphixpy/v1_6_2/web/jetstream/usage/branch',
        'delphixpy/v1_6_2/web/jetstream/usage/user',
        'delphixpy/v1_6_2/web/jetstream/usage/container',
        'delphixpy/v1_6_2/web/jetstream/usage/bookmark',
        'delphixpy/v1_6_2/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_6_2/web/jetstream/container',
        'delphixpy/v1_6_2/web/jetstream/bookmark',
        'delphixpy/v1_6_2/web/service',
        'delphixpy/v1_6_2/web/service/smtp',
        'delphixpy/v1_6_2/web/service/time',
        'delphixpy/v1_6_2/web/service/certificate',
        'delphixpy/v1_6_2/web/service/ldap',
        'delphixpy/v1_6_2/web/service/ldap/server',
        'delphixpy/v1_6_2/web/service/linkingsettings',
        'delphixpy/v1_6_2/web/service/phonehome',
        'delphixpy/v1_6_2/web/service/dns',
        'delphixpy/v1_6_2/web/service/support',
        'delphixpy/v1_6_2/web/service/support/bundle',
        'delphixpy/v1_6_2/web/service/support/access',
        'delphixpy/v1_6_2/web/service/security',
        'delphixpy/v1_6_2/web/service/locale',
        'delphixpy/v1_6_2/web/service/schema',
        'delphixpy/v1_6_2/web/service/syslog',
        'delphixpy/v1_6_2/web/service/snmp',
        'delphixpy/v1_6_2/web/service/snmp/manager',
        'delphixpy/v1_6_2/web/service/proxy',
        'delphixpy/v1_6_2/web/repository',
        'delphixpy/v1_6_2/web/repository/template',
        'delphixpy/v1_6_2/web/data',
        'delphixpy/v1_6_2/web/snapshot',
        'delphixpy/v1_6_2/web/alert',
        'delphixpy/v1_6_2/web/alert/profile',
        'delphixpy/v1_6_2/web/storage',
        'delphixpy/v1_6_2/web/storage/device',
        'delphixpy/v1_6_2/web/storage/scrub',
        'delphixpy/v1_6_2/web/storage/remove',
        'delphixpy/v1_6_2/web/storage/test',
        'delphixpy/v1_6_2/web/job',
        'delphixpy/v1_6_2/web/source',
        'delphixpy/v1_6_2/web/source/operationTemplate',
        'delphixpy/v1_6_2/web/sourceconfig',
        'delphixpy/v1_6_2/web/sourceconfig/oracle',
        'delphixpy/v1_6_2/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_6_2/web/namespace',
        'delphixpy/v1_6_2/web/about',
        'delphixpy/v1_5_2',
        'delphixpy/v1_5_2/web',
        'delphixpy/v1_5_2/web/environment',
        'delphixpy/v1_5_2/web/environment/oracle',
        'delphixpy/v1_5_2/web/environment/oracle/clusternode',
        'delphixpy/v1_5_2/web/environment/oracle/listener',
        'delphixpy/v1_5_2/web/environment/user',
        'delphixpy/v1_5_2/web/environment/windows',
        'delphixpy/v1_5_2/web/environment/windows/clusternode',
        'delphixpy/v1_5_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_5_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_5_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_5_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_5_2/web/domain',
        'delphixpy/v1_5_2/web/connectivity',
        'delphixpy/v1_5_2/web/replication',
        'delphixpy/v1_5_2/web/replication/sourcestate',
        'delphixpy/v1_5_2/web/replication/targetstate',
        'delphixpy/v1_5_2/web/replication/spec',
        'delphixpy/v1_5_2/web/replication/serializationpoint',
        'delphixpy/v1_5_2/web/registration',
        'delphixpy/v1_5_2/web/registration/status',
        'delphixpy/v1_5_2/web/fault',
        'delphixpy/v1_5_2/web/fault/effect',
        'delphixpy/v1_5_2/web/network',
        'delphixpy/v1_5_2/web/network/interface',
        'delphixpy/v1_5_2/web/network/route',
        'delphixpy/v1_5_2/web/network/test',
        'delphixpy/v1_5_2/web/network/test/latency',
        'delphixpy/v1_5_2/web/network/test/throughput',
        'delphixpy/v1_5_2/web/network/test/dsp',
        'delphixpy/v1_5_2/web/database',
        'delphixpy/v1_5_2/web/database/template',
        'delphixpy/v1_5_2/web/user',
        'delphixpy/v1_5_2/web/delphix',
        'delphixpy/v1_5_2/web/host',
        'delphixpy/v1_5_2/web/host/privilegeElevation',
        'delphixpy/v1_5_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_5_2/web/system',
        'delphixpy/v1_5_2/web/system/version',
        'delphixpy/v1_5_2/web/capacity',
        'delphixpy/v1_5_2/web/capacity/consumer',
        'delphixpy/v1_5_2/web/capacity/consumer/historical',
        'delphixpy/v1_5_2/web/capacity/system',
        'delphixpy/v1_5_2/web/capacity/system/historical',
        'delphixpy/v1_5_2/web/capacity/group',
        'delphixpy/v1_5_2/web/capacity/group/historical',
        'delphixpy/v1_5_2/web/capacity/snapshot',
        'delphixpy/v1_5_2/web/action',
        'delphixpy/v1_5_2/web/analytics',
        'delphixpy/v1_5_2/web/analytics/statistic',
        'delphixpy/v1_5_2/web/group',
        'delphixpy/v1_5_2/web/permission',
        'delphixpy/v1_5_2/web/notification',
        'delphixpy/v1_5_2/web/policy',
        'delphixpy/v1_5_2/web/session',
        'delphixpy/v1_5_2/web/timeflow',
        'delphixpy/v1_5_2/web/timeflow/oracle',
        'delphixpy/v1_5_2/web/timeflow/oracle/log',
        'delphixpy/v1_5_2/web/timeflow/bookmark',
        'delphixpy/v1_5_2/web/objects',
        'delphixpy/v1_5_2/web/authorization',
        'delphixpy/v1_5_2/web/role',
        'delphixpy/v1_5_2/web/toolkit',
        'delphixpy/v1_5_2/web/jetstream',
        'delphixpy/v1_5_2/web/jetstream/datasource',
        'delphixpy/v1_5_2/web/jetstream/template',
        'delphixpy/v1_5_2/web/jetstream/branch',
        'delphixpy/v1_5_2/web/jetstream/usagedata',
        'delphixpy/v1_5_2/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_5_2/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_5_2/web/jetstream/operation',
        'delphixpy/v1_5_2/web/jetstream/usage',
        'delphixpy/v1_5_2/web/jetstream/usage/template',
        'delphixpy/v1_5_2/web/jetstream/usage/branch',
        'delphixpy/v1_5_2/web/jetstream/usage/user',
        'delphixpy/v1_5_2/web/jetstream/usage/container',
        'delphixpy/v1_5_2/web/jetstream/usage/bookmark',
        'delphixpy/v1_5_2/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_5_2/web/jetstream/container',
        'delphixpy/v1_5_2/web/jetstream/bookmark',
        'delphixpy/v1_5_2/web/service',
        'delphixpy/v1_5_2/web/service/smtp',
        'delphixpy/v1_5_2/web/service/time',
        'delphixpy/v1_5_2/web/service/certificate',
        'delphixpy/v1_5_2/web/service/ldap',
        'delphixpy/v1_5_2/web/service/ldap/server',
        'delphixpy/v1_5_2/web/service/linkingsettings',
        'delphixpy/v1_5_2/web/service/phonehome',
        'delphixpy/v1_5_2/web/service/dns',
        'delphixpy/v1_5_2/web/service/support',
        'delphixpy/v1_5_2/web/service/support/bundle',
        'delphixpy/v1_5_2/web/service/support/access',
        'delphixpy/v1_5_2/web/service/security',
        'delphixpy/v1_5_2/web/service/locale',
        'delphixpy/v1_5_2/web/service/schema',
        'delphixpy/v1_5_2/web/service/syslog',
        'delphixpy/v1_5_2/web/service/snmp',
        'delphixpy/v1_5_2/web/service/snmp/manager',
        'delphixpy/v1_5_2/web/service/proxy',
        'delphixpy/v1_5_2/web/repository',
        'delphixpy/v1_5_2/web/repository/template',
        'delphixpy/v1_5_2/web/data',
        'delphixpy/v1_5_2/web/snapshot',
        'delphixpy/v1_5_2/web/alert',
        'delphixpy/v1_5_2/web/alert/profile',
        'delphixpy/v1_5_2/web/storage',
        'delphixpy/v1_5_2/web/storage/device',
        'delphixpy/v1_5_2/web/storage/scrub',
        'delphixpy/v1_5_2/web/storage/test',
        'delphixpy/v1_5_2/web/job',
        'delphixpy/v1_5_2/web/source',
        'delphixpy/v1_5_2/web/source/operationTemplate',
        'delphixpy/v1_5_2/web/sourceconfig',
        'delphixpy/v1_5_2/web/sourceconfig/oracle',
        'delphixpy/v1_5_2/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_5_2/web/namespace',
        'delphixpy/v1_5_2/web/about',
        'delphixpy/v1_8_2',
        'delphixpy/v1_8_2/web',
        'delphixpy/v1_8_2/web/environment',
        'delphixpy/v1_8_2/web/environment/oracle',
        'delphixpy/v1_8_2/web/environment/oracle/clusternode',
        'delphixpy/v1_8_2/web/environment/oracle/listener',
        'delphixpy/v1_8_2/web/environment/user',
        'delphixpy/v1_8_2/web/environment/windows',
        'delphixpy/v1_8_2/web/environment/windows/clusternode',
        'delphixpy/v1_8_2/web/environment/windows/clusterinstance',
        'delphixpy/v1_8_2/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_8_2/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_8_2/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_8_2/web/timezone',
        'delphixpy/v1_8_2/web/domain',
        'delphixpy/v1_8_2/web/connectivity',
        'delphixpy/v1_8_2/web/replication',
        'delphixpy/v1_8_2/web/replication/sourcestate',
        'delphixpy/v1_8_2/web/replication/targetstate',
        'delphixpy/v1_8_2/web/replication/spec',
        'delphixpy/v1_8_2/web/replication/serializationpoint',
        'delphixpy/v1_8_2/web/registration',
        'delphixpy/v1_8_2/web/registration/status',
        'delphixpy/v1_8_2/web/fault',
        'delphixpy/v1_8_2/web/fault/effect',
        'delphixpy/v1_8_2/web/network',
        'delphixpy/v1_8_2/web/network/interface',
        'delphixpy/v1_8_2/web/network/route',
        'delphixpy/v1_8_2/web/network/test',
        'delphixpy/v1_8_2/web/network/test/latency',
        'delphixpy/v1_8_2/web/network/test/throughput',
        'delphixpy/v1_8_2/web/network/test/dsp',
        'delphixpy/v1_8_2/web/transformation',
        'delphixpy/v1_8_2/web/database',
        'delphixpy/v1_8_2/web/database/template',
        'delphixpy/v1_8_2/web/user',
        'delphixpy/v1_8_2/web/delphix',
        'delphixpy/v1_8_2/web/host',
        'delphixpy/v1_8_2/web/host/privilegeElevation',
        'delphixpy/v1_8_2/web/host/privilegeElevation/profile',
        'delphixpy/v1_8_2/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_8_2/web/system',
        'delphixpy/v1_8_2/web/system/version',
        'delphixpy/v1_8_2/web/capacity',
        'delphixpy/v1_8_2/web/capacity/consumer',
        'delphixpy/v1_8_2/web/capacity/consumer/historical',
        'delphixpy/v1_8_2/web/capacity/system',
        'delphixpy/v1_8_2/web/capacity/system/historical',
        'delphixpy/v1_8_2/web/capacity/group',
        'delphixpy/v1_8_2/web/capacity/group/historical',
        'delphixpy/v1_8_2/web/capacity/snapshot',
        'delphixpy/v1_8_2/web/action',
        'delphixpy/v1_8_2/web/analytics',
        'delphixpy/v1_8_2/web/analytics/statistic',
        'delphixpy/v1_8_2/web/group',
        'delphixpy/v1_8_2/web/permission',
        'delphixpy/v1_8_2/web/notification',
        'delphixpy/v1_8_2/web/policy',
        'delphixpy/v1_8_2/web/session',
        'delphixpy/v1_8_2/web/timeflow',
        'delphixpy/v1_8_2/web/timeflow/oracle',
        'delphixpy/v1_8_2/web/timeflow/oracle/log',
        'delphixpy/v1_8_2/web/timeflow/bookmark',
        'delphixpy/v1_8_2/web/maskingjob',
        'delphixpy/v1_8_2/web/maskingjob/serviceconfig',
        'delphixpy/v1_8_2/web/objects',
        'delphixpy/v1_8_2/web/authorization',
        'delphixpy/v1_8_2/web/role',
        'delphixpy/v1_8_2/web/toolkit',
        'delphixpy/v1_8_2/web/jetstream',
        'delphixpy/v1_8_2/web/jetstream/datasource',
        'delphixpy/v1_8_2/web/jetstream/template',
        'delphixpy/v1_8_2/web/jetstream/branch',
        'delphixpy/v1_8_2/web/jetstream/usagedata',
        'delphixpy/v1_8_2/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_8_2/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_8_2/web/jetstream/operation',
        'delphixpy/v1_8_2/web/jetstream/usage',
        'delphixpy/v1_8_2/web/jetstream/usage/template',
        'delphixpy/v1_8_2/web/jetstream/usage/branch',
        'delphixpy/v1_8_2/web/jetstream/usage/user',
        'delphixpy/v1_8_2/web/jetstream/usage/container',
        'delphixpy/v1_8_2/web/jetstream/usage/bookmark',
        'delphixpy/v1_8_2/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_8_2/web/jetstream/container',
        'delphixpy/v1_8_2/web/jetstream/bookmark',
        'delphixpy/v1_8_2/web/service',
        'delphixpy/v1_8_2/web/service/saml',
        'delphixpy/v1_8_2/web/service/saml/serviceprovider',
        'delphixpy/v1_8_2/web/service/smtp',
        'delphixpy/v1_8_2/web/service/httpConnector',
        'delphixpy/v1_8_2/web/service/time',
        'delphixpy/v1_8_2/web/service/certificate',
        'delphixpy/v1_8_2/web/service/ldap',
        'delphixpy/v1_8_2/web/service/ldap/server',
        'delphixpy/v1_8_2/web/service/linkingsettings',
        'delphixpy/v1_8_2/web/service/phonehome',
        'delphixpy/v1_8_2/web/service/dns',
        'delphixpy/v1_8_2/web/service/support',
        'delphixpy/v1_8_2/web/service/support/bundle',
        'delphixpy/v1_8_2/web/service/support/access',
        'delphixpy/v1_8_2/web/service/security',
        'delphixpy/v1_8_2/web/service/locale',
        'delphixpy/v1_8_2/web/service/schema',
        'delphixpy/v1_8_2/web/service/syslog',
        'delphixpy/v1_8_2/web/service/snmp',
        'delphixpy/v1_8_2/web/service/snmp/manager',
        'delphixpy/v1_8_2/web/service/proxy',
        'delphixpy/v1_8_2/web/service/kerberos',
        'delphixpy/v1_8_2/web/repository',
        'delphixpy/v1_8_2/web/repository/template',
        'delphixpy/v1_8_2/web/data',
        'delphixpy/v1_8_2/web/snapshot',
        'delphixpy/v1_8_2/web/alert',
        'delphixpy/v1_8_2/web/alert/profile',
        'delphixpy/v1_8_2/web/storage',
        'delphixpy/v1_8_2/web/storage/device',
        'delphixpy/v1_8_2/web/storage/scrub',
        'delphixpy/v1_8_2/web/storage/remove',
        'delphixpy/v1_8_2/web/storage/test',
        'delphixpy/v1_8_2/web/job',
        'delphixpy/v1_8_2/web/source',
        'delphixpy/v1_8_2/web/source/operationTemplate',
        'delphixpy/v1_8_2/web/sourceconfig',
        'delphixpy/v1_8_2/web/sourceconfig/oracle',
        'delphixpy/v1_8_2/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_8_2/web/namespace',
        'delphixpy/v1_8_2/web/about',
        'delphixpy/v1_4_1',
        'delphixpy/v1_4_1/web',
        'delphixpy/v1_4_1/web/environment',
        'delphixpy/v1_4_1/web/environment/oracle',
        'delphixpy/v1_4_1/web/environment/oracle/clusternode',
        'delphixpy/v1_4_1/web/environment/oracle/listener',
        'delphixpy/v1_4_1/web/environment/user',
        'delphixpy/v1_4_1/web/environment/windows',
        'delphixpy/v1_4_1/web/environment/windows/clusternode',
        'delphixpy/v1_4_1/web/environment/windows/clusterinstance',
        'delphixpy/v1_4_1/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_4_1/web/domain',
        'delphixpy/v1_4_1/web/connectivity',
        'delphixpy/v1_4_1/web/replication',
        'delphixpy/v1_4_1/web/replication/spec',
        'delphixpy/v1_4_1/web/registration',
        'delphixpy/v1_4_1/web/registration/status',
        'delphixpy/v1_4_1/web/fault',
        'delphixpy/v1_4_1/web/fault/effect',
        'delphixpy/v1_4_1/web/network',
        'delphixpy/v1_4_1/web/network/interface',
        'delphixpy/v1_4_1/web/network/route',
        'delphixpy/v1_4_1/web/network/test',
        'delphixpy/v1_4_1/web/network/test/latency',
        'delphixpy/v1_4_1/web/network/test/throughput',
        'delphixpy/v1_4_1/web/database',
        'delphixpy/v1_4_1/web/database/template',
        'delphixpy/v1_4_1/web/user',
        'delphixpy/v1_4_1/web/delphix',
        'delphixpy/v1_4_1/web/host',
        'delphixpy/v1_4_1/web/host/privilegeElevation',
        'delphixpy/v1_4_1/web/host/privilegeElevation/profile',
        'delphixpy/v1_4_1/web/system',
        'delphixpy/v1_4_1/web/system/version',
        'delphixpy/v1_4_1/web/capacity',
        'delphixpy/v1_4_1/web/capacity/consumer',
        'delphixpy/v1_4_1/web/capacity/consumer/historical',
        'delphixpy/v1_4_1/web/capacity/system',
        'delphixpy/v1_4_1/web/capacity/system/historical',
        'delphixpy/v1_4_1/web/capacity/group',
        'delphixpy/v1_4_1/web/capacity/group/historical',
        'delphixpy/v1_4_1/web/capacity/snapshot',
        'delphixpy/v1_4_1/web/action',
        'delphixpy/v1_4_1/web/analytics',
        'delphixpy/v1_4_1/web/analytics/statistic',
        'delphixpy/v1_4_1/web/group',
        'delphixpy/v1_4_1/web/permission',
        'delphixpy/v1_4_1/web/notification',
        'delphixpy/v1_4_1/web/policy',
        'delphixpy/v1_4_1/web/session',
        'delphixpy/v1_4_1/web/timeflow',
        'delphixpy/v1_4_1/web/timeflow/bookmark',
        'delphixpy/v1_4_1/web/objects',
        'delphixpy/v1_4_1/web/authorization',
        'delphixpy/v1_4_1/web/role',
        'delphixpy/v1_4_1/web/toolkit',
        'delphixpy/v1_4_1/web/jetstream',
        'delphixpy/v1_4_1/web/jetstream/datasource',
        'delphixpy/v1_4_1/web/jetstream/template',
        'delphixpy/v1_4_1/web/jetstream/branch',
        'delphixpy/v1_4_1/web/jetstream/usagedata',
        'delphixpy/v1_4_1/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_4_1/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_4_1/web/jetstream/operation',
        'delphixpy/v1_4_1/web/jetstream/capacity',
        'delphixpy/v1_4_1/web/jetstream/capacity/template',
        'delphixpy/v1_4_1/web/jetstream/capacity/branch',
        'delphixpy/v1_4_1/web/jetstream/capacity/container',
        'delphixpy/v1_4_1/web/jetstream/capacity/bookmark',
        'delphixpy/v1_4_1/web/jetstream/capacity/bookmark/tag',
        'delphixpy/v1_4_1/web/jetstream/container',
        'delphixpy/v1_4_1/web/jetstream/preferences',
        'delphixpy/v1_4_1/web/jetstream/bookmark',
        'delphixpy/v1_4_1/web/service',
        'delphixpy/v1_4_1/web/service/smtp',
        'delphixpy/v1_4_1/web/service/time',
        'delphixpy/v1_4_1/web/service/certificate',
        'delphixpy/v1_4_1/web/service/ldap',
        'delphixpy/v1_4_1/web/service/ldap/server',
        'delphixpy/v1_4_1/web/service/linkingsettings',
        'delphixpy/v1_4_1/web/service/phonehome',
        'delphixpy/v1_4_1/web/service/dns',
        'delphixpy/v1_4_1/web/service/support',
        'delphixpy/v1_4_1/web/service/support/bundle',
        'delphixpy/v1_4_1/web/service/support/access',
        'delphixpy/v1_4_1/web/service/security',
        'delphixpy/v1_4_1/web/service/locale',
        'delphixpy/v1_4_1/web/service/syslog',
        'delphixpy/v1_4_1/web/service/snmp',
        'delphixpy/v1_4_1/web/service/snmp/manager',
        'delphixpy/v1_4_1/web/service/proxy',
        'delphixpy/v1_4_1/web/repository',
        'delphixpy/v1_4_1/web/data',
        'delphixpy/v1_4_1/web/snapshot',
        'delphixpy/v1_4_1/web/alert',
        'delphixpy/v1_4_1/web/alert/profile',
        'delphixpy/v1_4_1/web/storage',
        'delphixpy/v1_4_1/web/storage/device',
        'delphixpy/v1_4_1/web/storage/scrub',
        'delphixpy/v1_4_1/web/job',
        'delphixpy/v1_4_1/web/source',
        'delphixpy/v1_4_1/web/sourceconfig',
        'delphixpy/v1_4_1/web/sourceconfig/oracle',
        'delphixpy/v1_4_1/web/sourceconfig/oracle/pdb',
        'delphixpy/v1_4_1/web/namespace',
        'delphixpy/v1_4_1/web/about',
        'delphixpy/v1_9_3',
        'delphixpy/v1_9_3/web',
        'delphixpy/v1_9_3/web/environment',
        'delphixpy/v1_9_3/web/environment/oracle',
        'delphixpy/v1_9_3/web/environment/oracle/clusternode',
        'delphixpy/v1_9_3/web/environment/oracle/listener',
        'delphixpy/v1_9_3/web/environment/user',
        'delphixpy/v1_9_3/web/environment/windows',
        'delphixpy/v1_9_3/web/environment/windows/clusternode',
        'delphixpy/v1_9_3/web/environment/windows/clusterinstance',
        'delphixpy/v1_9_3/web/environment/windows/availabilitygrouplistener',
        'delphixpy/v1_9_3/web/environment/windows/failoverclusterrepositoryinstance',
        'delphixpy/v1_9_3/web/environment/windows/failoverclusterrepositorylistener',
        'delphixpy/v1_9_3/web/timezone',
        'delphixpy/v1_9_3/web/domain',
        'delphixpy/v1_9_3/web/connectivity',
        'delphixpy/v1_9_3/web/replication',
        'delphixpy/v1_9_3/web/replication/sourcestate',
        'delphixpy/v1_9_3/web/replication/targetstate',
        'delphixpy/v1_9_3/web/replication/spec',
        'delphixpy/v1_9_3/web/replication/serializationpoint',
        'delphixpy/v1_9_3/web/registration',
        'delphixpy/v1_9_3/web/registration/status',
        'delphixpy/v1_9_3/web/fault',
        'delphixpy/v1_9_3/web/fault/effect',
        'delphixpy/v1_9_3/web/network',
        'delphixpy/v1_9_3/web/network/interface',
        'delphixpy/v1_9_3/web/network/route',
        'delphixpy/v1_9_3/web/network/test',
        'delphixpy/v1_9_3/web/network/test/latency',
        'delphixpy/v1_9_3/web/network/test/throughput',
        'delphixpy/v1_9_3/web/network/test/dsp',
        'delphixpy/v1_9_3/web/network/dsp',
        'delphixpy/v1_9_3/web/network/dsp/autotune',
        'delphixpy/v1_9_3/web/transformation',
        'delphixpy/v1_9_3/web/database',
        'delphixpy/v1_9_3/web/database/template',
        'delphixpy/v1_9_3/web/database/performanceHistory',
        'delphixpy/v1_9_3/web/user',
        'delphixpy/v1_9_3/web/delphix',
        'delphixpy/v1_9_3/web/host',
        'delphixpy/v1_9_3/web/host/privilegeElevation',
        'delphixpy/v1_9_3/web/host/privilegeElevation/profile',
        'delphixpy/v1_9_3/web/host/privilegeElevation/profileScript',
        'delphixpy/v1_9_3/web/system',
        'delphixpy/v1_9_3/web/system/package',
        'delphixpy/v1_9_3/web/system/version',
        'delphixpy/v1_9_3/web/system/upgradeCheckResult',
        'delphixpy/v1_9_3/web/capacity',
        'delphixpy/v1_9_3/web/capacity/consumer',
        'delphixpy/v1_9_3/web/capacity/consumer/historical',
        'delphixpy/v1_9_3/web/capacity/system',
        'delphixpy/v1_9_3/web/capacity/system/historical',
        'delphixpy/v1_9_3/web/capacity/group',
        'delphixpy/v1_9_3/web/capacity/group/historical',
        'delphixpy/v1_9_3/web/capacity/snapshot',
        'delphixpy/v1_9_3/web/action',
        'delphixpy/v1_9_3/web/analytics',
        'delphixpy/v1_9_3/web/analytics/statistic',
        'delphixpy/v1_9_3/web/group',
        'delphixpy/v1_9_3/web/passwordPolicy',
        'delphixpy/v1_9_3/web/permission',
        'delphixpy/v1_9_3/web/notification',
        'delphixpy/v1_9_3/web/policy',
        'delphixpy/v1_9_3/web/session',
        'delphixpy/v1_9_3/web/timeflow',
        'delphixpy/v1_9_3/web/timeflow/oracle',
        'delphixpy/v1_9_3/web/timeflow/oracle/log',
        'delphixpy/v1_9_3/web/timeflow/bookmark',
        'delphixpy/v1_9_3/web/maskingjob',
        'delphixpy/v1_9_3/web/maskingjob/serviceconfig',
        'delphixpy/v1_9_3/web/objects',
        'delphixpy/v1_9_3/web/authorization',
        'delphixpy/v1_9_3/web/role',
        'delphixpy/v1_9_3/web/toolkit',
        'delphixpy/v1_9_3/web/jetstream',
        'delphixpy/v1_9_3/web/jetstream/datasource',
        'delphixpy/v1_9_3/web/jetstream/template',
        'delphixpy/v1_9_3/web/jetstream/branch',
        'delphixpy/v1_9_3/web/jetstream/usagedata',
        'delphixpy/v1_9_3/web/jetstream/usagedata/operationduration',
        'delphixpy/v1_9_3/web/jetstream/usagedata/operationcount',
        'delphixpy/v1_9_3/web/jetstream/config',
        'delphixpy/v1_9_3/web/jetstream/operation',
        'delphixpy/v1_9_3/web/jetstream/usage',
        'delphixpy/v1_9_3/web/jetstream/usage/template',
        'delphixpy/v1_9_3/web/jetstream/usage/branch',
        'delphixpy/v1_9_3/web/jetstream/usage/user',
        'delphixpy/v1_9_3/web/jetstream/usage/container',
        'delphixpy/v1_9_3/web/jetstream/usage/bookmark',
        'delphixpy/v1_9_3/web/jetstream/usage/bookmark/tag',
        'delphixpy/v1_9_3/web/jetstream/container',
        'delphixpy/v1_9_3/web/jetstream/bookmark',
        'delphixpy/v1_9_3/web/service',
        'delphixpy/v1_9_3/web/service/saml',
        'delphixpy/v1_9_3/web/service/saml/serviceprovider',
        'delphixpy/v1_9_3/web/service/smtp',
        'delphixpy/v1_9_3/web/service/httpConnector',
        'delphixpy/v1_9_3/web/service/time',
        'delphixpy/v1_9_3/web/service/certificate',
        'delphixpy/v1_9_3/web/service/ldap',
        'delphixpy/v1_9_3/web/service/ldap/server',
        'delphixpy/v1_9_3/web/service/linkingsettings',
        'delphixpy/v1_9_3/web/service/phonehome',
        'delphixpy/v1_9_3/web/service/dns',
        'delphixpy/v1_9_3/web/service/support',
        'delphixpy/v1_9_3/web/service/support/bundle',
        'delphixpy/v1_9_3/web/service/support/access',
        'delphixpy/v1_9_3/web/service/security',
        'delphixpy/v1_9_3/web/service/userInterface',
        'delphixpy/v1_9_3/web/service/locale',
        'delphixpy/v1_9_3/web/service/schema',
        'delphixpy/v1_9_3/web/service/syslog',
        'delphixpy/v1_9_3/web/service/snmp',
        'delphixpy/v1_9_3/web/service/snmp/manager',
        'delphixpy/v1_9_3/web/service/proxy',
        'delphixpy/v1_9_3/web/service/tls',
        'delphixpy/v1_9_3/web/service/tls/caCertificate',
        'delphixpy/v1_9_3/web/service/tls/csr',
        'delphixpy/v1_9_3/web/service/tls/endEntityCertificate',
        'delphixpy/v1_9_3/web/service/kerberos',
        'delphixpy/v1_9_3/web/repository',
        'delphixpy/v1_9_3/web/repository/template',
        'delphixpy/v1_9_3/web/data',
        'delphixpy/v1_9_3/web/snapshot',
        'delphixpy/v1_9_3/web/alert',
        'delphixpy/v1_9_3/web/alert/profile',
        'delphixpy/v1_9_3/web/storage',
        'delphixpy/v1_9_3/web/storage/device',
        'delphixpy/v1_9_3/web/storage/scrub',
        'delphixpy/v1_9_3/web/storage/remove',
        'delphixpy/v1_9_3/web/storage/test',
        'delphixpy/v1_9_3/web/job',
        'delphixpy/v1_9_3/web/source',
        'delphixpy/v1_9_3/web/source/operationTemplate',
        'delphixpy/v1_9_3/web/sourceconfig',
        'delphixpy/v1_9_3/web/namespace',
        'delphixpy/v1_9_3/web/about'
    ]
)